<?php

$LANG = array(
    'organization' => 'Organizzazione',
    'name' => 'Nome',
    'website' => 'Sito web',
    'work_phone' => 'Telefono',
    'address' => 'Indirizzo',
    'address1' => 'Via',
    'address2' => 'Appartamento/Piano',
    'city' => 'Città',
    'state' => 'Stato/Provincia',
    'postal_code' => 'Codice postale',
    'country_id' => 'Paese',
    'contacts' => 'Contatti',
    'first_name' => 'Nome',
    'last_name' => 'Cognome',
    'phone' => 'Telefono',
    'email' => 'Email',
    'additional_info' => 'Maggiori informazioni',
    'payment_terms' => 'Termini di pagamento',
    'currency_id' => 'Valuta',
    'size_id' => 'Dimensione',
    'industry_id' => 'Industria',
    'private_notes' => 'Note Personali',
    'invoice' => 'Fattura',
    'client' => 'Cliente',
    'invoice_date' => 'Data Fattura',
    'due_date' => 'Scadenza',
    'invoice_number' => 'Numero Fattura',
    'invoice_number_short' => 'Fattura #',
    'po_number' => 'Numero d\'ordine d\'acquisto',
    'po_number_short' => 'Ordine d\'acquisto #',
    'frequency_id' => 'Frequenza',
    'discount' => 'Sconto',
    'taxes' => 'Tasse',
    'tax' => 'Tassa',
    'item' => 'Articolo',
    'description' => 'Descrizione',
    'unit_cost' => 'Costo Unitario',
    'quantity' => 'Quantità',
    'line_total' => 'Totale Riga',
    'subtotal' => 'Subtotale',
    'paid_to_date' => 'Pagato a oggi',
    'balance_due' => 'Totale da Pagare',
    'invoice_design_id' => 'Stile',
    'terms' => 'Termini',
    'your_invoice' => 'La Tua Fattura',
    'remove_contact' => 'Rimuovi contatto',
    'add_contact' => 'Aggiungi contatto',
    'create_new_client' => 'Crea nuovo cliente',
    'edit_client_details' => 'Modifica dati cliente',
    'enable' => 'Abilita',
    'learn_more' => 'Scopri di più',
    'manage_rates' => 'Gestisci tassi',
    'note_to_client' => 'Nota al cliente',
    'invoice_terms' => 'Termini della fattura',
    'save_as_default_terms' => 'Salva termini come predefiniti',
    'download_pdf' => 'Scarica PDF',
    'pay_now' => 'Paga Adesso',
    'save_invoice' => 'Salva Fattura',
    'clone_invoice' => 'Clona come Fattura',
    'archive_invoice' => 'Archivia Fattura',
    'delete_invoice' => 'Elimina Fattura',
    'email_invoice' => 'Invia Fattura',
    'enter_payment' => 'Inserisci Pagamento',
    'tax_rates' => 'Aliquote Fiscali',
    'rate' => 'Aliquota',
    'settings' => 'Impostazioni',
    'enable_invoice_tax' => 'Possibile specificare <b>tasse per la fattura</b>',
    'enable_line_item_tax' => 'Abilita <b>imposta specifica per ogni riga articolo</b>',
    'dashboard' => 'Pannello di Controllo',
    'dashboard_totals_in_all_currencies_help' => 'Nota: aggiungi un :link chiamato ":name" per vedere i totali usando una sola valuta di base.',
    'clients' => 'Clienti',
    'invoices' => 'Fatture',
    'payments' => 'Pagamenti',
    'credits' => 'Crediti',
    'history' => 'Storico',
    'search' => 'Cerca',
    'sign_up' => 'Registrati',
    'guest' => 'Ospite',
    'company_details' => 'Dettagli Azienda',
    'online_payments' => 'Pagamenti Online',
    'notifications' => 'Notifiche',
    'import_export' => 'Importa/Esporta',
    'done' => 'Fatto',
    'save' => 'Salva',
    'create' => 'Crea',
    'upload' => 'Carica',
    'import' => 'Importa',
    'download' => 'Scarica',
    'cancel' => 'Annulla',
    'close' => 'Close',
    'provide_email' => 'Per favore, fornisci un indirizzo email valido',
    'powered_by' => 'Powered by',
    'no_items' => 'Nessun articolo',
    'recurring_invoices' => 'Fatture Ricorrenti',
    'recurring_help' => '<p>Invia automaticamente al cliente le stesse fatture settimanalmente, bimestralmente, mensilmente, trimestralmente o annualmente. </p>
        <p>Usa :MONTH, :QUARTER o :YEAR per date dinamiche. Funziona anche con la matematica di base, ad esempio :MONTH-1.</p>
        <p>Esempi di variabili di fattura dinamiche:</p>
        <ul>
          <li>"Iscrizione palestra per il mese di :MONTH" => "Iscrizione palestra per il mese di Luglio"</li>
          <li>"Anno d\'iscrizione :YEAR+1" => "Anno d\'iscrizione 2015"</li>
          <li>"Pagamento fermo a :QUARTER+1" => "Pagamento fermo a Q2"</li>
        </ul>',
    'recurring_quotes' => 'Preventivi Ricorrenti',
    'in_total_revenue' => 'di fatturato',
    'billed_client' => 'Cliente fatturato',
    'billed_clients' => 'Clienti fatturati',
    'active_client' => 'cliente attivo',
    'active_clients' => 'clienti attivi',
    'invoices_past_due' => 'Fatture Scadute',
    'upcoming_invoices' => 'Prossime fatture',
    'average_invoice' => 'Fattura media',
    'archive' => 'Archivia',
    'delete' => 'Elimina',
    'archive_client' => 'Archivia cliente',
    'delete_client' => 'Elimina cliente',
    'archive_payment' => 'Archivia pagamento',
    'delete_payment' => 'Elimina pagamento',
    'archive_credit' => 'Archivia credito',
    'delete_credit' => 'Elimina credito',
    'show_archived_deleted' => 'Mostra Archiviati/eliminati',
    'filter' => 'Filtra',
    'new_client' => 'Nuovo Cliente',
    'new_invoice' => 'Nuova Fattura',
    'new_payment' => 'Inserisci il pagamento',
    'new_credit' => 'Inserisci il credito',
    'contact' => 'Contatto',
    'date_created' => 'Data Creazione',
    'last_login' => 'Ultimo Accesso',
    'balance' => 'Bilancio',
    'action' => 'Azione',
    'status' => 'Stato',
    'invoice_total' => 'Totale Fattura',
    'frequency' => 'Frequenza',
    'range' => 'Intervallo',
    'start_date' => 'Data Inizio',
    'end_date' => 'Data Fine',
    'transaction_reference' => 'Riferimento Transazione',
    'method' => 'Metodo',
    'payment_amount' => 'Importo Pagamento',
    'payment_date' => 'Data Pagamento',
    'credit_amount' => 'Importo Credito',
    'credit_balance' => 'Saldo Credito',
    'credit_date' => 'Data Credito',
    'empty_table' => 'Nessun dato disponibile nella tabella',
    'select' => 'Seleziona',
    'edit_client' => 'Modifica Cliente',
    'edit_invoice' => 'Modifica Fattura',
    'create_invoice' => 'Crea Fattura',
    'enter_credit' => 'Inserisci Credito',
    'last_logged_in' => 'Ultimo accesso',
    'details' => 'Dettagli',
    'standing' => 'Fermo',
    'credit' => 'Credito',
    'activity' => 'Attività',
    'date' => 'Data',
    'message' => 'Messaggio',
    'adjustment' => 'Variazione',
    'are_you_sure' => 'Sei sicuro?',
    'payment_type_id' => 'Tipo di Pagamento',
    'amount' => 'Importo',
    'work_email' => 'Email',
    'language_id' => 'Lingua',
    'timezone_id' => 'Fuso Orario',
    'date_format_id' => 'Formato data',
    'datetime_format_id' => 'Formato Data/Ora',
    'users' => 'Utenti',
    'localization' => 'Linguaggio',
    'remove_logo' => 'Rimuovi logo',
    'logo_help' => 'Supportati: JPEG, GIF e PNG',
    'payment_gateway' => 'Piattaforma di Pagamento',
    'gateway_id' => 'Piattaforma',
    'email_notifications' => 'Notifiche Email',
    'email_sent' => 'Mandami un\'email quando una fattura è <b>inviata</b>',
    'email_viewed' => 'Mandami un\'email quando una fattura è <b>visualizzata</b>',
    'email_paid' => 'Mandami un\'email quando una fattura è <b>pagata</b>',
    'site_updates' => 'Aggiornamenti Sito',
    'custom_messages' => 'Messaggi Personalizzati',
    'default_email_footer' => 'Salva firma email come predefinita',
    'select_file' => 'Seleziona un file, per favore',
    'first_row_headers' => 'Usa la prima riga come Intestazione',
    'column' => 'Colonna',
    'sample' => 'Esempio',
    'import_to' => 'Importa in',
    'client_will_create' => 'il cliente sarà creato',
    'clients_will_create' => 'i clienti saranno creati',
    'email_settings' => 'Impostazioni email',
    'client_view_styling' => 'Stile di visualizzazione cliente',
    'pdf_email_attachment' => 'Allega PDF',
    'custom_css' => 'CSS Personalizzato',
    'import_clients' => 'Importa Dati Clienti',
    'csv_file' => 'Seleziona file CSV',
    'export_clients' => 'Esporta Dati Clienti',
    'created_client' => 'Cliente creato con successo',
    'created_clients' => ':count clienti creati con successo',
    'updated_settings' => 'Impostazioni aggiornate con successo',
    'removed_logo' => 'Logo rimosso con successo',
    'sent_message' => 'Messaggio inviato con successo',
    'invoice_error' => 'Per favore, assicurati di aver selezionato un cliente e correggi tutti gli errori',
    'limit_clients' => 'Ci dispiace, questo supererà il limite di :count clienti',
    'payment_error' => 'C\'è stato un errore durante il pagamento. Riprova più tardi, per favore.',
    'registration_required' => 'Per favore, registrati per inviare una fattura',
    'confirmation_required' => 'Vogliate confermare il vostro indirizzo email, :link per rinviare una email di conferma',
    'updated_client' => 'Cliente aggiornato con successo',
    'archived_client' => 'Cliente archiviato con successo',
    'archived_clients' => ':count clienti archiviati con successo',
    'deleted_client' => 'Cliente eliminato con successo',
    'deleted_clients' => ':count clienti eliminati con successo',
    'updated_invoice' => 'Fattura aggiornata con successo',
    'created_invoice' => 'Fattura creata con successo',
    'cloned_invoice' => 'Fattura duplicata con successo',
    'emailed_invoice' => 'Fattura inviata con successo',
    'and_created_client' => 'e cliente creato',
    'archived_invoice' => 'Fattura archiviata con successo',
    'archived_invoices' => ':count fatture archiviate con successo',
    'deleted_invoice' => 'Fattura eliminata con successo',
    'deleted_invoices' => ':count fatture eliminate con successo',
    'created_payment' => 'Pagamento creato con successo',
    'created_payments' => 'Creati :count pagamenti con successo.',
    'archived_payment' => 'Pagamento archiviato con successo',
    'archived_payments' => ':count pagamenti archiviati con successo',
    'deleted_payment' => 'Pagamenti eliminati con successo',
    'deleted_payments' => ':count pagamenti eliminati con successo',
    'applied_payment' => 'Pagamento applicato con successo',
    'created_credit' => 'Credito creato con successo',
    'archived_credit' => 'Credito archiviato con successo',
    'archived_credits' => ':count crediti archiviati con successo',
    'deleted_credit' => 'Credito eliminato con successo',
    'deleted_credits' => ':count crediti eliminati con successo',
    'imported_file' => 'File importato con successo',
    'updated_vendor' => 'Fornitore aggiornato con successo',
    'created_vendor' => 'Fornitore creato con successo',
    'archived_vendor' => 'Fornitore archiviato con successo',
    'archived_vendors' => ':count fornitori archiviati con successo',
    'deleted_vendor' => 'Fornitore eliminato con successo',
    'deleted_vendors' => ':count fornitori eliminati con successo',
    'confirmation_subject' => 'Conferma Account Invoice Ninja',
    'confirmation_header' => 'Conferma Account',
    'confirmation_message' => 'Per favore, accedi al link qui sotto per confermare il tuo account.',
    'invoice_subject' => 'Nuova fattura :number da :account',
    'invoice_message' => 'Per visualizzare la tua fattura di :amount, clicca sul link qui sotto.',
    'payment_subject' => 'Pagamento Ricevuto',
    'payment_message' => 'Grazie per il tuo pagamento di :amount.',
    'email_salutation' => 'Caro :name,',
    'email_signature' => 'Distinti saluti,',
    'email_from' => 'Il Team di InvoiceNinja',
    'invoice_link_message' => 'Per visualizzare la tua fattura del cliente clicca sul link qui sotto:',
    'notification_invoice_paid_subject' => 'La fattura :invoice è stata pagata da :client',
    'notification_invoice_sent_subject' => 'La fattura :invoice è stata inviata a :client',
    'notification_invoice_viewed_subject' => 'La fattura :invoice è stata visualizzata da :client',
    'notification_invoice_paid' => 'Un pagamento di :amount è stato effettuato dal cliente :client attraverso la fattura :invoice.',
    'notification_invoice_sent' => 'Al seguente cliente :client è stata inviata via email la fattura :invoice di :amount.',
    'notification_invoice_viewed' => 'Il seguente cliente :client ha visualizzato la fattura :invoice di :amount.',
    'reset_password' => 'Puoi resettare la password del tuo account cliccando sul link qui sotto:',
    'secure_payment' => 'Pagamento Sicuro',
    'card_number' => 'Numero Carta',
    'expiration_month' => 'Mese di Scadenza',
    'expiration_year' => 'Anno di Scadenza',
    'cvv' => 'CVV',
    'logout' => 'Esci',
    'sign_up_to_save' => 'Registrati per salvare il tuo lavoro',
    'agree_to_terms' => 'Accetto i :terms',
    'terms_of_service' => 'Termini di Servizio',
    'email_taken' => 'Questo indirizzo email è già registrato',
    'working' => 'In elaborazione',
    'success' => 'Fatto',
    'success_message' => 'Registrazione avvenuta con successo. Per favore visita il link nell\'email di conferma per verificare il tuo indirizzo email.',
    'erase_data' => 'Il tuo account non è registrato, questo eliminerà definitivamente i tuoi dati.',
    'password' => 'Password',
    'pro_plan_product' => 'Piano PRO',
    'pro_plan_success' => 'Grazie per aver aderito! Non appena la fattura risulterà pagata il tuo piano PRO avrà inizio.',
    'unsaved_changes' => 'Ci sono dei cambiamenti non salvati',
    'custom_fields' => 'Campi Personalizzabili',
    'company_fields' => 'Campi Azienda',
    'client_fields' => 'Campi Cliente',
    'field_label' => 'Etichetta Campo',
    'field_value' => 'Valore Campo',
    'edit' => 'Modifica',
    'set_name' => 'Imposta il nome dalla tua azienda',
    'view_as_recipient' => 'Visualizza come destinatario',
    'product_library' => 'Libreria prodotti',
    'product' => 'Prodotto',
    'products' => 'Prodotti',
    'fill_products' => 'Riempimento automatico prodotti',
    'fill_products_help' => 'Selezionare un prodotto farà automaticamente <b>inserire la descrizione ed il costo</b>',
    'update_products' => 'Aggiorna automaticamente i prodotti',
    'update_products_help' => 'Aggiornare una fatura farà automaticamente <b>aggiornare i prodotti</b>',
    'create_product' => 'Crea Prodotto',
    'edit_product' => 'Modifica Prodotto',
    'archive_product' => 'Archivia Prodotto',
    'updated_product' => 'Prodotto aggiornato con successo',
    'created_product' => 'Prodotto creato con successo',
    'archived_product' => 'Prodotto archiviato con successo',
    'pro_plan_custom_fields' => ':link per attivare i campi personalizzati sottoscrivi il Piano Pro',
    'advanced_settings' => 'Impostazioni Avanzate',
    'pro_plan_advanced_settings' => ':link per attivare le impostazioni avanzate sottoscrivi il Piano Pro',
    'invoice_design' => 'Stile Fattura',
    'specify_colors' => 'Specifica i Colori',
    'specify_colors_label' => 'Select the colors used in the invoice',
    'chart_builder' => 'Creatore grafico',
    'ninja_email_footer' => 'Creato da :site | Crea. Invia. Ricevi pagamento.',
    'go_pro' => 'diventa Pro',
    'quote' => 'Preventivo',
    'quotes' => 'Preventivi',
    'quote_number' => 'Numero Preventivo',
    'quote_number_short' => 'Preventivo #',
    'quote_date' => 'Data Preventivo',
    'quote_total' => 'Totale Preventivo',
    'your_quote' => 'Il vostro Preventivo',
    'total' => 'Totale',
    'clone' => 'Clona',
    'new_quote' => 'Nuovo Preventivo',
    'create_quote' => 'Crea Preventivo',
    'edit_quote' => 'Modifica Preventivo',
    'archive_quote' => 'Archivia Preventivo',
    'delete_quote' => 'Cancella Preventivo',
    'save_quote' => 'Salva Preventivo',
    'email_quote' => 'Invia Preventivo via Email',
    'clone_quote' => 'Clona come Preventivo',
    'convert_to_invoice' => 'Converti a Fattura',
    'view_invoice' => 'Vedi Fattura',
    'view_client' => 'Vedi Cliente',
    'view_quote' => 'Vedi Preventivo',
    'updated_quote' => 'Preventivo aggiornato con successo',
    'created_quote' => 'Preventivo creato con successo',
    'cloned_quote' => 'Preventivo clonato con successo',
    'emailed_quote' => 'Preventivo inviato con successo',
    'archived_quote' => 'Preventivo archiviato con successo',
    'archived_quotes' => 'Sono stati archiviati :count preventivi con successo',
    'deleted_quote' => 'Preventivo cancellato con successo',
    'deleted_quotes' => 'Sono stati cancellati :count preventivi con successo',
    'converted_to_invoice' => 'Il preventivo è stato convertito a fattura con successo',
    'quote_subject' => 'Nuovo preventivo :number da :account',
    'quote_message' => 'Per visualizzare il vostro preventivo di :amount, cliccate il collegamento sotto.',
    'quote_link_message' => 'Per visualizzare il preventivo del vostro cliente cliccate il collegamento sotto:',
    'notification_quote_sent_subject' => 'Il preventivo :invoice è stato inviato a :client',
    'notification_quote_viewed_subject' => 'Il preventivo :invoice è stato visualizzato da :client',
    'notification_quote_sent' => 'Al seguente cliente :client è stata inviato il preventivo :invoice per un importo di :amount.',
    'notification_quote_viewed' => 'Il seguente cliente :client ha visualizzato il preventivo :invoice di :amount.',
    'session_expired' => 'La vostra sessione è scaduta.',
    'invoice_fields' => 'Campi Fattura',
    'invoice_options' => 'Opzioni Fattura',
    'hide_paid_to_date' => 'Nascondi la data di pagamento',
    'hide_paid_to_date_help' => 'Visualizza l\'area "Pagato alla data" sulle fatture solo dopo aver ricevuto un pagamento.',
    'charge_taxes' => 'Applica Tasse',
    'user_management' => 'Gestione utente',
    'add_user' => 'Aggiungi Utente',
    'send_invite' => 'Invia Invito',
    'sent_invite' => 'Invito inviato con successo',
    'updated_user' => 'Utente aggiornato con successo',
    'invitation_message' => 'Sei stato invitato da :invitor.',
    'register_to_add_user' => 'Registrati per aggiungere un utente',
    'user_state' => 'Stato',
    'edit_user' => 'Modifca Utente',
    'delete_user' => 'Elimia Utente',
    'active' => 'Attivo',
    'pending' => 'In attesa',
    'deleted_user' => 'Utente eliminato con successo',
    'confirm_email_invoice' => 'Sei sicuro di voler spedire via email questa fattura?',
    'confirm_email_quote' => 'Sei sicuro di voler inviare questo preventivo via email?',
    'confirm_recurring_email_invoice' => 'Sei sicuro di voler inviare questa fattura via email?',
    'confirm_recurring_email_invoice_not_sent' => 'Sei sicuro di voler iniziare la periodicità?',
    'cancel_account' => 'Elimina l\'account',
    'cancel_account_message' => 'Attenzione: Questo eliminerà permanentemente il tuo account, non si potrà più tornare indietro.',
    'go_back' => 'Torna indietro',
    'data_visualizations' => 'Visualizzazioni dei dati',
    'sample_data' => 'Mostra dati di esempio',
    'hide' => 'Nascondi',
    'new_version_available' => 'È disponibile una nuova versione di :releases_link. Stai eseguendo la v:user_version, L\'ultima è la v:latest_version',
    'invoice_settings' => 'Preferenze Fattura',
    'invoice_number_prefix' => 'Prefisso numerazione fatture',
    'invoice_number_counter' => 'Contatore numerazione fatture',
    'quote_number_prefix' => 'Prefisso numerazione preventivi',
    'quote_number_counter' => 'Contatore numerazione preventivi',
    'share_invoice_counter' => 'Condividi contatore fatture',
    'invoice_issued_to' => 'Fattura emessa a',
    'invalid_counter' => 'Per prevenire possibili conflitti per favore setta un prefisso sia per le fatture che per i preventivi',
    'mark_sent' => 'Contrassegna come inviato',
    'gateway_help_1' => ':link per iscriversi a Authorize.net.',
    'gateway_help_2' => ':link per iscriversi a Authorize.net.',
    'gateway_help_17' => ':link per ottenere la firma API di PayPal.',
    'gateway_help_27' => ':link per registrarsi su 2Checkout.com. Per garantire che i pagamenti vengano tracciati, imposta :complete_link come URL di reindirizzamento in Account > Site Management nel portale 2Checkout.',
    'gateway_help_60' => ':link per creare un account WePay',
    'more_designs' => 'Più stili',
    'more_designs_title' => 'Stili di fattura aggiuntivi',
    'more_designs_cloud_header' => 'Attiva Pro per stili di fattura aggiuntivi',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Compra',
    'bought_designs' => 'Nuovi stili di fattura aggiunti con successo ',
    'sent' => 'Inviato',
    'vat_number' => 'Partita IVA',
    'timesheets' => 'Schede attività',
    'payment_title' => 'Inserisci il tuo indirizzo di fatturazione e i dati della tua carta di credito',
    'payment_cvv' => '*Numero di 3-4 cifre sul retro della carta',
    'payment_footer1' => '*L\'indirizzo di fatturazione deve corrispondere all\'indirizzo associato alla carta di credito.',
    'payment_footer2' => '* Fare clic su "PAY NOW" solo una volta - la transazione può richiedere fino a 1 minuto per l\'elaborazione.',
    'id_number' => 'Codice Fiscale',
    'white_label_link' => 'Etichetta bianca',
    'white_label_header' => 'Etichetta bianca',
    'bought_white_label' => 'Abilitata con successo la licenza etichetta bianca',
    'white_labeled' => 'Etichetta bianca',
    'restore' => 'Ripristina',
    'restore_invoice' => 'Ripristina Fattura',
    'restore_quote' => 'Ripristina Preventivo',
    'restore_client' => 'Ripristina Cliente',
    'restore_credit' => 'Ripristina Credito',
    'restore_payment' => 'Ripristina Pagamento',
    'restored_invoice' => 'Fattura ripristinata con successo',
    'restored_quote' => 'Preventivo ripristinato con successo',
    'restored_client' => 'Cliente ripristinato con successo',
    'restored_payment' => 'Pagamento ripristinato con successo',
    'restored_credit' => 'Credito ripristinato con successo',
    'reason_for_canceling' => 'Aiutaci a migliorare il nostro sito dicendoci perché ci stai lasciando.',
    'discount_percent' => 'Percentuale',
    'discount_amount' => 'Quantità',
    'invoice_history' => 'Storico fatture',
    'quote_history' => 'Storico preventivi',
    'current_version' => 'Versione attuale',
    'select_version' => 'Seleziona versione',
    'view_history' => 'Vedi storico',
    'edit_payment' => 'Modifica pagamento',
    'updated_payment' => 'Pagamento aggiornato con successo',
    'deleted' => 'Eliminato',
    'restore_user' => 'Ripristina utente',
    'restored_user' => 'Utente ripristinato con successo',
    'show_deleted_users' => 'Visualizza utenti cancellati',
    'email_templates' => 'Modelli Email',
    'invoice_email' => 'Email Fattura',
    'payment_email' => 'Email Pagamento',
    'quote_email' => 'Email Preventivo',
    'reset_all' => 'Resetta Tutto',
    'approve' => 'Approva',
    'token_billing_type_id' => 'Fatturazione',
    'token_billing_help' => 'Memorizza i dettagli di pagamento con WePay, Stripe, Braintree o GoCardless.',
    'token_billing_1' => 'Disabilitato',
    'token_billing_2' => 'Attivazione: la checkbox è mostrata ma non selezionata',
    'token_billing_3' => 'Rinuncia - la checkbox è visualizzata e selezionata',
    'token_billing_4' => 'Sempre',
    'token_billing_checkbox' => 'Salva dettagli carta di credito',
    'view_in_gateway' => 'Vedi transazione in :gateway',
    'use_card_on_file' => 'Usa Card su File',
    'edit_payment_details' => 'Modifica dettagli pagamento',
    'token_billing' => 'Salva carta di credito',
    'token_billing_secure' => 'I dati sono memorizzati su piattaforma sicura mediante :link',
    'support' => 'Supporto',
    'contact_information' => 'Informazioni di contatto',
    '256_encryption' => 'Criptazione 256-Bit',
    'amount_due' => 'Saldo dovuto',
    'billing_address' => 'Indirizzo di fatturazione',
    'billing_method' => 'Metodo di pagamento',
    'order_overview' => 'Riepilogo ordine',
    'match_address' => '*L\'indirizzo deve corrispondere con quello associato alla carta di credito.',
    'click_once' => '*Per favore clicca "PAGA ADESSO" solo una volta - la transazione può impiegare sino a 1 minuto per essere completata.',
    'invoice_footer' => 'Piè di Pagina Fattura',
    'save_as_default_footer' => 'Salva come più di pagina predefinito',
    'token_management' => 'Gestione token',
    'tokens' => 'Token',
    'add_token' => 'Aggiungi token',
    'show_deleted_tokens' => 'Mostra token eliminati',
    'deleted_token' => 'Token eliminato correttamente',
    'created_token' => 'Token creato correttamente',
    'updated_token' => 'Token aggiornato correttamente',
    'edit_token' => 'Modifica token',
    'delete_token' => 'Elimina Token',
    'token' => 'Token',
    'add_gateway' => 'Aggiungi Gateway',
    'delete_gateway' => 'Elimina Gateway',
    'edit_gateway' => 'Modifica Gateway',
    'updated_gateway' => 'Piattaforma aggiornata con successo',
    'created_gateway' => 'Gateway creato correttamente',
    'deleted_gateway' => 'Piattaforma eliminata correttamente',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Carta di Credito',
    'change_password' => 'Cambia password',
    'current_password' => 'Password attuale',
    'new_password' => 'Nuova password',
    'confirm_password' => 'Conferma password',
    'password_error_incorrect' => 'La password inserita è incorretta.',
    'password_error_invalid' => 'La nuova password non è valida.',
    'updated_password' => 'Password aggiornata correttamente',
    'api_tokens' => 'API Token',
    'users_and_tokens' => 'Utenti & Token',
    'account_login' => 'Login account',
    'recover_password' => 'Recupera password',
    'forgot_password' => 'Hai dimenticato la password?',
    'email_address' => 'Indirizzo eMail',
    'lets_go' => 'Vai',
    'password_recovery' => 'Recupero Password',
    'send_email' => 'Invia Email',
    'set_password' => 'Imposta Password',
    'converted' => 'Convertito',
    'email_approved' => 'Inviami una email quando il preventivo è <b>Accettato</b>',
    'notification_quote_approved_subject' => 'Il preventivo :invoice è stato approvato dal :client',
    'notification_quote_approved' => 'Il cliente :client ha approvato il preventivo :invoice di :amount.',
    'resend_confirmation' => 'Re-invio mail di conferma',
    'confirmation_resent' => 'L\'e-mail di conferma è stata nuovamente inviata',
    'gateway_help_42' => ':link per registrarti a BitPay.<br/> Nota: utilizza una Key API legacy, non un token API.',
    'payment_type_credit_card' => 'Carta di credito',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'Conoscenza di base',
    'partial' => 'Parziale/Deposito',
    'partial_remaining' => ':partial di :balance',
    'more_fields' => 'Più campi',
    'less_fields' => 'Meno campi',
    'client_name' => 'Nome Cliente',
    'pdf_settings' => 'Preferenze PDF',
    'product_settings' => 'Preferenze Prodotti',
    'auto_wrap' => 'Linea a capo automaticamente',
    'duplicate_post' => 'Attenzione: la pagina precedente è stata inviata due volte. Il secondo invio è stato ignorato.',
    'view_documentation' => 'Visualizza documentazione',
    'app_title' => 'Fatturazione Online Open-Source',
    'app_description' => 'Invoice Ninja è gratuito, rappresenta una soluzione Open-source per la fatturazione e i pagamenti dei clienti. Con Invoice Ninja, puoi creare ed inviare bellissime fatture da qualsiasi device connesso al web. I tuoi clienti possono stampare le tue fatture, scaricarle come file pdf ed anche pagartele online con le funzionalità interne al sistema.',
    'rows' => 'righe',
    'www' => 'www',
    'logo' => 'Logo',
    'subdomain' => 'Sottodominio',
    'provide_name_or_email' => 'Per favore inserisci un nome o una email',
    'charts_and_reports' => 'Grafici e Report',
    'chart' => 'Grafico',
    'report' => 'Report',
    'group_by' => 'Raggruppa per',
    'paid' => 'Pagata',
    'enable_report' => 'Rapporto',
    'enable_chart' => 'Grafico',
    'totals' => 'Totali',
    'run' => 'Esegui',
    'export' => 'Esporta',
    'documentation' => 'Documentazione',
    'zapier' => 'Zapier',
    'recurring' => 'Ricorrenti',
    'last_invoice_sent' => 'Ultima fattura inviata :date',
    'processed_updates' => 'Aggiornamento completato con successo',
    'tasks' => 'Attività',
    'new_task' => 'Nuova Attività',
    'start_time' => 'Tempo di inizio',
    'created_task' => 'Attività creata con successo',
    'updated_task' => 'Attività aggiornata con successo',
    'edit_task' => 'Modifica l\'attività',
    'clone_task' => 'Clona l\'attività',
    'archive_task' => 'Archivia l\'attività',
    'restore_task' => 'Ripristina l\'attività',
    'delete_task' => 'Cancella l\'attività',
    'stop_task' => 'Ferma l\'attività',
    'time' => 'Tempo',
    'start' => 'Inizia',
    'stop' => 'Ferma',
    'now' => 'Adesso',
    'timer' => 'Timer',
    'manual' => 'Manuale',
    'date_and_time' => 'Data e ora',
    'second' => 'Secondo',
    'seconds' => 'Secondi',
    'minute' => 'Minuto',
    'minutes' => 'Minuti',
    'hour' => 'Ora',
    'hours' => 'Ore',
    'task_details' => 'Dettagli dell\'attività',
    'duration' => 'Durata',
    'time_log' => 'Log temporale',
    'end_time' => 'Tempo di fine',
    'end' => 'Fine',
    'invoiced' => 'Fatturato',
    'logged' => 'Registrato',
    'running' => 'In corso',
    'task_error_multiple_clients' => 'Le attività non possono appartenere a clienti diversi',
    'task_error_running' => 'Si prega di fermare prima l\'attività',
    'task_error_invoiced' => 'Le attività sono già state fatturate',
    'restored_task' => 'Attività ripristinata con successo',
    'archived_task' => 'Attività archiviata con successo',
    'archived_tasks' => ':count attività archiviate correttamente',
    'deleted_task' => 'Attività cancellata con successo',
    'deleted_tasks' => ':count attività eliminate correttamente',
    'create_task' => 'Crea un\'attività',
    'stopped_task' => 'Attività arrestata con successo',
    'invoice_task' => 'Fattura l\'attività',
    'invoice_labels' => 'Etichette Fattura',
    'prefix' => 'Prefisso',
    'counter' => 'Contatore',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link per iscriversi a Dwolla',
    'partial_value' => 'Deve essere maggiore di zero ed inferiore al totale',
    'more_actions' => 'Altre Azioni',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Aggiorna Ora!',
    'pro_plan_feature1' => 'Crea clienti illimitati',
    'pro_plan_feature2' => 'Accesso a 10 bellissimi design di fatture',
    'pro_plan_feature3' => 'URL Personalizzato - "IlTuoMarchio.InvoiceNinja.com"',
    'pro_plan_feature4' => 'Rimuovi "Created by Invoice Ninja"',
    'pro_plan_feature5' => 'Accesso multiutente e tracciamento delle attività',
    'pro_plan_feature6' => 'Crea preventivi e fatture proforma',
    'pro_plan_feature7' => 'Personalizza il titolo e la numerazione delle fatture',
    'pro_plan_feature8' => 'Opzione per allegare PDF alle e-mail del cliente',
    'resume' => 'Riprendi',
    'break_duration' => 'Interrompi',
    'edit_details' => 'Modifica dettagli',
    'work' => 'Work',
    'timezone_unset' => 'Per favore :link per impostare la tua timezone',
    'click_here' => 'clicca qui',
    'email_receipt' => 'Invia ricevuta di pagamento al cliente',
    'created_payment_emailed_client' => 'Pagamento creato con successo ed inviato al cliente',
    'add_company' => 'Aggiungi azienda',
    'untitled' => 'Senza titolo',
    'new_company' => 'Nuova azienda',
    'associated_accounts' => 'Account collegato con successo',
    'unlinked_account' => 'Account scollegato con successo',
    'login' => 'Login',
    'or' => 'o',
    'email_error' => 'Si è verificato un problema durante l\'invio dell\'email',
    'confirm_recurring_timing' => 'Nota: le e-mail vengono inviate all\'inizio dell\'ora.',
    'confirm_recurring_timing_not_sent' => 'Nota: le fatture vengono create all\'inizio dell\'ora.',
    'payment_terms_help' => 'Imposta la <b>scadenza fattura</b>predefinita',
    'unlink_account' => 'Scollega account',
    'unlink' => 'Scollega',
    'show_address' => 'Mostra indirizzo',
    'show_address_help' => 'Richiedere al cliente di fornire il proprio indirizzo di fatturazione',
    'update_address' => 'Aggiorna indirizzo',
    'update_address_help' => 'Aggiorna l\'indirizzo del cliente con i dettagli forniti',
    'times' => 'Tempi',
    'set_now' => 'Imposta a ora',
    'dark_mode' => 'Modalità scura',
    'dark_mode_help' => 'Usa uno sfondo scuro per le barre laterali',
    'add_to_invoice' => 'Aggiungi alla fattura :invoice',
    'create_new_invoice' => 'Crea nuova fattura',
    'task_errors' => 'Si prega di correggere eventuali tempi di sovrapposizione',
    'from' => 'Da',
    'to' => 'a',
    'font_size' => 'Dimensione Font',
    'primary_color' => 'Colore primario',
    'secondary_color' => 'Colore secondario',
    'customize_design' => 'Personalizza stile',
    'content' => 'Contenuto',
    'styles' => 'Stili',
    'defaults' => 'Predefiniti',
    'margins' => 'Margini',
    'header' => 'Header',
    'footer' => 'Piè di Pagina',
    'custom' => 'Personalizzato',
    'invoice_to' => 'Fattura a',
    'invoice_no' => 'Fattura N.',
    'quote_no' => 'Preventivo N°',
    'recent_payments' => 'Pagamenti recenti',
    'outstanding' => 'Inevase',
    'manage_companies' => 'Gestisci aziende',
    'total_revenue' => 'Ricavo totale',
    'current_user' => 'Current User',
    'new_recurring_invoice' => 'Nuova Fattura Ricorrente',
    'recurring_invoice' => 'Fattura Ricorrente',
    'new_recurring_quote' => 'Nuovo Preventivo Ricorrente',
    'recurring_quote' => 'Preventivo Ricorrente',
    'recurring_too_soon' => 'È troppo presto per creare la prossima fattura ricorrente, è prevista per :date',
    'created_by_invoice' => 'Creato da :invoice',
    'primary_user' => 'Utente principale',
    'help' => 'Aiuto',
    'customize_help' => '<p>Usiamo :pdfmake_link per definire gli stili delle fatture in modo dichiarativo. Il link pdfmake :playground_link fornisce un ottimo modo per vedere la libreria in azione.</p>
<p>Se hai bisogno di aiuto per capire qualcosa, scrivi una domanda al nostro :forum_link con il design che stai usando.</p>',
    'playground' => 'playground',
    'support_forum' => 'Forum di supporto',
    'invoice_due_date' => 'Scadenza fattura',
    'quote_due_date' => 'Valido fino a',
    'valid_until' => 'Valido fino a',
    'reset_terms' => 'Resetta termini',
    'reset_footer' => 'Ripristina Piè di Pagina',
    'invoice_sent' => ' :count fattura inviata',
    'invoices_sent' => ' :count fatture inviate',
    'status_draft' => 'Bozza',
    'status_sent' => 'Spedito',
    'status_viewed' => 'Visto',
    'status_partial' => 'Parziale',
    'status_paid' => 'Pagato',
    'status_unpaid' => 'Non pagato',
    'status_all' => 'Tutti',
    'show_line_item_tax' => 'Mostra <b>imposte dell\'articolo sulla riga stessa</b> ',
    'iframe_url' => 'Website',
    'iframe_url_help1' => 'Copia il seguente codice in una pagina del tuo sito.',
    'iframe_url_help2' => 'È possibile verificare la funzionalità facendo clic su "Visualizza come destinatario" per una fattura.',
    'auto_bill' => 'Fatturazione automatica',
    'military_time' => '24 ore',
    'last_sent' => 'Ultimo inviato',
    'reminder_emails' => 'Email di promemoria',
    'quote_reminder_emails' => 'Email Promemoria Preventivo',
    'templates_and_reminders' => 'Modelli & Promemoria',
    'subject' => 'Oggetto',
    'body' => 'Corpo',
    'first_reminder' => 'Primo Promemoria',
    'second_reminder' => 'Secondo Promemoria',
    'third_reminder' => 'Terzo Promemoria',
    'num_days_reminder' => 'Giorni dopo la scadenza',
    'reminder_subject' => 'Promemoria: Fattura n° :invoice da :account',
    'reset' => 'Reset',
    'invoice_not_found' => 'La fattura richiesta non è disponibile',
    'referral_program' => 'Referral Program',
    'referral_code' => 'Referral Code',
    'last_sent_on' => 'Ultimo invio il :date',
    'page_expire' => 'Questa pagina scadrà presto, :click_here per continuare',
    'upcoming_quotes' => 'Preventivi in scadenza',
    'expired_quotes' => 'Preventivi Scaduti',
    'sign_up_using' => 'Registrati usando',
    'invalid_credentials' => 'Queste credenziali non hanno trovato corrispondenza',
    'show_all_options' => 'Mostra tutte le opzioni',
    'user_details' => 'Dettagli Utente',
    'oneclick_login' => 'Account connessi',
    'disable' => 'Disabilita',
    'invoice_quote_number' => 'Numerazione Fatture e Preventivi',
    'invoice_charges' => 'Supplementi fattura',
    'notification_invoice_bounced' => 'Non siamo riusciti ad inviare la fattura :invoice a :contact',
    'notification_invoice_bounced_subject' => 'Impossibile recapitare la fattura n° :invoice',
    'notification_quote_bounced' => 'Non siamo riusciti ad inviare il preventivo :invoice a :contact',
    'notification_quote_bounced_subject' => 'Impossibile recapitare il preventivo  :invoice',
    'custom_invoice_link' => 'Link fattura personalizzata',
    'total_invoiced' => 'Fatturato totale',
    'open_balance' => 'Da saldare',
    'verify_email' => 'Per favore, clicca sul link nella mail di conferma per verificare il tuo indirizzo email.',
    'basic_settings' => 'Impostazioni Base',
    'pro' => 'Pro',
    'gateways' => 'Piattaforme di pagamento',
    'next_send_on' => 'Invia il prossimo il: :date',
    'no_longer_running' => 'Questa fattura non è pianificata per essere emessa',
    'general_settings' => 'Impostazioni generali',
    'customize' => 'Personalizza',
    'oneclick_login_help' => 'Connetti un account per entrare senza password',
    'referral_code_help' => 'Guadagna condividendo la nostra applicazione online',
    'enable_with_stripe' => 'Abilita | Richiede Stripe',
    'tax_settings' => 'Impostazioni tasse',
    'create_tax_rate' => 'Aggiungi aliquota fiscale',
    'updated_tax_rate' => 'Aliquota fiscale aggiornata',
    'created_tax_rate' => 'Aliquota fiscale creata',
    'edit_tax_rate' => 'Modifica aliquota fiscale',
    'archive_tax_rate' => 'Archivia aliquota fiscale',
    'archived_tax_rate' => 'Successfully archived the tax rate',
    'default_tax_rate_id' => 'Tariffa Predefinita',
    'tax_rate' => 'Tax Rate',
    'recurring_hour' => 'Ora Ricorrente',
    'pattern' => 'Pattern',
    'pattern_help_title' => 'Aiuto Pattern',
    'pattern_help_1' => 'Crea una numerazione personalizzata tramite un modello',
    'pattern_help_2' => 'Available variables:',
    'pattern_help_3' => 'For example, :example would be converted to :value',
    'see_options' => 'See options',
    'invoice_counter' => 'Invoice Counter',
    'quote_counter' => 'Quote Counter',
    'type' => 'Tipo',
    'activity_1' => ':user ha creato il cliente :client',
    'activity_2' => ':user ha archiviato il cliente :client',
    'activity_3' => ':user ha cancellato il cliente :client',
    'activity_4' => ':user ha creato la fattura :invoice',
    'activity_5' => ':user ha aggiornato la fattura :invoice',
    'activity_6' => ':user ha inviato per email la fattura :invoice per:client a :contact',
    'activity_7' => ':contact ha visualizzato la fattura :invoice per :client',
    'activity_8' => ':user ha archiviato la fattura :invoice',
    'activity_9' => ':user ha cancellato la fattura :invoice',
    'activity_10' => ':contact ha registrato il pagamento :payment di :payment_amount sulla fattura :invoice per :client',
    'activity_11' => ':user ha aggiornato il pagamento :payment',
    'activity_12' => ':user ha archiviato il pagamento :payment',
    'activity_13' => ':user ha cancellato il pagamento :payment',
    'activity_14' => ':user entered :credit credit',
    'activity_15' => ':user updated :credit credit',
    'activity_16' => ':user archived :credit credit',
    'activity_17' => ':user deleted :credit credit',
    'activity_18' => ':user created quote :quote',
    'activity_19' => ':user updated quote :quote',
    'activity_20' => ':user ha inviato per email il preventivo :quote per :client a :contact',
    'activity_21' => ':contact ha visto il preventivo :quote',
    'activity_22' => ':user archived quote :quote',
    'activity_23' => ':user deleted quote :quote',
    'activity_24' => ':user restored quote :quote',
    'activity_25' => ':user restored invoice :invoice',
    'activity_26' => ':user ha ripristinato il cliente :client',
    'activity_27' => ':user restored payment :payment',
    'activity_28' => ':user restored :credit credit',
    'activity_29' => ':contact ha approvato il preventivo :quote per :client',
    'activity_30' => 'L\'utente :user ha creato il fornitore :vendor',
    'activity_31' => 'L\'utente :user ha archiviato il fornitore :vendor',
    'activity_32' => 'L\'utente :user ha eliminato il fornitore :vendor',
    'activity_33' => 'L\'utente :user ha ripristinato il fornitore :vendor',
    'activity_34' => 'L\'utente :user ha creato la spesa :expense',
    'activity_35' => 'L\'utente :user ha archiviato la spesa :expense',
    'activity_36' => 'L\'utente :user ha eliminato la spesa :expense',
    'activity_37' => 'L\'utente :user ha ripristinato la spesa :expense',
    'activity_42' => 'L\'utente :user ha creato l\'attività :task',
    'activity_43' => 'L\'utente :user ha aggiornato l\'attività :task',
    'activity_44' => 'L\'utente :user ha archiviato l\'attività :task',
    'activity_45' => 'L\'utente :user ha eliminato l\'attività :task',
    'activity_46' => 'L\'utente :user ha ripristinato l\'attività :task',
    'activity_47' => 'L\'utente :user ha aggiornato la spesa :expense',
    'activity_48' => ':user ha aggiornato il ticket :ticket',
    'activity_49' => ':user ha chiuso il ticket :ticket',
    'activity_50' => ':user ha unito il ticket :ticket',
    'activity_51' => ':user ha separato il ticket :ticket',
    'activity_52' => ':contact ha aperto il ticket :ticket',
    'activity_53' => ':contact ha riaperto il ticket :ticket',
    'activity_54' => ':user ha riaperto il ticket :ticket',
    'activity_55' => ':contact ha risposto al ticket :ticket',
    'activity_56' => ':user ha visualizzato il ticket :ticket',

    'payment' => 'Pagamento',
    'system' => 'System',
    'signature' => 'Email Signature',
    'default_messages' => 'Default Messages',
    'quote_terms' => 'Termini del preventivo',
    'default_quote_terms' => 'Termini di default del preventivo',
    'default_invoice_terms' => 'Salva termini come predefiniti',
    'default_invoice_footer' => 'Imposta il piè di pagina predefinito per le fatture',
    'quote_footer' => 'Piè di Pagina Preventivi',
    'free' => 'Free',
    'quote_is_approved' => 'Approvato con successo',
    'apply_credit' => 'Apply Credit',
    'system_settings' => 'Impostazioni di Sistema',
    'archive_token' => 'Archive Token',
    'archived_token' => 'Successfully archived token',
    'archive_user' => 'Archive User',
    'archived_user' => 'Successfully archived user',
    'archive_account_gateway' => 'Elimina Piattaforma',
    'archived_account_gateway' => 'Piattaforma archiviata con successo',
    'archive_recurring_invoice' => 'Archivia Fattura Ricorrente',
    'archived_recurring_invoice' => 'Fattura ricorrente archiviata con successo',
    'delete_recurring_invoice' => 'Elimina Fattura Ricorrente',
    'deleted_recurring_invoice' => 'Fattura ricorrente eliminata con successo',
    'restore_recurring_invoice' => 'Ripristina Fattura Ricorrente',
    'restored_recurring_invoice' => 'Fattura ricorrente ripristinata con successo',
    'archive_recurring_quote' => 'Archivia Preventivi Ricorrente',
    'archived_recurring_quote' => 'Preventivo ricorrente archiviato con successo',
    'delete_recurring_quote' => 'Elimina Preventivo Ricorrente',
    'deleted_recurring_quote' => 'Preventivo ricorrente eliminato con successo',
    'restore_recurring_quote' => 'Ripristina Preventivo Ricorrente',
    'restored_recurring_quote' => 'Preventivo ricorrente ripristinato con successo',
    'archived' => 'Archived',
    'untitled_account' => 'Azienda senza nome',
    'before' => 'Before',
    'after' => 'After',
    'reset_terms_help' => 'Resetta ai termini di servizio di default',
    'reset_footer_help' => 'Ripristina al Piè di Pagina predefinito',
    'export_data' => 'Export Data',
    'user' => 'User',
    'country' => 'Paese',
    'include' => 'Include',
    'logo_too_large' => 'Il tuo logo è :size, per una migliore prestazione del PDF ti suggeriamo di caricare un file immagine inferiore a 200 KB',
    'import_freshbooks' => 'Import From FreshBooks',
    'import_data' => 'Import Data',
    'source' => 'Source',
    'csv' => 'CSV',
    'client_file' => 'File Cliente',
    'invoice_file' => 'Invoice File',
    'task_file' => 'Task File',
    'no_mapper' => 'Nessuna mappatura valida per il file',
    'invalid_csv_header' => 'Intestazione CSV non valida',
    'client_portal' => 'Portale Clienti',
    'admin' => 'Admin',
    'disabled' => 'Disabled',
    'show_archived_users' => 'Show archived users',
    'notes' => 'Note',
    'invoice_will_create' => 'la fattura sarà creata',
    'invoices_will_create' => 'invoices will be created',
    'failed_to_import' => 'I seguenti record non sono stati importati; esistono già o mancano i campi obbligatori.',
    'publishable_key' => 'Publishable Key',
    'secret_key' => 'Secret Key',
    'missing_publishable_key' => 'Set your Stripe publishable key for an improved checkout process',
    'email_design' => 'Email Design',
    'due_by' => 'Scadenza :date',
    'enable_email_markup' => 'Enable Markup',
    'enable_email_markup_help' => 'Rendi più facile per i tuoi clienti pagarti aggiungendo il markup schema.org alle tue e-mail.',
    'template_help_title' => 'Aiuto Modelli',
    'template_help_1' => 'Available variables:',
    'email_design_id' => 'Email Style',
    'email_design_help' => 'Rendi le tue email più professionali con i layout HTML.',
    'plain' => 'Plain',
    'light' => 'Light',
    'dark' => 'Dark',
    'industry_help' => 'Utilizzato per fornire confronti con le medie di aziende di dimensioni e settore simili.',
    'subdomain_help' => 'Imposta il sottodominio o visualizza la fattura sul tuo sito web.',
    'website_help' => 'Visualizza la fattura in un iFrame sul tuo sito web',
    'invoice_number_help' => 'Specifica un prefisso o usa un modello personalizzato per generare i numeri delle fatture dinamicamente.',
    'quote_number_help' => 'Specifica un prefisso o usa un modello personalizzato per generare i numeri dei preventivi dinamicamente.',
    'custom_client_fields_helps' => 'Aggiungi un campo quando crei un cliente e opzionalmente visualizzalo assieme al suo valore nel PDF.',
    'custom_account_fields_helps' => 'Aggiungi un\'etichetta e un valore alla sezione dei dettagli dell\'azienda nel PDF.',
    'custom_invoice_fields_helps' => 'Aggiungi un campo quando crei una fattura e opzionalmente visualizzalo assieme al suo valore nel PDF.',
    'custom_invoice_charges_helps' => 'Aggiungi un campo quando crei una fattura e includi il costo nel subtotale.',
    'token_expired' => 'Flusso di validazione scaduto. Si prega di riprovare.',
    'invoice_link' => 'Invoice Link',
    'button_confirmation_message' => 'Click to confirm your email address.',
    'confirm' => 'Confirm',
    'email_preferences' => 'Email Preferences',
    'created_invoices' => 'Successfully created :count invoice(s)',
    'next_invoice_number' => 'Il prossimo numero per le fatture è :number.',
    'next_quote_number' => 'Il prossimo numero per i preventivi è :number.',
    'days_before' => 'giorni prima di',
    'days_after' => 'giorni dopo di',
    'field_due_date' => 'data scadenza',
    'field_invoice_date' => 'invoice date',
    'schedule' => 'Schedule',
    'email_designs' => 'Email Designs',
    'assigned_when_sent' => 'Assigned when sent',
    'white_label_purchase_link' => 'Purchase a white label license',
    'expense' => 'Spesa',
    'expenses' => 'Spese',
    'new_expense' => 'Inserisci spesa',
    'enter_expense' => 'Inserisci Spesa',
    'vendors' => 'Fornitori',
    'new_vendor' => 'Nuovo Fornitore',
    'payment_terms_net' => 'Netto',
    'vendor' => 'Fornitore',
    'edit_vendor' => 'Modifica Fornitore',
    'archive_vendor' => 'Archivia Fornitore',
    'delete_vendor' => 'Cancella Fornitore ',
    'view_vendor' => 'Vedi Fornitore',
    'deleted_expense' => 'Successfully deleted expense',
    'archived_expense' => 'Successfully archived expense',
    'deleted_expenses' => 'Successfully deleted expenses',
    'archived_expenses' => 'Successfully archived expenses',
    'expense_amount' => 'Importo Spesa',
    'expense_balance' => 'Bilancio Spesa',
    'expense_date' => 'Data Spesa',
    'expense_should_be_invoiced' => 'Questa spesa deve essere fatturata?',
    'public_notes' => 'Note Pubbliche (Descrizione in fattura)',
    'invoice_amount' => 'Importo Fattura',
    'exchange_rate' => 'Tasso di Cambio',
    'yes' => 'Si',
    'no' => 'No',
    'should_be_invoiced' => 'Deve essere fatturata',
    'view_expense' => 'Vedi spesa # :expense',
    'edit_expense' => 'Modifica Spesa',
    'archive_expense' => 'Archivia Spesa',
    'delete_expense' => 'Cancella Spesa',
    'view_expense_num' => 'Spesa # :expense',
    'updated_expense' => 'Spesa aggiornata con successo',
    'created_expense' => 'Spesa creata con successo',
    'enter_expense' => 'Inserisci Spesa',
    'view' => 'Vedi',
    'restore_expense' => 'Ripristina Spesa',
    'invoice_expense' => 'Fattura Spesa',
    'expense_error_multiple_clients' => 'Le spese non possono appartenere a clienti differenti',
    'expense_error_invoiced' => 'La spesa è stata già fatturata',
    'convert_currency' => 'Converti valuta',
    'num_days' => 'Numero di Giorni',
    'create_payment_term' => 'Crea termini di pagamento',
    'edit_payment_terms' => 'Modifica termini di pagamento',
    'edit_payment_term' => 'Modifica termini di pagamento',
    'archive_payment_term' => 'Archivia termini di pagamento',
    'recurring_due_dates' => 'Data Scadenza Fatture Ricorrenti',
    'recurring_due_date_help' => '<p>Automatically sets a due date for the invoice.</p>
        <p>Invoices on a monthly or yearly cycle set to be due on or before the day they are created will be due the next month. Invoices set to be due on the 29th or 30th in months that don\'t have that day will be due the last day of the month.</p>
        <p>Invoices on a weekly cycle set to be due on the day of the week they are created will be due the next week.</p>
        <p>For example:</p>
        <ul>
          <li>Today is the 15th, due date is 1st of the month. The due date should likely be the 1st of the next month.</li>
          <li>Today is the 15th, due date is the last day of the month. The due date will be the last day of the this month.
</li>
          <li>Today is the 15th, due date is the 15th day of the month. The due date will be the 15th day of <strong>next</strong> month.
</li>
          <li>Today is the Friday, due date is the 1st Friday after. The due date will be next Friday, not today.
</li>
        </ul>',
    'due' => 'Da pagare',
    'next_due_on' => 'Prossima scadenza: :date',
    'use_client_terms' => 'Usa i termini del cliente',
    'day_of_month' => ':ordinal giorno del mese',
    'last_day_of_month' => 'L\'ultimo giorno del mese',
    'day_of_week_after' => ':ordinal :day dopo',
    'sunday' => 'Domenica',
    'monday' => 'Lunedì',
    'tuesday' => 'Martedì',
    'wednesday' => 'Mercoledì',
    'thursday' => 'Giovedì',
    'friday' => 'Venerdì',
    'saturday' => 'Sabato',
    'header_font_id' => 'Header Font',
    'body_font_id' => 'Body Font',
    'color_font_help' => 'Nota: il colore principale e i caratteri vengono anche utilizzati nel portale del cliente e nei progetti di e-mail personalizzati.',
    'live_preview' => 'Anteprima Live',
    'invalid_mail_config' => 'Impossibile inviare e-mail, controlla che le impostazioni della posta siano corrette.',
    'invoice_message_button' => 'Per visualizzare la fattura :amount, clicca il bottone qui sotto.',
    'quote_message_button' => 'Per visualizzare il preventivo per :amount, fare clic sul pulsante qui sotto.',
    'payment_message_button' => 'Grazie per il pagamento di :amount.',
    'payment_type_direct_debit' => 'Direct Debit',
    'bank_accounts' => 'Conti corrente',
    'add_bank_account' => 'Nuovo conto corrente',
    'setup_account' => 'Impostazione Account',
    'import_expenses' => 'Importa Spese',
    'bank_id' => 'Banca',
    'integration_type' => 'Tipo di integrazione',
    'updated_bank_account' => 'Conto bancario aggiornato con successo',
    'edit_bank_account' => 'Modifica conto bancario',
    'archive_bank_account' => 'Archivio conto bancario',
    'archived_bank_account' => 'Conto bancario correttamente archiviato',
    'created_bank_account' => 'Conto bancario creato con successo',
    'validate_bank_account' => 'Convalida il conto bancario',
    'bank_password_help' => 'Nota: la tua password viene trasmessa in modo sicuro e mai memorizzata sui nostri server.',
    'bank_password_warning' => 'Attenzione: la tua password può essere trasmessa in testo normale, prendi in considerazione l\'abilitazione di HTTPS.',
    'username' => 'Username',
    'account_number' => 'Numero account',
    'account_name' => 'Nome utente',
    'bank_account_error' => 'Impossibile ottenere i dettagli dell\'account, per favore controllare le proprie credenziali.',
    'status_approved' => 'Approvato',
    'quote_settings' => 'Impostazioni preventivo',
    'auto_convert_quote' => 'Conversione automatica',
    'auto_convert_quote_help' => 'Converti automaticamente un preventivo in una fattura se approvato da un cliente.',
    'validate' => 'Convalida',
    'info' => 'Info',
    'imported_expenses' => 'Creato con successo :count_vendors fornitore(i) e :count_expenses spesa(e)',
    'iframe_url_help3' => 'Nota: se prevedi di accettare i dettagli delle carte di credito, ti consigliamo vivamente di abilitare HTTPS sul tuo sito.',
    'expense_error_multiple_currencies' => 'Le spese non possono avere valute diverse.',
    'expense_error_mismatch_currencies' => 'La valuta del cliente non corrisponde alla valuta di spesa.',
    'trello_roadmap' => 'Trello Roadmap',
    'header_footer' => 'Intestazione/Piè di Pagina',
    'first_page' => 'Prima pagina',
    'all_pages' => 'Tutte le pagine',
    'last_page' => 'Ultima pagina',
    'all_pages_header' => 'Mostra l\'Intestazione nel',
    'all_pages_footer' => 'Visualizza Piè di Pagina nel',
    'invoice_currency' => 'Valuta fattura',
    'enable_https' => 'Si consiglia vivamente di utilizzare HTTPS per accettare i dettagli della carta di credito online.',
    'quote_issued_to' => 'Preventivo emesso a',
    'show_currency_code' => 'Codice Valuta',
    'free_year_message' => 'Il tuo account è stato aggiornato al piano pro per un anno senza alcun costo.',
    'trial_message' => 'Il tuo account riceverà una prova gratuita di due settimane del nostro piano PRO.',
    'trial_footer' => 'La tua prova gratuita del piano PRO dura altri :count giorni,  :link per eseguire l\'aggiornamento ora',
    'trial_footer_last_day' => 'Questo è l\'ultimo giorno di prova gratuita del tuo piano PRO, :link per aggiornarlo.',
    'trial_call_to_action' => 'Start Free Trial',
    'trial_success' => 'Successfully enabled two week free pro plan trial',
    'overdue' => 'Scaduto',


    'white_label_text' => 'Acquista una licenza di un anno al prezzo di $:price per rimuovere il logo di Invoice Ninja dalle fatture e dal portale clienti.',
    'user_email_footer' => 'Per modificare le impostazioni di notifiche via email per favore accedi a: :link',
    'reset_password_footer' => 'Se non sei stato tu a voler resettare la password per favore invia un\'email di assistenza a: :email',
    'limit_users' => 'Sorry, this will exceed the limit of :limit users',
    'more_designs_self_host_header' => 'Get 6 more invoice designs for just $:price',
    'old_browser' => 'Per favore usa un :link',
    'newer_browser' => 'browser più recente',
    'white_label_custom_css' => ':link for $:price to enable custom styling and help support our project.',
    'bank_accounts_help' => 'Connetti un conto bancario per importare le spese e creare i fornitori automaticamente. Supporta American Express e :link',
    'us_banks' => 'Più di 400 banche negli Stati Uniti',

    'pro_plan_remove_logo' => ':link per rimuovere il logo di Invoice Ninja aderendo al programma pro',
    'pro_plan_remove_logo_link' => 'Clicca qui',
    'invitation_status_sent' => 'Inviato',
    'invitation_status_opened' => 'Aperto',
    'invitation_status_viewed' => 'Visto',
    'email_error_inactive_client' => 'Emails can not be sent to inactive clients',
    'email_error_inactive_contact' => 'Emails can not be sent to inactive contacts',
    'email_error_inactive_invoice' => 'Emails can not be sent to inactive invoices',
    'email_error_inactive_proposal' => 'Non si possono inviare email a proposte inattive.',
    'email_error_user_unregistered' => 'Please register your account to send emails',
    'email_error_user_unconfirmed' => 'Please confirm your account to send emails',
    'email_error_invalid_contact_email' => 'E-mail di contatto non valida',

    'navigation' => 'Navigation',
    'list_invoices' => 'List Invoices',
    'list_clients' => 'Elenco Clienti',
    'list_quotes' => 'List Quotes',
    'list_tasks' => 'Lista le attività',
    'list_expenses' => 'Lista Spese',
    'list_recurring_invoices' => 'Elenca Fatture Ricorrenti',
    'list_payments' => 'Elenca pagamenti',
    'list_credits' => 'List Credits',
    'tax_name' => 'Nome Tassa',
    'report_settings' => 'Impostazioni Report',
    'search_hotkey' => 'shortcut is /',

    'new_user' => 'New User',
    'new_product' => 'Nuovo Prodotto',
    'new_tax_rate' => 'New Tax Rate',
    'invoiced_amount' => 'Invoiced Amount',
    'invoice_item_fields' => 'Campi articoli fattura',
    'custom_invoice_item_fields_help' => 'Aggiungi un campo quando crei un articolo fattura e opzionalmente visualizzalo assieme al suo valore nel PDF.',
    'recurring_invoice_number' => 'Numero ricorrente',
    'recurring_invoice_number_prefix_help' => 'Specifica un prefisso da aggiungere al numero di fattura per fatture ricorrenti.',

    // Client Passwords
    'enable_portal_password' => 'Fatture Protette da Password',
    'enable_portal_password_help' => 'Permette di impostare una password per ogni contatto. Se una password è impostata, al contatto sarà richiesto di inserire una password prima di visualizzare le fatture.',
    'send_portal_password' => 'Genera Automaticamente',
    'send_portal_password_help' => 'Se non è stata impostata alcuna password, ne verrà generata ed inviata una con la prima fattura.',

    'expired' => 'Scaduto',
    'invalid_card_number' => 'Il numero della carta di credito non è valido.',
    'invalid_expiry' => 'La data di scadenza non è valida.',
    'invalid_cvv' => 'Il CVV non è valido.',
    'cost' => 'Cost',
    'create_invoice_for_sample' => 'Note: create your first invoice to see a preview here.',

    // User Permissions
    'owner' => 'Owner',
    'administrator' => 'Administrator',
    'administrator_help' => 'Permettere all\'utente di gestire gli utenti, cambiare le impostazioni e modificare tutti i record',
    'user_create_all' => 'Create clients, invoices, etc.',
    'user_view_all' => 'View all clients, invoices, etc.',
    'user_edit_all' => 'Edit all clients, invoices, etc.',
    'gateway_help_20' => ':link per iscriverti a Sage Pay.',
    'gateway_help_21' => ':link per iscriverti a Sage Pay.',
    'partial_due' => 'Da versare (parziale)',
    'restore_vendor' => 'Ripristina Fornitore',
    'restored_vendor' => 'Successfully restored vendor',
    'restored_expense' => 'Successfully restored expense',
    'permissions' => 'Permissions',
    'create_all_help' => 'Allow user to create and modify records',
    'view_all_help' => 'Allow user to view records they didn\'t create',
    'edit_all_help' => 'Allow user to modify records they didn\'t create',
    'view_payment' => 'Visualizza pagamento',

    'january' => 'Gennaio',
    'february' => 'Febbraio',
    'march' => 'Marzo',
    'april' => 'Aprile',
    'may' => 'Maggio',
    'june' => 'Giugno',
    'july' => 'Luglio',
    'august' => 'Agosto',
    'september' => 'Settembre',
    'october' => 'Ottobre',
    'november' => 'Novembre',
    'december' => 'Dicembre',

    // Documents
    'documents_header' => 'Documenti:',
    'email_documents_header' => 'Documenti:',
    'email_documents_example_1' => 'Widgets Receipt.pdf',
    'email_documents_example_2' => 'Final Deliverable.zip',
    'quote_documents' => 'Documenti Preventivi',
    'invoice_documents' => 'Documenti Fatture',
    'expense_documents' => 'Documenti di Spesa',
    'invoice_embed_documents' => 'Embed Documents',
    'invoice_embed_documents_help' => 'Includi immagini allegate alla fattura.',
    'document_email_attachment' => 'Allega Documenti',
    'ubl_email_attachment' => 'Allega UBL',
    'download_documents' => 'Scarica Documenti (:size)',
    'documents_from_expenses' => 'Da spese:',
    'dropzone_default_message' => 'Trascina file o clicca per caricare',
    'dropzone_default_message_disabled' => 'Upload disattivati',
    'dropzone_fallback_message' => 'Your browser does not support drag\'n\'drop file uploads.',
    'dropzone_fallback_text' => 'Please use the fallback form below to upload your files like in the olden days.',
    'dropzone_file_too_big' => 'File troppo grande ({{filesize}}MiB). Dimensione massima: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'You can\'t upload files of this type.',
    'dropzone_response_error' => 'Server responded with {{statusCode}} code.',
    'dropzone_cancel_upload' => 'Cancella caricamento',
    'dropzone_cancel_upload_confirmation' => 'Sei sicuro di voler annullare questo caricamento?',
    'dropzone_remove_file' => 'Remove file',
    'documents' => 'Documenti',
    'document_date' => 'Document Date',
    'document_size' => 'Dimensione',

    'enable_client_portal' => 'Portale Clienti',
    'enable_client_portal_help' => 'Mostra/nascondi il portale clienti.',
    'enable_client_portal_dashboard' => 'Pannello di Controllo',
    'enable_client_portal_dashboard_help' => 'Mostra/nascondi il Pannello di Controllo nel portale clienti.',

    // Plans
    'account_management' => 'Gestione Account',
    'plan_status' => 'Plan Status',

    'plan_upgrade' => 'Upgrade',
    'plan_change' => 'Change Plan',
    'pending_change_to' => 'Changes To',
    'plan_changes_to' => ':plan on :date',
    'plan_term_changes_to' => ':plan (:term) on :date',
    'cancel_plan_change' => 'Cancel Change',
    'plan' => 'Plan',
    'expires' => 'Scadenza',
    'renews' => 'Renews',
    'plan_expired' => ':plan Piano scaduto',
    'trial_expired' => ':plan Plan Trial Ended',
    'never' => 'Never',
    'plan_free' => 'Free',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Enterprise',
    'plan_white_label' => 'Self Hosted (White labeled)',
    'plan_free_self_hosted' => 'Self Hosted (Free)',
    'plan_trial' => 'Trial',
    'plan_term' => 'Term',
    'plan_term_monthly' => 'Monthly',
    'plan_term_yearly' => 'Yearly',
    'plan_term_month' => 'Month',
    'plan_term_year' => 'Year',
    'plan_price_monthly' => '$:price/Month',
    'plan_price_yearly' => '$:price/Year',
    'updated_plan' => 'Impostazioni piano aggiornate',
    'plan_paid' => 'Term Started',
    'plan_started' => 'Plan Started',
    'plan_expires' => 'Scadenza piano',

    'white_label_button' => 'White Label',

    'pro_plan_year_description' => 'One year enrollment in the Invoice Ninja Pro Plan.',
    'pro_plan_month_description' => 'One month enrollment in the Invoice Ninja Pro Plan.',
    'enterprise_plan_product' => 'Enterprise Plan',
    'enterprise_plan_year_description' => 'One year enrollment in the Invoice Ninja Enterprise Plan.',
    'enterprise_plan_month_description' => 'One month enrollment in the Invoice Ninja Enterprise Plan.',
    'plan_credit_product' => 'Credit',
    'plan_credit_description' => 'Credit for unused time',
    'plan_pending_monthly' => 'Will switch to monthly on :date',
    'plan_refunded' => 'A refund has been issued.',

    'live_preview' => 'Anteprima Live',
    'page_size' => 'Dimensione Pagina',
    'live_preview_disabled' => 'Live preview has been disabled to support selected font',
    'invoice_number_padding' => 'Padding',
    'preview' => 'Preview',
    'list_vendors' => 'Elenco Fornitori',
    'add_users_not_supported' => 'Upgrade to the Enterprise plan to add additional users to your account.',
    'enterprise_plan_features' => 'Il piano Enterprise aggiunge il supporto per più utenti e file allegati, :link per visualizzare l\'elenco completo delle funzionalità.',
    'return_to_app' => 'Ritorna all\'App',


    // Payment updates
    'refund_payment' => 'Rimborsa Pagamento',
    'refund_max' => 'Massimo:',
    'refund' => 'Rimborso',
    'are_you_sure_refund' => 'Rimborsare il pagamento selezionato?',
    'status_pending' => 'In attesa',
    'status_completed' => 'Completato',
    'status_failed' => 'Fallito',
    'status_partially_refunded' => 'Parzialmente Rimborsata',
    'status_partially_refunded_amount' => ':amount Rimborsato',
    'status_refunded' => 'Rimborsata',
    'status_voided' => 'Cancellata',
    'refunded_payment' => 'Pagamento Rimborsato',
    'activity_39' => ':user ha annullato un pagamento :payment da :payment_amount',
    'activity_40' => ':user ha rimborsato :adjustment di un pagamento :payment da :payment_amount',
    'card_expiration' => 'Scad:&nbsp:expires',

    'card_creditcardother' => 'Sconosciuto',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Cambio',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Accetta bonifici USA',
    'stripe_ach_help' => 'Il supporto per ACH deve essere abilitato anche in :link',
    'ach_disabled' => 'Un\'altra piattaforma è già configurata per addebito diretto',

    'plaid' => 'Plaid',
    'client_id' => 'Id Cliente',
    'secret' => 'Segreta',
    'public_key' => 'Chiave Pubblica',
    'plaid_optional' => '(opzionale)',
    'plaid_environment_help' => 'When a Stripe test key is given, Plaid\'s development environment (tartan) will be used.',
    'other_providers' => 'Altri Provider',
    'country_not_supported' => 'Il paese non è supportato',
    'invalid_routing_number' => 'Numero di avviamento non valido.',
    'invalid_account_number' => 'Il numero dell\'account non è valido',
    'account_number_mismatch' => 'Il numero di conto non è uguale a quello già fornito.',
    'missing_account_holder_type' => 'Prego selezionare un conto individuale o aziendale.',
    'missing_account_holder_name' => 'Prego fornire il nome dell\'intestatario del conto.',
    'routing_number' => 'Numero di Avviamento',
    'confirm_account_number' => 'Conferma il numero di conto.',
    'individual_account' => 'Account Individuale',
    'company_account' => 'Conto aziendale.',
    'account_holder_name' => 'Nome Proprietario Account',
    'add_account' => 'Aggiungi conto.',
    'payment_methods' => 'Metodi di Pagamento',
    'complete_verification' => 'Completa la Verifica',
    'verification_amount1' => 'Importo 1',
    'verification_amount2' => 'Importo 2',
    'payment_method_verified' => 'Verifica completata con successo',
    'verification_failed' => 'Verifica fallita',
    'remove_payment_method' => 'Rimuovi il metodo di pagamento',
    'confirm_remove_payment_method' => 'Sei sicuro di voler eliminare questo metodo di pagamento ?',
    'remove' => 'Elimina',
    'payment_method_removed' => 'Metodo di pagamento eliminato.',
    'bank_account_verification_help' => 'Abbiamo effettuato due depositi sul tuo conto con la descrizione "VERIFICATION". Questi depositi impiegheranno 1-2 giorni lavorativi perché tu li possa vedere. Per favore fornisci l\'importo qui sotto.',
    'bank_account_verification_next_steps' => 'Abbiamo effettuato due depositi sul tuo conto con la descrizione "VERIFICATION". Questi depositi impiegheranno 1-2 giorni lavorativi perché tu li possa vedere. Quando vedrai gli importi, torna nella pagina dei metodi di pagamento e seleziona "Complete Verification" vicino al tuo conto.',
    'unknown_bank' => 'Banca sconosciuta',
    'ach_verification_delay_help' => 'Dopo aver completato la verifica sarai in grado di usare l\'account. La verifica di solito ci impiega 1-2 giorni lavorativi.',
    'add_credit_card' => 'Aggiungi una carta di credito.',
    'payment_method_added' => 'Metodo di pagamento aggiunto.',
    'use_for_auto_bill' => 'Usa per l\'autofattura',
    'used_for_auto_bill' => 'Metodo di Pagamento per autofattura',
    'payment_method_set_as_default' => 'Imposta metodo di pagamento per autofattura',
    'activity_41' => 'pagamento di :payment_amount (:payment) fallito',
    'webhook_url' => 'Webhook URL',
    'stripe_webhook_help' => 'You must :link.',
    'stripe_webhook_help_link_text' => 'aggiungi questo URL come endpoint su Stripe',
    'gocardless_webhook_help_link_text' => 'add this URL as an endpoint in GoCardless',
    'payment_method_error' => 'C\'è stato un errore nel salvare il tuo metodo di pagamento. Per favore prova più tardi.',
    'notification_invoice_payment_failed_subject' => 'Pagamento fallito per la fattura :invoice',
    'notification_invoice_payment_failed' => 'Il pagamento fatto da :client per la fattura :fattura è fallito. Il pagamento è stato segnato come fallito e :amout sono stati aggiunti al saldo del cliente.',
    'link_with_plaid' => 'Link Account Instantly with Plaid',
    'link_manually' => 'Link Manuale',
    'secured_by_plaid' => 'Secured by Plaid',
    'plaid_linked_status' => 'Il tuo conto bancario presso :bank',
    'add_payment_method' => 'Aggiungi un metodo di pagamento',
    'account_holder_type' => 'Tipo Proprietario Account',
    'ach_authorization' => 'Autorizzo :company a utilizzare il mio conto bancario per pagamenti futuri e, se necessario, accreditare elettronicamente il mio conto per correggere addebiti errati Comprendo che posso annullare questa autorizzazione in qualsiasi momento rimuovendo il metodo di pagamento o contattando :email.',
    'ach_authorization_required' => 'Devi dare il consenso ai pagamenti ACH.',
    'off' => 'Off',
    'opt_in' => 'Permetti di aderire',
    'opt_out' => 'Permetti di non aderire, adesione preselezionata',
    'always' => 'Sempre',
    'opted_out' => 'Adesione ritirata',
    'opted_in' => 'Adesione effettuata',
    'manage_auto_bill' => 'Gestisci autofattura',
    'enabled' => 'Abilitato',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'Abilita i pagamenti PayPal tramite BrainTree',
    'braintree_paypal_disabled_help' => 'La piattaforma PayPal sta gestendo i pagamenti PayPal',
    'braintree_paypal_help' => 'Devi collegare anche :link',
    'braintree_paypal_help_link_text' => 'collega PayPal al tuo account BrainTree',
    'token_billing_braintree_paypal' => 'Salva i dettagli del pagamento',
    'add_paypal_account' => 'Aggiungi un account Paypal',


    'no_payment_method_specified' => 'Nessun metodo di pagamento specificato',
    'chart_type' => 'Tipo di grafico',
    'format' => 'Formato',
    'import_ofx' => 'Importa OFX',
    'ofx_file' => 'File OFX',
    'ofx_parse_failed' => 'Analisi del file OFX fallita',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'Iscriviti su WePay',
    'use_another_provider' => 'Usa un\'altro provider',
    'company_name' => 'Nome Azienda',
    'wepay_company_name_help' => 'Comparirà sull\'estratto conto della carta del cliente.',
    'wepay_description_help' => 'Scopo di questo account.',
    'wepay_tos_agree' => 'Accetto :link.',
    'wepay_tos_link_text' => 'Termini di servizio WePay',
    'resend_confirmation_email' => 'Rispedisci la mail di conferma',
    'manage_account' => 'Gestisci account',
    'action_required' => 'Richiesta azione',
    'finish_setup' => 'Finisci il setup',
    'created_wepay_confirmation_required' => 'Controlla la tua casella email e conferma l\'indirizzo con WePay',
    'switch_to_wepay' => 'Passa a WePay',
    'switch' => 'Cambia',
    'restore_account_gateway' => 'Ripristina Piattaforma',
    'restored_account_gateway' => 'Piattaforma ripristinata correttamente',
    'united_states' => 'Stati Uniti',
    'canada' => 'Canada',
    'accept_debit_cards' => 'Accettare carte di debito',
    'debit_cards' => 'Carte di debito',

    'warn_start_date_changed' => 'La prossima fattura verrà inviata alla nuova data di inizio.',
    'warn_start_date_changed_not_sent' => 'La prossima fattura verrà creata alla nuova data di inizio.',
    'original_start_date' => 'Data di inizio originale',
    'new_start_date' => 'Nuova data di inizio',
    'security' => 'Sicurezza',
    'see_whats_new' => 'Scopri le novità nella  versione :version',
    'wait_for_upload' => 'Attendere che il caricamento del documento sia completato. ',
    'upgrade_for_permissions' => 'Upgrade to our Enterprise plan to enable permissions.',
    'enable_second_tax_rate' => 'Possibile specificare una <b>tassa secondaria</b>',
    'payment_file' => 'File Pagamento',
    'expense_file' => 'File Spese',
    'product_file' => 'File Prodotto',
    'import_products' => 'Importa Prodotti',
    'products_will_create' => 'prodotti saranno creati',
    'product_key' => 'Prodotto',
    'created_products' => ':count prodotto/i aggiornato/i o creato/i con successo',
    'export_help' => 'Usa JSON se hai intenzione di importare i dati in Invoice Ninja.<br/>il file include clienti, prodotti, fatture, preventivi e pagamenti.',
    'selfhost_export_help' => '<br/>We recommend using mysqldump to create a full backup.',
    'JSON_file' => 'File JSON',

    'view_dashboard' => 'Vedi Pannello di Controllo',
    'client_session_expired' => 'Sessione Scaduta',
    'client_session_expired_message' => 'La tua sessione è scaduta. Pre favore clicca di nuovo il link nella tua email.',

    'auto_bill_notification' => 'Questa fattura sarà addebitata automaticamente con :payment_method il :due_date.',
    'auto_bill_payment_method_bank_transfer' => 'conto bancario',
    'auto_bill_payment_method_credit_card' => 'carta di credito',
    'auto_bill_payment_method_paypal' => 'Conto PayPal',
    'auto_bill_notification_placeholder' => 'La fattura verrà automaticamente addebitata sulla tua carta di credito salvata, alla data di scadenza.',
    'payment_settings' => 'Impostazioni di Pagamento',

    'on_send_date' => 'Alla data di invio',
    'on_due_date' => 'Alla data di scadenza',
    'auto_bill_ach_date_help' => 'ACH effettuerà sempre l\'addebito automatico alla data di scadenza.',
    'warn_change_auto_bill' => 'A causa delle regole NACHA, le modifiche a questa fattura potrebbero impedire la fatturazione automatica ACH.',

    'bank_account' => 'COnto bancario',
    'payment_processed_through_wepay' => 'I pagamenti ACH verranno gestiti da WePay.',
    'wepay_payment_tos_agree' => 'Accetto :terms e :privacy_policy di WePay.',
    'privacy_policy' => 'Privacy Policy',
    'wepay_payment_tos_agree_required' => 'Devi accettare i termini di servizio e della privacy di WePay.',
    'ach_email_prompt' => 'Per favore inserisci un indirizzo email:',
    'verification_pending' => 'In attesa di Verifica',

    'update_font_cache' => 'Please force refresh the page to update the font cache.',
    'more_options' => 'Altre opzioni',
    'credit_card' => 'Carta di Credito',
    'bank_transfer' => 'Bonifico Bancario',
    'no_transaction_reference' => 'Non abbiamo ricevuto riferimenti della transazione per il pagamento dalla piattaforma.',
    'use_bank_on_file' => 'Use Bank on File',
    'auto_bill_email_message' => 'Questa fattura verrà automaticamente fatturata al metodo di pagamento in archivio alla data di scadenza.',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'Aggiunta :date',
    'failed_remove_payment_method' => 'Rimozione metodo di pagamento fallita',
    'gateway_exists' => 'Questa piattaforma esiste già',
    'manual_entry' => 'Inserimento manuale',
    'start_of_week' => 'Primo giorno della settimana',

    // Frequencies
    'freq_inactive' => 'Inattivo',
    'freq_daily' => 'Giornaliero',
    'freq_weekly' => 'Settimanale',
    'freq_biweekly' => 'Bisettimanale',
    'freq_two_weeks' => 'Due settimane',
    'freq_four_weeks' => 'Quattro settimane',
    'freq_monthly' => 'Mensile',
    'freq_three_months' => 'Tre Mesi',
    'freq_four_months' => 'Quattro mesi',
    'freq_six_months' => 'Sei Mesi',
    'freq_annually' => 'Annuale',
    'freq_two_years' => 'Due anni',

    // Payment types
    'payment_type_Apply Credit' => 'Applica Credito',
    'payment_type_Bank Transfer' => 'Bonifico Bancario',
    'payment_type_Cash' => 'Contanti',
    'payment_type_Debit' => 'Debito',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Carta Visa',
    'payment_type_MasterCard' => 'MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Carta Discover',
    'payment_type_Diners Card' => 'Carta Diners',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Altra Carta di Credito',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Assegno',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Switch',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'Addebito diretto SEPA',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Accounting & Legal',
    'industry_Advertising' => 'Pubblicità',
    'industry_Aerospace' => 'Aerospaziale',
    'industry_Agriculture' => 'Agricoltura',
    'industry_Automotive' => 'Automobilistico',
    'industry_Banking & Finance' => 'Banking & Finance',
    'industry_Biotechnology' => 'Biotecnologie',
    'industry_Broadcasting' => 'Broadcasting',
    'industry_Business Services' => 'Business Services',
    'industry_Commodities & Chemicals' => 'Commodities & Chemicals',
    'industry_Communications' => 'Communications',
    'industry_Computers & Hightech' => 'Computers & Hightech',
    'industry_Defense' => 'Difesa',
    'industry_Energy' => 'Energia',
    'industry_Entertainment' => 'Intrattenimento',
    'industry_Government' => 'Governo',
    'industry_Healthcare & Life Sciences' => 'Healthcare & Life Sciences',
    'industry_Insurance' => 'Assicurazione',
    'industry_Manufacturing' => 'Manifatturiero',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Nonprofit & Higher Ed',
    'industry_Pharmaceuticals' => 'Farmaceutico',
    'industry_Professional Services & Consulting' => 'Professional Services & Consulting',
    'industry_Real Estate' => 'Immobiliare',
    'industry_Restaurant & Catering' => 'Ristorazione & Catering',
    'industry_Retail & Wholesale' => 'Vendita al dettaglio & Vendita all\'ingrosso',
    'industry_Sports' => 'Sports',
    'industry_Transportation' => 'Trasporti',
    'industry_Travel & Luxury' => 'Viaggi & Lusso',
    'industry_Other' => 'Altro',
    'industry_Photography' => 'Fotografia',

    // Countries
    'country_Afghanistan' => 'Afghanistan',
    'country_Albania' => 'Albania',
    'country_Antarctica' => 'Antartide',
    'country_Algeria' => 'Algeria',
    'country_American Samoa' => 'American Samoa',
    'country_Andorra' => 'Andorra',
    'country_Angola' => 'Angola',
    'country_Antigua and Barbuda' => 'Antigua and Barbuda',
    'country_Azerbaijan' => 'Azerbaijan',
    'country_Argentina' => 'Argentina',
    'country_Australia' => 'Australia',
    'country_Austria' => 'Austria',
    'country_Bahamas' => 'Bahamas',
    'country_Bahrain' => 'Bahrain',
    'country_Bangladesh' => 'Bangladesh',
    'country_Armenia' => 'Armenia',
    'country_Barbados' => 'Barbados',
    'country_Belgium' => 'Belgio',
    'country_Bermuda' => 'Bermuda',
    'country_Bhutan' => 'Bhutan',
    'country_Bolivia, Plurinational State of' => 'Bolivia, Plurinational State of',
    'country_Bosnia and Herzegovina' => 'Bosnia and Herzegovina',
    'country_Botswana' => 'Botswana',
    'country_Bouvet Island' => 'Bouvet Island',
    'country_Brazil' => 'Brasile',
    'country_Belize' => 'Belize',
    'country_British Indian Ocean Territory' => 'British Indian Ocean Territory',
    'country_Solomon Islands' => 'Isole Solomone',
    'country_Virgin Islands, British' => 'Virgin Islands, British',
    'country_Brunei Darussalam' => 'Brunei Darussalam',
    'country_Bulgaria' => 'Bulgaria',
    'country_Myanmar' => 'Myanmar',
    'country_Burundi' => 'Burundi',
    'country_Belarus' => 'Bielorussia',
    'country_Cambodia' => 'Cambogia',
    'country_Cameroon' => 'Camerun',
    'country_Canada' => 'Canada',
    'country_Cape Verde' => 'Cape Verde',
    'country_Cayman Islands' => 'Isole Cayman',
    'country_Central African Republic' => 'Repubblica di Centro Africa',
    'country_Sri Lanka' => 'Sri Lanka',
    'country_Chad' => 'Chad',
    'country_Chile' => 'Cile',
    'country_China' => 'Cina',
    'country_Taiwan, Province of China' => 'Taiwan',
    'country_Christmas Island' => 'Christmas Island',
    'country_Cocos (Keeling) Islands' => 'Cocos (Keeling) Islands',
    'country_Colombia' => 'Colombia',
    'country_Comoros' => 'Comoros',
    'country_Mayotte' => 'Mayotte',
    'country_Congo' => 'Congo',
    'country_Congo, the Democratic Republic of the' => 'Congo',
    'country_Cook Islands' => 'Isola di Cook',
    'country_Costa Rica' => 'Costa Rica',
    'country_Croatia' => 'Croazia',
    'country_Cuba' => 'Cuba',
    'country_Cyprus' => 'Cipro',
    'country_Czech Republic' => 'Repubblica Ceca',
    'country_Benin' => 'Benin',
    'country_Denmark' => 'Danimarca',
    'country_Dominica' => 'Dominica',
    'country_Dominican Republic' => 'Repubblica Dominicana',
    'country_Ecuador' => 'Ecuador',
    'country_El Salvador' => 'El Salvador',
    'country_Equatorial Guinea' => 'Equatorial Guinea',
    'country_Ethiopia' => 'tiopia',
    'country_Eritrea' => 'Eritrea',
    'country_Estonia' => 'Estonia',
    'country_Faroe Islands' => 'Isole Faroe',
    'country_Falkland Islands (Malvinas)' => 'Isole Falkland (Malvina)',
    'country_South Georgia and the South Sandwich Islands' => 'South Georgia and the South Sandwich Islands',
    'country_Fiji' => 'Fiji',
    'country_Finland' => 'Finlandia',
    'country_Åland Islands' => 'Åland Islands',
    'country_France' => 'Francia',
    'country_French Guiana' => 'French Guiana',
    'country_French Polynesia' => 'French Polynesia',
    'country_French Southern Territories' => 'French Southern Territories',
    'country_Djibouti' => 'Djibouti',
    'country_Gabon' => 'Gabon',
    'country_Georgia' => 'Georgia',
    'country_Gambia' => 'Gambia',
    'country_Palestinian Territory, Occupied' => 'Palestinian Territory, Occupied',
    'country_Germany' => 'Germania',
    'country_Ghana' => 'Ghana',
    'country_Gibraltar' => 'Gibilterra',
    'country_Kiribati' => 'Kiribati',
    'country_Greece' => 'Grecia',
    'country_Greenland' => 'Groenlandia',
    'country_Grenada' => 'Grenada',
    'country_Guadeloupe' => 'Guadeloupe',
    'country_Guam' => 'Guam',
    'country_Guatemala' => 'Guatemala',
    'country_Guinea' => 'Guinea',
    'country_Guyana' => 'Guyana',
    'country_Haiti' => 'Haiti',
    'country_Heard Island and McDonald Islands' => 'Heard Island and McDonald Islands',
    'country_Holy See (Vatican City State)' => 'Città del Vaticano',
    'country_Honduras' => 'Honduras',
    'country_Hong Kong' => 'Hong Kong',
    'country_Hungary' => 'Ungheria',
    'country_Iceland' => 'Islanda',
    'country_India' => 'India',
    'country_Indonesia' => 'Indonesia',
    'country_Iran, Islamic Republic of' => 'Iran',
    'country_Iraq' => 'Iraq',
    'country_Ireland' => 'Ireland',
    'country_Israel' => 'Israele',
    'country_Italy' => 'Italia',
    'country_Côte d\'Ivoire' => 'Costa d\'Avorio',
    'country_Jamaica' => 'Giamaica',
    'country_Japan' => 'Giappone',
    'country_Kazakhstan' => 'Kazakhstan',
    'country_Jordan' => 'Giordania',
    'country_Kenya' => 'Kenya',
    'country_Korea, Democratic People\'s Republic of' => 'Korea, Democratic People\'s Republic of',
    'country_Korea, Republic of' => 'Korea, Republic of',
    'country_Kuwait' => 'Kuwait',
    'country_Kyrgyzstan' => 'Kyrgyzstan',
    'country_Lao People\'s Democratic Republic' => 'Lao People\'s Democratic Republic',
    'country_Lebanon' => 'Libano',
    'country_Lesotho' => 'Lesotho',
    'country_Latvia' => 'Lettonia',
    'country_Liberia' => 'Liberia',
    'country_Libya' => 'Libia',
    'country_Liechtenstein' => 'Liechtenstein',
    'country_Lithuania' => 'Lituania',
    'country_Luxembourg' => 'Lussemburgo',
    'country_Macao' => 'Macao',
    'country_Madagascar' => 'Madagascar',
    'country_Malawi' => 'Malawi',
    'country_Malaysia' => 'Malesia',
    'country_Maldives' => 'Maldive',
    'country_Mali' => 'Mali',
    'country_Malta' => 'Malta',
    'country_Martinique' => 'Martinique',
    'country_Mauritania' => 'Mauritania',
    'country_Mauritius' => 'Mauritius',
    'country_Mexico' => 'Messico',
    'country_Monaco' => 'Monaco',
    'country_Mongolia' => 'Mongolia',
    'country_Moldova, Republic of' => 'Moldova, Republic of',
    'country_Montenegro' => 'Montenegro',
    'country_Montserrat' => 'Montserrat',
    'country_Morocco' => 'Morocco',
    'country_Mozambique' => 'Mozambique',
    'country_Oman' => 'Oman',
    'country_Namibia' => 'Namibia',
    'country_Nauru' => 'Nauru',
    'country_Nepal' => 'Nepal',
    'country_Netherlands' => 'Olanda',
    'country_Curaçao' => 'Curaçao',
    'country_Aruba' => 'Aruba',
    'country_Sint Maarten (Dutch part)' => 'Sint Maarten (Dutch part)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Bonaire, Sint Eustatius and Saba',
    'country_New Caledonia' => 'Nuova Caledonia',
    'country_Vanuatu' => 'Vanuatu',
    'country_New Zealand' => 'Nuova Zelanda',
    'country_Nicaragua' => 'Nicaragua',
    'country_Niger' => 'Niger',
    'country_Nigeria' => 'Nigeria',
    'country_Niue' => 'Niue',
    'country_Norfolk Island' => 'Norfolk Island',
    'country_Norway' => 'Norvegia',
    'country_Northern Mariana Islands' => 'Northern Mariana Islands',
    'country_United States Minor Outlying Islands' => 'United States Minor Outlying Islands',
    'country_Micronesia, Federated States of' => 'Micronesia, Federated States of',
    'country_Marshall Islands' => 'Marshall Islands',
    'country_Palau' => 'Palau',
    'country_Pakistan' => 'Pakistan',
    'country_Panama' => 'Panama',
    'country_Papua New Guinea' => 'Papua Nuova Guinea',
    'country_Paraguay' => 'Paraguai',
    'country_Peru' => 'Peru',
    'country_Philippines' => 'Filippine',
    'country_Pitcairn' => 'Pitcairn',
    'country_Poland' => 'Polonia',
    'country_Portugal' => 'ortogallo',
    'country_Guinea-Bissau' => 'Guinea-Bissau',
    'country_Timor-Leste' => 'Timor-Leste',
    'country_Puerto Rico' => 'Porto Rico',
    'country_Qatar' => 'Qatar',
    'country_Réunion' => 'Réunion',
    'country_Romania' => 'Romania',
    'country_Russian Federation' => 'Russia',
    'country_Rwanda' => 'Ruanda',
    'country_Saint Barthélemy' => 'Saint Barthélemy',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Saint Helena, Ascension and Tristan da Cunha',
    'country_Saint Kitts and Nevis' => 'Saint Kitts and Nevis',
    'country_Anguilla' => 'Anguilla',
    'country_Saint Lucia' => 'Saint Lucia',
    'country_Saint Martin (French part)' => 'Saint Martin (French part)',
    'country_Saint Pierre and Miquelon' => 'Saint Pierre and Miquelon',
    'country_Saint Vincent and the Grenadines' => 'Saint Vincent and the Grenadines',
    'country_San Marino' => 'San Marino',
    'country_Sao Tome and Principe' => 'Sao Tome and Principe',
    'country_Saudi Arabia' => 'Arabia Saudita',
    'country_Senegal' => 'Senegal',
    'country_Serbia' => 'Serbia',
    'country_Seychelles' => 'Seychelles',
    'country_Sierra Leone' => 'Sierra Leone',
    'country_Singapore' => 'Singapore',
    'country_Slovakia' => 'Slovacchia',
    'country_Viet Nam' => 'Viet Nam',
    'country_Slovenia' => 'Slovenia',
    'country_Somalia' => 'Somalia',
    'country_South Africa' => 'Sud Africa',
    'country_Zimbabwe' => 'Zimbabwe',
    'country_Spain' => 'Spagna',
    'country_South Sudan' => 'South Sudan',
    'country_Sudan' => 'Sudan',
    'country_Western Sahara' => 'Western Sahara',
    'country_Suriname' => 'Suriname',
    'country_Svalbard and Jan Mayen' => 'Svalbard and Jan Mayen',
    'country_Swaziland' => 'Swaziland',
    'country_Sweden' => 'Svezia',
    'country_Switzerland' => 'Svizzera',
    'country_Syrian Arab Republic' => 'Syrian Arab Republic',
    'country_Tajikistan' => 'Tajikistan',
    'country_Thailand' => 'Thailand',
    'country_Togo' => 'Togo',
    'country_Tokelau' => 'Tokelau',
    'country_Tonga' => 'Tonga',
    'country_Trinidad and Tobago' => 'Trinidad and Tobago',
    'country_United Arab Emirates' => 'United Arab Emirates',
    'country_Tunisia' => 'Tunisia',
    'country_Turkey' => 'Turchia',
    'country_Turkmenistan' => 'Turkmenistan',
    'country_Turks and Caicos Islands' => 'Turks and Caicos Islands',
    'country_Tuvalu' => 'Tuvalu',
    'country_Uganda' => 'Uganda',
    'country_Ukraine' => 'Ucraina',
    'country_Macedonia, the former Yugoslav Republic of' => 'Macedonia, the former Yugoslav Republic of',
    'country_Egypt' => 'Egitto',
    'country_United Kingdom' => 'Regno Unito',
    'country_Guernsey' => 'Guernsey',
    'country_Jersey' => 'Jersey',
    'country_Isle of Man' => 'Isle of Man',
    'country_Tanzania, United Republic of' => 'Tanzania, United Republic of',
    'country_United States' => 'Stati Uniti',
    'country_Virgin Islands, U.S.' => 'Virgin Islands, U.S.',
    'country_Burkina Faso' => 'Burkina Faso',
    'country_Uruguay' => 'Uruguay',
    'country_Uzbekistan' => 'Uzbekistan',
    'country_Venezuela, Bolivarian Republic of' => 'Venezuela',
    'country_Wallis and Futuna' => 'Wallis and Futuna',
    'country_Samoa' => 'Samoa',
    'country_Yemen' => 'Yemen',
    'country_Zambia' => 'Zambia',

    // Languages
    'lang_Brazilian Portuguese' => 'Brasiliano Portoghese',
    'lang_Croatian' => 'Croato',
    'lang_Czech' => 'Ceco',
    'lang_Danish' => 'Danese',
    'lang_Dutch' => 'Olandese',
    'lang_English' => 'Inglese',
    'lang_French' => 'Francese',
    'lang_French - Canada' => 'Francese Canada',
    'lang_German' => 'Tedesco',
    'lang_Italian' => 'Italiano',
    'lang_Japanese' => 'Giapponese',
    'lang_Lithuanian' => 'Lituano',
    'lang_Norwegian' => 'Norvegese',
    'lang_Polish' => 'Olacco',
    'lang_Spanish' => 'Spagnolo',
    'lang_Spanish - Spain' => 'Spagnolo - Spagna',
    'lang_Swedish' => 'Svedese',
    'lang_Albanian' => 'Albanese',
    'lang_Greek' => 'Greco',
    'lang_English - United Kingdom' => 'Inglese - Regno Unito',
    'lang_English - Australia' => 'English - Australia',
    'lang_Slovenian' => 'Slovacco',
    'lang_Finnish' => 'Finlandese',
    'lang_Romanian' => 'Romeno',
    'lang_Turkish - Turkey' => 'Turco',
    'lang_Portuguese - Brazilian' => 'Portoghese - Brasiliano',
    'lang_Portuguese - Portugal' => 'Portoghese - Portogallo',
    'lang_Thai' => 'Thailandese',
    'lang_Macedonian' => 'Macedonian',
    'lang_Chinese - Taiwan' => 'Chinese - Taiwan',
    'lang_Serbian' => 'Serbian',
    'lang_Bulgarian' => 'Bulgarian',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Accounting & Legal',
    'industry_Advertising' => 'Pubblicità',
    'industry_Aerospace' => 'Aerospaziale',
    'industry_Agriculture' => 'Agricoltura',
    'industry_Automotive' => 'Automobilistico',
    'industry_Banking & Finance' => 'Banking & Finance',
    'industry_Biotechnology' => 'Biotecnologie',
    'industry_Broadcasting' => 'Broadcasting',
    'industry_Business Services' => 'Business Services',
    'industry_Commodities & Chemicals' => 'Commodities & Chemicals',
    'industry_Communications' => 'Communications',
    'industry_Computers & Hightech' => 'Computers & Hightech',
    'industry_Defense' => 'Difesa',
    'industry_Energy' => 'Energia',
    'industry_Entertainment' => 'Intrattenimento',
    'industry_Government' => 'Governo',
    'industry_Healthcare & Life Sciences' => 'Healthcare & Life Sciences',
    'industry_Insurance' => 'Assicurazione',
    'industry_Manufacturing' => 'Manifatturiero',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Nonprofit & Higher Ed',
    'industry_Pharmaceuticals' => 'Farmaceutico',
    'industry_Professional Services & Consulting' => 'Professional Services & Consulting',
    'industry_Real Estate' => 'Immobiliare',
    'industry_Retail & Wholesale' => 'Vendita al dettaglio & Vendita all\'ingrosso',
    'industry_Sports' => 'Sports',
    'industry_Transportation' => 'Trasporti',
    'industry_Travel & Luxury' => 'Viaggi & Lusso',
    'industry_Other' => 'Altro',
    'industry_Photography' => 'Fotografia',

    'view_client_portal' => 'Visualizza il portale del cliente',
    'view_portal' => 'Visualizza il portale',
    'vendor_contacts' => 'Contatti del Fornitore',
    'all' => 'Tutti',
    'selected' => 'Selezionato',
    'category' => 'Categoria',
    'categories' => 'Categorie',
    'new_expense_category' => 'Nuova Categoria di Spesa',
    'edit_category' => 'Modifica Categoria',
    'archive_expense_category' => 'Archivia Categoria',
    'expense_categories' => 'Categorie di Spesa',
    'list_expense_categories' => 'Lista Categorie di Spesa',
    'updated_expense_category' => 'Categoria spese aggiornata con successo',
    'created_expense_category' => 'Categoria spese creata con successo',
    'archived_expense_category' => 'Categoria spese archiviata con successo',
    'archived_expense_categories' => 'Archiviato con successo :count categorie di spesa',
    'restore_expense_category' => 'Ripristina categoria spese',
    'restored_expense_category' => 'Categoria spese ripristinata con successo',
    'apply_taxes' => 'Applica Tasse',
    'min_to_max_users' => 'Da :min a :max utenti',
    'max_users_reached' => 'E\' stato raggiunto il massimo numero di utenti',
    'buy_now_buttons' => 'Puslanti Compra Ora',
    'landing_page' => 'Pagina di destinazione',
    'payment_type' => 'Tipo di Pagamento',
    'form' => 'Modulo',
    'link' => 'Collegamento',
    'fields' => 'Campi',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Nota: il cliente e la fattura sono creati anche se la transazione non è completata.',
    'buy_now_buttons_disabled' => 'Questa funzione richiede che siano configurati almeno un prodotto ed una piattaforma di pagamento.',
    'enable_buy_now_buttons_help' => 'Abilita supporto per il bottoni Compra Ora',
    'changes_take_effect_immediately' => 'Nota: i cambiamenti hanno effetto immediatamente',
    'wepay_account_description' => 'Piattaforma di pagamento per Invoice Ninja',
    'payment_error_code' => 'C\'è stato un errore nella gestione del tuo pagamento [:code]. Per favore prova tra qualche minuto.',
    'standard_fees_apply' => 'Commissione: 2,9%/1,2% [Carta di Credito/Trasferimento Bancario] + 0,30€ per ogni transazione eseguita con successo.',
    'limit_import_rows' => 'Data needs to be imported in batches of :count rows or less',
    'error_title' => 'Qualcosa è andato storto',
    'error_contact_text' => 'Se ci vuoi aiutare per favore mandaci una mail a: :mailaddress',
    'no_undo' => 'Attenzione: non si può recuperare',
    'no_contact_selected' => 'Per favore seleziona un contatto',
    'no_client_selected' => 'Per favore seleziona un cliente',

    'gateway_config_error' => 'Potrebbe essere utile impostare una nuova password o generare una nuova chiave API',
    'payment_type_on_file' => ':type on file',
    'invoice_for_client' => 'Fattura :invoice per :client',
    'intent_not_found' => 'Mi dispiace, non sono sicuro di quello che stai chiedendo.',
    'intent_not_supported' => 'Mi dispiace, non sono in grado di farlo.',
    'client_not_found' => 'Non posso trovare il cliente',
    'not_allowed' => 'Mi dispiace, non hai il permesso richiesto',
    'bot_emailed_invoice' => 'La tua fattura è stata spedita',
    'bot_emailed_notify_viewed' => 'Ti mando una mail quando è stata visualizzata.',
    'bot_emailed_notify_paid' => 'Ti mando una mail quando è pagata.',
    'add_product_to_invoice' => 'Aggiungi 1 :product',
    'not_authorized' => 'Non hai l\'autorizzazione',
    'bot_get_email' => 'Hi! (wave)<br/>Thanks for trying the Invoice Ninja Bot.<br/>You need to create a free account to use this bot.<br/>Send me your account email address to get started.',
    'bot_get_code' => 'Grazie! Ti ho inviato un\'email con il tuo codice di sicurezza',
    'bot_welcome' => 'That\'s it, your account is verified.<br/>',
    'email_not_found' => 'Nessun account trovato per :email',
    'invalid_code' => 'Il codice non è corretto',
    'security_code_email_subject' => 'Codice di sicurezza per il Bot Invoice Ninja',
    'security_code_email_line1' => 'Questo è il codice di sicurezza del tuo Bot Invoice Ninja',
    'security_code_email_line2' => 'Nota: scadrà in 10 minuti',
    'bot_help_message' => 'Attualmente posso:<br/>• Creare\aggiornare\emettere una fattura<br/>• Elencare i prodotti<br/>Per esempio:<br/><i>fatturare bob per 2 biglietti, impostare la data di scadenza a giovedì prossimo e fare uno sconto al 10 per cento</i>',
    'list_products' => 'Lista prodotti',

    'include_item_taxes_inline' => 'Includi <b>tasse di riga articolo in totale riga</b>',
    'created_quotes' => 'Successfully created :count quotes(s)',
    'limited_gateways' => 'Nota: supportiamo una piattaforma per le carte di credito per ogni società.',

    'warning' => 'Attenzione',
    'self-update' => 'Aggiorna',
    'update_invoiceninja_title' => 'Aggiorna Invoice Ninja',
    'update_invoiceninja_warning' => 'Prima di aggiornare Invoice Ninja, crea un backup del database e dei files!',
    'update_invoiceninja_available' => 'Una nuova versione di Invoice Ninja è disponibile.',
    'update_invoiceninja_unavailable' => 'Non ci sono disponibili nuove versioni di Invoice Ninja.',
    'update_invoiceninja_instructions' => 'Please install the new version <strong>:version</strong> by clicking the <em>Update now</em> button below. Afterwards you\'ll be redirected to the dashboard.',
    'update_invoiceninja_update_start' => 'Aggiorna ora',
    'update_invoiceninja_download_start' => 'Scarica :version',
    'create_new' => 'Crea Nuovo',

    'toggle_navigation' => 'Apri/Chiudi Navigazione',
    'toggle_history' => 'Apri/chiudi Storico',
    'unassigned' => 'Non assegnato',
    'task' => 'Attività',
    'contact_name' => 'Nome Contatto',
    'city_state_postal' => 'Città/Stato/CAP',
    'custom_field' => 'Campo Personalizzato',
    'account_fields' => 'Campi Azienda',
    'facebook_and_twitter' => 'Facebook e Twitter',
    'facebook_and_twitter_help' => 'Follow our feeds to help support our project',
    'reseller_text' => 'Note: the white-label license is intended for personal use, please email us at :email if you\'d like to resell the app.',
    'unnamed_client' => 'Cliente senza nome',

    'day' => 'GIorno',
    'week' => 'Settimana',
    'month' => 'Mese',
    'inactive_logout' => 'Disconnessione per inattività',
    'reports' => 'Rapporti',
    'total_profit' => 'Profitto Totale',
    'total_expenses' => 'Spese Totali',
    'quote_to' => 'Preventivo per',

    // Limits
    'limit' => 'Limite',
    'min_limit' => 'Minimo :min',
    'max_limit' => 'Massimo :max',
    'no_limit' => 'Senza Limiti',
    'set_limits' => 'Imposta il limite per :gateway_type',
    'enable_min' => 'Attiva minimo',
    'enable_max' => 'Attiva massimo',
    'min' => 'Min',
    'max' => 'ax',
    'limits_not_met' => 'Questa fattura non rispetta i limiti per quel metodo di pagamento.',

    'date_range' => 'Intervallo di Tempo',
    'raw' => 'Raw',
    'raw_html' => 'Raw HTML',
    'update' => 'Aggiorna',
    'invoice_fields_help' => 'Spostali per cambiare ordine e posizione',
    'new_category' => 'Nuova Categoria',
    'restore_product' => 'Ripristina Prodotto',
    'blank' => 'Vuoto',
    'invoice_save_error' => 'C\'è stato un errore durante il salvataggio della fattura',
    'enable_recurring' => 'Attiva Ricorrenza',
    'disable_recurring' => 'Disattiva Ricorrenza',
    'text' => 'Testo',
    'expense_will_create' => 'spesa verrà creata',
    'expenses_will_create' => 'spese verranno trovate',
    'created_expenses' => 'Creata/e con successo :count spesa/e',

    'translate_app' => 'Aiutaci a migliorare le traduzioni con :link',
    'expense_category' => 'Categoria Spesa',

    'go_ninja_pro' => 'Passa a Ninja Pro!',
    'go_enterprise' => 'Passa a Enterprise!',
    'upgrade_for_features' => 'Fai l\'upgrade per più funzionalità',
    'pay_annually_discount' => 'Paga annualmente per avere 10 mesi + 2 gratis!',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'IlTuoBrand.InvoiceNinja.com',
    'pro_upgrade_feature2' => 'Personalizza ogni parte della tua fattura!',
    'enterprise_upgrade_feature1' => 'Imposta permessi per utenti multipli',
    'enterprise_upgrade_feature2' => 'Allegare file di terze parti a fatture e spese',
    'much_more' => 'Molto di più!',
    'all_pro_fetaures' => 'Più tutte le funzionalità pro!',

    'currency_symbol' => 'Simbolo',
    'currency_code' => 'Codice',

    'buy_license' => 'Compa Licenza',
    'apply_license' => 'Applica Licenza',
    'submit' => 'Invia',
    'white_label_license_key' => 'Chiave di Licenza',
    'invalid_white_label_license' => 'La licenza white label non è valida',
    'created_by' => 'Creato da :name',
    'modules' => 'Moduli',
    'financial_year_start' => 'Primo mese dell\'anno',
    'authentication' => 'Autenticazione',
    'checkbox' => 'Checkbox',
    'invoice_signature' => 'Firma',
    'show_accept_invoice_terms' => 'Casella di controllo termini di servizio fatture',
    'show_accept_invoice_terms_help' => 'Rendi obbligatoria l\'accettazione dei termini della fattura.',
    'show_accept_quote_terms' => 'Casella di controllo termini di servizio preventivi',
    'show_accept_quote_terms_help' => 'Rendi obbligatoria l\'accettazione dei termini del preventivo.',
    'require_invoice_signature' => 'Firma Fattura',
    'require_invoice_signature_help' => 'Richiedi al cliente di firmare la fattura.',
    'require_quote_signature' => 'Firma Bozza',
    'require_quote_signature_help' => 'Richiedi al cliente di firmare il preventivo.',
    'i_agree' => 'Accetto i Termini',
    'sign_here' => 'Per favore firma qui:',
    'authorization' => 'Autorizzazione',
    'signed' => 'Firmato',

    // BlueVine
    'bluevine_promo' => 'Get flexible business lines of credit and invoice factoring using BlueVine.',
    'bluevine_modal_label' => 'Sign up with BlueVine',
    'bluevine_modal_text' => '<h3>Fast funding for your business. No paperwork.</h3>
<ul><li>Flexible business lines of credit and invoice factoring.</li></ul>',
    'bluevine_create_account' => 'Crea un account',
    'quote_types' => 'Ricevi un preventivo per',
    'invoice_factoring' => 'Invoice factoring',
    'line_of_credit' => 'Linea di Credito',
    'fico_score' => 'Il tuo punteggio FICO',
    'business_inception' => 'Business Inception Date',
    'average_bank_balance' => 'Average bank account balance',
    'annual_revenue' => 'Guadagno Annuale',
    'desired_credit_limit_factoring' => 'Desired invoice factoring limit',
    'desired_credit_limit_loc' => 'Desired line of credit limit',
    'desired_credit_limit' => 'Limite credito desiderato',
    'bluevine_credit_line_type_required' => 'Devi sceglierne almeno uno',
    'bluevine_field_required' => 'Questo campo è obbligatorio',
    'bluevine_unexpected_error' => 'Errore inaspettato!',
    'bluevine_no_conditional_offer' => 'More information is required before getting a quote. Click continue below.',
    'bluevine_invoice_factoring' => 'Invoice Factoring',
    'bluevine_conditional_offer' => 'Conditional Offer',
    'bluevine_credit_line_amount' => 'Linea di Credito',
    'bluevine_advance_rate' => 'Advance Rate',
    'bluevine_weekly_discount_rate' => 'Weekly Discount Rate',
    'bluevine_minimum_fee_rate' => 'Commissione Minima',
    'bluevine_line_of_credit' => 'Linea di Credito',
    'bluevine_interest_rate' => 'Tasso di Interesse',
    'bluevine_weekly_draw_rate' => 'Weekly Draw Rate',
    'bluevine_continue' => 'Continue to BlueVine',
    'bluevine_completed' => 'BlueVine signup completed',

    'vendor_name' => 'Fornitore',
    'entity_state' => 'State',
    'client_created_at' => 'Data Creazione',
    'postmark_error' => 'There was a problem sending the email through Postmark: :link',
    'project' => 'Progetto',
    'projects' => 'Progetti',
    'new_project' => 'Nuovo Progetto',
    'edit_project' => 'Modifica Progetto',
    'archive_project' => 'Archivia Progetto',
    'list_projects' => 'Lista Progetti',
    'updated_project' => 'Progetto aggiornato con successo',
    'created_project' => 'Progetto creato con successo',
    'archived_project' => 'Progetto archiviato con successo',
    'archived_projects' => ':count progetti archiviati con successo',
    'restore_project' => 'Ripristina Progetto',
    'restored_project' => 'Progetto ripristinato con successo',
    'delete_project' => 'Elimina Progetto',
    'deleted_project' => 'Progetto eliminato con successo',
    'deleted_projects' => ':count progetti eliminati con successo',
    'delete_expense_category' => 'Elimina categoria',
    'deleted_expense_category' => 'Categoria eliminata con successo',
    'delete_product' => 'Elimina prodotto',
    'deleted_product' => 'Prodotto eliminato con successo',
    'deleted_products' => ':count prodotti eliminati con successo',
    'restored_product' => 'Prodotto ripristinato con successo',
    'update_credit' => 'Aggiorna Credito',
    'updated_credit' => 'Credito aggiornato con successo',
    'edit_credit' => 'Modifica Credito',
    'realtime_preview' => 'Anteprima Live',
    'realtime_preview_help' => 'Aggiorna in tempo reale l\'anteprima PDF sulla pagina della fattura quando si modifica la fattura.<br/>Disabilita questa opzione per migliorare le prestazioni quando si modificano le fatture.',
    'live_preview_help' => 'Visualizza un\'anteprima PDF aggiornata nella pagina della fattura.',
    'force_pdfjs_help' => 'Replace the built-in PDF viewer in :chrome_link and :firefox_link.<br/>Enable this if your browser is automatically downloading the PDF.',
    'force_pdfjs' => 'Impedisci il download',
    'redirect_url' => 'Redirect URL',
    'redirect_url_help' => 'Specifica un URL su cui redirigere dopo il pagamento (Opzionale)',
    'save_draft' => 'Salva Bozza',
    'refunded_credit_payment' => 'Pagamento del credito rimborsato',
    'keyboard_shortcuts' => 'Keyboard Shortcuts',
    'toggle_menu' => 'Toggle Menu',
    'new_...' => 'Nuovo ...',
    'list_...' => 'Lista ...',
    'created_at' => 'Data Creazione',
    'contact_us' => 'Contattaci',
    'user_guide' => 'Guida Utente',
    'promo_message' => 'Upgrade before :expires and get :amount OFF your first year of our Pro or Enterprise packages.',
    'discount_message' => ':amount off expires :expires',
    'mark_paid' => 'Segna come Pagata',
    'marked_sent_invoice' => 'Fattura segnata come spedita',
    'marked_sent_invoices' => 'Fatture segnate come spedite',
    'invoice_name' => 'Fattura',
    'product_will_create' => 'prodotto sarà creato',
    'contact_us_response' => 'Thank you for your message! We\'ll try to respond as soon as possible.',
    'last_7_days' => 'Ultimi 7 giorni',
    'last_30_days' => 'Ultimi 30 giorni',
    'this_month' => 'Questo mese',
    'last_month' => 'Mese scorso',
    'current_quarter' => 'Current Quarter',
    'last_quarter' => 'Last Quarter',
    'last_year' => 'Anno scorso',
    'custom_range' => 'Intervallo personalizzato',
    'url' => 'URL',
    'debug' => 'Debug',
    'https' => 'HTTPS',
    'require' => 'Obbligatorio',
    'license_expiring' => 'Note: Your license will expire in :count days, :link to renew it.',
    'security_confirmation' => 'Il tuo indirizzo email è stato confermato.',
    'white_label_expired' => 'Your white label license has expired, please consider renewing it to help support our project.',
    'renew_license' => 'Rinnova Licenza',
    'iphone_app_message' => 'Consider downloading our :link',
    'iphone_app' => 'App per iPhone',
    'android_app' => 'Android app',
    'logged_in' => 'Autenticato',
    'switch_to_primary' => 'Switch to your primary company (:name) to manage your plan.',
    'inclusive' => 'Inclusiva',
    'exclusive' => 'Esclusiva',
    'postal_city_state' => 'Postal/City/State',
    'phantomjs_help' => 'In certain cases the app uses :link_phantom to generate the PDF, install :link_docs to generate it locally.',
    'phantomjs_local' => 'Using local PhantomJS',
    'client_number' => 'Numero Cliente',
    'client_number_help' => 'Specifica un prefisso o usa un modello personalizzato per settare dinamicamente il numero cliente.',
    'next_client_number' => 'Il prossimo numero cliente è :number.',
    'generated_numbers' => 'Generazione Numeri',
    'notes_reminder1' => 'Primo promemoria',
    'notes_reminder2' => 'Secondo promemoria',
    'notes_reminder3' => 'Terzo promemoria',
    'notes_reminder4' => 'Promemoria',
    'bcc_email' => 'BCC Email',
    'tax_quote' => 'Tassa Preventivo',
    'tax_invoice' => 'Tassa Fattura',
    'emailed_invoices' => 'Fatture inviate con successo',
    'emailed_quotes' => 'Preventivi inviati con successo',
    'website_url' => 'URL SitoWeb',
    'domain' => 'Dominio',
    'domain_help' => 'Used in the client portal and when sending emails.',
    'domain_help_website' => 'Used when sending emails.',
    'import_invoices' => 'Importa fatture',
    'new_report' => 'Nuovo Rapporto',
    'edit_report' => 'Modifica Rapporto',
    'columns' => 'Colonne',
    'filters' => 'Filtri',
    'sort_by' => 'Ordina per',
    'draft' => 'Bozza',
    'unpaid' => 'Non pagata',
    'aging' => 'Aging',
    'age' => 'Età',
    'days' => 'Giorni',
    'age_group_0' => '0 - 30 Giorni',
    'age_group_30' => '30 - 60 Giorni',
    'age_group_60' => '60 - 90 Giorni',
    'age_group_90' => '90 - 120 Giorni',
    'age_group_120' => '120+ Giorni',
    'invoice_details' => 'Dettagli fattura',
    'qty' => 'Quantità',
    'profit_and_loss' => 'Utile e Perdite',
    'revenue' => 'Entrate',
    'profit' => 'Utile',
    'group_when_sorted' => 'Group Sort',
    'group_dates_by' => 'Raggruppa Date per',
    'year' => 'Anno',
    'view_statement' => 'Estratto Conto',
    'statement' => 'Statement',
    'statement_date' => 'Statement Date',
    'mark_active' => 'Segna come attivo',
    'send_automatically' => 'Invia Automaticamente',
    'initial_email' => 'Email iniziale',
    'invoice_not_emailed' => 'Questa fattura non è stata invia via mail.',
    'quote_not_emailed' => 'Questo preventivo non è stato inviato via mail.',
    'sent_by' => 'Inviato da :user',
    'recipients' => 'Destinatari',
    'save_as_default' => 'Salva come predefinito',
    'start_of_week_help' => 'Used by <b>date</b> selectors',
    'financial_year_start_help' => 'Used by <b>date range</b> selectors',
    'reports_help' => 'Shift + Click to sort by multiple columns, Ctrl + Click to clear the grouping.',
    'this_year' => 'Quest\'anno',

    // Updated login screen
    'ninja_tagline' => 'Create. Send. Get Paid.',
    'login_or_existing' => 'Or login with a connected account.',
    'sign_up_now' => 'Iscriviti ora',
    'not_a_member_yet' => 'Not a member yet?',
    'login_create_an_account' => 'Crea un account!',

    // New Client Portal styling
    'invoice_from' => 'Fatture Da:',
    'email_alias_message' => 'We require each company to have a unique email address.<br/>Consider using an alias. ie, email+label@example.com',
    'full_name' => 'Nome Completo',
    'month_year' => 'MESE/ANNO',
    'valid_thru' => 'Valido\nfino a',

    'product_fields' => 'Campi Prodotto',
    'custom_product_fields_help' => 'Aggiungi un campo quando crei un prodotto o fattura e visualizzalo assieme al suo valore nel PDF.',
    'freq_two_months' => 'Due mesi',
    'freq_yearly' => 'Annualmente',
    'profile' => 'Profilo',
    'payment_type_help' => 'Imposta il <b>tipo di pagamento</b> di default',
    'industry_Construction' => 'Construction',
    'your_statement' => 'Your Statement',
    'statement_issued_to' => 'Statement issued to',
    'statement_to' => 'Statement to',
    'customize_options' => 'Personalizza opzioni',
    'created_payment_term' => 'Termini di pagamento creato con successo',
    'updated_payment_term' => 'Termini di pagamento aggiornato con successo',
    'archived_payment_term' => 'Termini di pagamento archiviato con successo',
    'resend_invite' => 'Re-invia invito ',
    'credit_created_by' => 'Credito creato dal pagamento :transaction_reference',
    'created_payment_and_credit' => 'Pagamento e credito creati con successo',
    'created_payment_and_credit_emailed_client' => 'Pagamento e credito creati ed inviati via email con successo al cliente ',
    'create_project' => 'Crea un Progetto',
    'create_vendor' => 'Crea fornitore',
    'create_expense_category' => 'Crea una categoria',
    'pro_plan_reports' => ':link to enable reports by joining the Pro Plan',
    'mark_ready' => 'Segna come pronto',

    'limits' => 'Limiti',
    'fees' => 'Commissioni',
    'fee' => 'Commissione',
    'set_limits_fees' => 'Imposta limiti/commissioni del :gateway_type',
    'fees_tax_help' => 'Abilita imposte per riga articolo per impostare i tassi di imposta.',
    'fees_sample' => 'La tariffa per una fattura :amount sarebbe :total.',
    'discount_sample' => 'Lo sconto per una fattura :amount sarebbe :total.',
    'no_fees' => 'No Fees',
    'gateway_fees_disclaimer' => 'Attenzione: non tutti gli stati/piattaforme permettono l\'aggiunta di commissioni, rivedere le leggi locali/i termini di utilizzo.',
    'percent' => 'Percentuale',
    'location' => 'Location',
    'line_item' => 'Riga articolo',
    'surcharge' => 'Sovrapprezzo',
    'location_first_surcharge' => 'Enabled - First surcharge',
    'location_second_surcharge' => 'Enabled - Second surcharge',
    'location_line_item' => 'Abilitata - Riga articolo',
    'online_payment_surcharge' => 'Supplemento pagamento online',
    'gateway_fees' => 'Commissione Piattaforma',
    'fees_disabled' => 'Commissioni disabilitate',
    'gateway_fees_help' => 'Aggiungi automaticamente un supplemento/sconto per il pagamento online.',
    'gateway' => 'Piattaforma',
    'gateway_fee_change_warning' => 'Se sono presenti fatture non pagate con commissioni, sarà necessario aggiornarle manualmente.',
    'fees_surcharge_help' => 'Personalizza sovrapprezzo :link',
    'label_and_taxes' => 'etichetta e tasse',
    'billable' => 'Fatturabile',
    'logo_warning_too_large' => 'The image file is too large.',
    'logo_warning_fileinfo' => 'Warning: To support gifs the fileinfo PHP extension needs to be enabled.',
    'logo_warning_invalid' => 'There was a problem reading the image file, please try a different format.',

    'error_refresh_page' => 'An error occurred, please refresh the page and try again.',
    'data' => 'Dati',
    'imported_settings' => 'Successfully imported settings',
    'reset_counter' => 'Resetta contatori',
    'next_reset' => 'Prossimo reset',
    'reset_counter_help' => 'Resetta automaticamente i contatori delle fatture e dei preventivi.',
    'auto_bill_failed' => 'Auto-fatturazione fallita per la fattura :invoice_number',
    'online_payment_discount' => 'Sconto pagamento online',
    'created_new_company' => 'Successfully created new company',
    'fees_disabled_for_gateway' => 'Tariffe disattivate per questa piattaforma.',
    'logout_and_delete' => 'Esci/Elimina Account',
    'tax_rate_type_help' => 'Inclusive tax rates adjust the line item cost when selected.<br/>Only exclusive tax rates can be used as a default.',
    'invoice_footer_help' => 'Use $pageNumber and $pageCount to display the page information.',
    'credit_note' => 'Nota di Credito',
    'credit_issued_to' => 'Credito rilasciato a',
    'credit_to' => 'Credito a',
    'your_credit' => 'Il tuo Credito',
    'credit_number' => 'Numero Credito',
    'create_credit_note' => 'Crea Nota di Credito',
    'menu' => 'Menu',
    'error_incorrect_gateway_ids' => 'Errore: La tabella delle piattaforme contiene degli id incorretti.',
    'purge_data' => 'Cancella dati permanentemente',
    'delete_data' => 'Cancella dati',
    'purge_data_help' => 'Permanently delete all data but keep the account and settings.',
    'cancel_account_help' => 'Permanently delete the account along with all data and setting.',
    'purge_successful' => 'Successfully purged company data',
    'forbidden' => 'Proibito',
    'purge_data_message' => 'Warning: This will permanently erase your data, there is no undo.',
    'contact_phone' => 'Telefono Contatto',
    'contact_email' => 'Contact Email',
    'reply_to_email' => 'Indirizzo di Risposta mail',
    'reply_to_email_help' => 'Specifica l\'indirizzo a cui può rispondere il cliente',
    'bcc_email_help' => 'Includi un indirizzo nascosto che riceverà le mail',
    'import_complete' => 'Your import has successfully completed.',
    'confirm_account_to_import' => 'Please confirm your account to import data.',
    'import_started' => 'Your import has started, we\'ll send you an email once it completes.',
    'listening' => 'In ascolto...',
    'microphone_help' => 'Say "new invoice for [client]" or "show me [client]\'s archived payments"',
    'voice_commands' => 'Comandi vocali',
    'sample_commands' => 'Comandi di esempio',
    'voice_commands_feedback' => 'We\'re actively working to improve this feature, if there\'s a command you\'d like us to support please email us at :email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Money Order',
    'archived_products' => 'Archiviati con successo :count prodotti',
    'recommend_on' => 'Si consiglia di <b>abilitare</b> questa impostazione.',
    'recommend_off' => 'Si consiglia di <b>disabilitare</b> questa impostazione.',
    'notes_auto_billed' => 'Auto-fattura',
    'surcharge_label' => 'Etichetta Sovrapprezzo',
    'contact_fields' => 'Campi Contatto',
    'custom_contact_fields_help' => 'Aggiungi un campo quando crei un contatto e opzionalmente visualizzalo assieme al suo valore nel PDF.',
    'datatable_info' => 'Showing :start to :end of :total entries',
    'credit_total' => 'Credito Totale',
    'mark_billable' => 'Segna come fatturabile',
    'billed' => 'Fatturato',
    'company_variables' => 'Company Variables',
    'client_variables' => 'Client Variables',
    'invoice_variables' => 'Variabili della fattura',
    'navigation_variables' => 'Navigation Variables',
    'custom_variables' => 'Variabili Personalizzate',
    'invalid_file' => 'Tipo di file non valido',
    'add_documents_to_invoice' => 'Aggiungere documenti a fattura',
    'mark_expense_paid' => 'Segna come pagato',
    'white_label_license_error' => 'Impossibile convalidare la licenza, controlla storage/logs-laravel-error.log per maggiori dettagli.',
    'plan_price' => 'Prezzo del piano',
    'wrong_confirmation' => 'Codice di conferma errato',
    'oauth_taken' => 'Questo account è già registrato',
    'emailed_payment' => 'Successfully emailed payment',
    'email_payment' => 'Email Pagamento',
    'invoiceplane_import' => 'Usate :link per migrare i tuoi dati da InvoicePlane.',
    'duplicate_expense_warning' => 'Warning: This :link may be a duplicate',
    'expense_link' => 'spesa',
    'resume_task' => ' Riprendi l\'attività',
    'resumed_task' => 'Attività ripresa con sucesso',
    'quote_design' => 'Stile Preventivo',
    'default_design' => 'Stile Standard',
    'custom_design1' => 'Design Personalizzato 1',
    'custom_design2' => 'Design Personalizzato 2',
    'custom_design3' => 'Design Personalizzato 3',
    'empty' => 'Vuoto',
    'load_design' => 'Carica Design',
    'accepted_card_logos' => 'Loghi carte accettate',
    'phantomjs_local_and_cloud' => 'Using local PhantomJS, falling back to phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Chiave Analytics',
    'analytics_key_help' => 'Tieni traccia dei pagamenti utilizzando :link',
    'start_date_required' => 'La data di inizio è necessaria',
    'application_settings' => 'Impostazioni Applicazione',
    'database_connection' => 'Connessione Database',
    'driver' => 'Driver',
    'host' => 'Host',
    'database' => 'Database',
    'test_connection' => 'Testa connessione',
    'from_name' => 'Da Nome',
    'from_address' => 'Da indirizzo',
    'port' => 'Porta',
    'encryption' => 'Encryption',
    'mailgun_domain' => 'Mailgun Domain',
    'mailgun_private_key' => 'Mailgun Private Key',
    'send_test_email' => 'Invia email di test',
    'select_label' => 'Seleziona etichetta',
    'label' => 'Etichetta',
    'service' => 'Servizio',
    'update_payment_details' => 'Aggiorna i dettagli di pagamento',
    'updated_payment_details' => 'Dettagli di pagamento aggiornati con successo',
    'update_credit_card' => 'Aggiorna carta di credito',
    'recurring_expenses' => 'Spese Ricorrenti',
    'recurring_expense' => 'Spesa Ricorrente',
    'new_recurring_expense' => 'Nuova Spesa Ricorrente',
    'edit_recurring_expense' => 'Modifica Spesa Ricorrente',
    'archive_recurring_expense' => 'Archivia spesa ricorrente',
    'list_recurring_expense' => 'Lista spese ricorrente',
    'updated_recurring_expense' => 'Spesa ricorrente aggiornata con successo',
    'created_recurring_expense' => 'Spesa ricorrente creata con successo',
    'archived_recurring_expense' => 'Spesa ricorrente archiviata con successo',
    'restore_recurring_expense' => 'Riprestina spesa ricorrente',
    'restored_recurring_expense' => 'Spesa ricorrente riprestinata con successo',
    'delete_recurring_expense' => 'Elimina Spesa Ricorrente',
    'deleted_recurring_expense' => 'Progetto cancellato con sucesso',
    'view_recurring_expense' => 'Vedi Spesa Ricorrente',
    'taxes_and_fees' => 'Tasse e commissioni',
    'import_failed' => 'Importazione Fallita',
    'recurring_prefix' => 'Prefisso Ricorrente',
    'options' => 'Opzioni',
    'credit_number_help' => 'Specifica un prefisso o usa un modello personalizzato per generare dinamicamente i numeri dei crediti per le fatture negative.',
    'next_credit_number' => 'Il prossimo numero per i crediti è :number.',
    'padding_help' => 'Il numero di cifre che compongono il numero.',
    'import_warning_invalid_date' => 'Attenzione: il formato della data sembra non essere valido.',
    'product_notes' => 'Note Prodotto',
    'app_version' => 'Versione App',
    'ofx_version' => 'OFX Version',
    'gateway_help_23' => ':link to get your Stripe API keys.',
    'error_app_key_set_to_default' => 'Error: APP_KEY is set to a default value, to update it backup your database and then run <code>php artisan ninja:update-key</code>',
    'charge_late_fee' => 'Charge Late Fee',
    'late_fee_amount' => 'Late Fee Amount',
    'late_fee_percent' => 'Late Fee Percent',
    'late_fee_added' => 'Late fee added on :date',
    'download_invoice' => 'Scarica fattura',
    'download_quote' => 'Scarica Preventivo',
    'invoices_are_attached' => 'I PDF delle tue fatture sono allegati.',
    'downloaded_invoice' => 'Sarà inviata un\'email con il PDF della fattura',
    'downloaded_quote' => 'An email will be sent with the quote PDF',
    'downloaded_invoices' => 'Sarà inviata un\'email con i PDF delle fatture',
    'downloaded_quotes' => 'An email will be sent with the quote PDFs',
    'clone_expense' => 'Clona spesa',
    'default_documents' => 'Documenti di default',
    'send_email_to_client' => 'Invia email a cliente',
    'refund_subject' => 'Rimborso Processato',
    'refund_body' => 'È stato elaborato un rimborso di :amount per la fattura :invoice_number.',

    'currency_us_dollar' => 'Dollaro USA',
    'currency_british_pound' => 'Sterlina Inglese',
    'currency_euro' => 'Euro',
    'currency_south_african_rand' => 'South African Rand',
    'currency_danish_krone' => 'Danish Krone',
    'currency_israeli_shekel' => 'Israeli Shekel',
    'currency_swedish_krona' => 'Swedish Krona',
    'currency_kenyan_shilling' => 'Kenyan Shilling',
    'currency_canadian_dollar' => 'Canadian Dollar',
    'currency_philippine_peso' => 'Philippine Peso',
    'currency_indian_rupee' => 'Indian Rupee',
    'currency_australian_dollar' => 'Australian Dollar',
    'currency_singapore_dollar' => 'Singapore Dollar',
    'currency_norske_kroner' => 'Norske Kroner',
    'currency_new_zealand_dollar' => 'New Zealand Dollar',
    'currency_vietnamese_dong' => 'Vietnamese Dong',
    'currency_swiss_franc' => 'Swiss Franc',
    'currency_guatemalan_quetzal' => 'Guatemalan Quetzal',
    'currency_malaysian_ringgit' => 'Malaysian Ringgit',
    'currency_brazilian_real' => 'Brazilian Real',
    'currency_thai_baht' => 'Thai Baht',
    'currency_nigerian_naira' => 'Nigerian Naira',
    'currency_argentine_peso' => 'Argentine Peso',
    'currency_bangladeshi_taka' => 'Bangladeshi Taka',
    'currency_united_arab_emirates_dirham' => 'United Arab Emirates Dirham',
    'currency_hong_kong_dollar' => 'Hong Kong Dollar',
    'currency_indonesian_rupiah' => 'Indonesian Rupiah',
    'currency_mexican_peso' => 'Mexican Peso',
    'currency_egyptian_pound' => 'Egyptian Pound',
    'currency_colombian_peso' => 'Colombian Peso',
    'currency_west_african_franc' => 'West African Franc',
    'currency_chinese_renminbi' => 'Chinese Renminbi',
    'currency_rwandan_franc' => 'Rwandan Franc',
    'currency_tanzanian_shilling' => 'Tanzanian Shilling',
    'currency_netherlands_antillean_guilder' => 'Netherlands Antillean Guilder',
    'currency_trinidad_and_tobago_dollar' => 'Trinidad and Tobago Dollar',
    'currency_east_caribbean_dollar' => 'East Caribbean Dollar',
    'currency_ghanaian_cedi' => 'Ghanaian Cedi',
    'currency_bulgarian_lev' => 'Bulgarian Lev',
    'currency_aruban_florin' => 'Aruban Florin',
    'currency_turkish_lira' => 'Turkish Lira',
    'currency_romanian_new_leu' => 'Romanian New Leu',
    'currency_croatian_kuna' => 'Croatian Kuna',
    'currency_saudi_riyal' => 'Saudi Riyal',
    'currency_japanese_yen' => 'Japanese Yen',
    'currency_maldivian_rufiyaa' => 'Maldivian Rufiyaa',
    'currency_costa_rican_colon' => 'Costa Rican Colón',
    'currency_pakistani_rupee' => 'Pakistani Rupee',
    'currency_polish_zloty' => 'Polish Zloty',
    'currency_sri_lankan_rupee' => 'Sri Lankan Rupee',
    'currency_czech_koruna' => 'Czech Koruna',
    'currency_uruguayan_peso' => 'Uruguayan Peso',
    'currency_namibian_dollar' => 'Namibian Dollar',
    'currency_tunisian_dinar' => 'Tunisian Dinar',
    'currency_russian_ruble' => 'Russian Ruble',
    'currency_mozambican_metical' => 'Mozambican Metical',
    'currency_omani_rial' => 'Omani Rial',
    'currency_ukrainian_hryvnia' => 'Ukrainian Hryvnia',
    'currency_macanese_pataca' => 'Macanese Pataca',
    'currency_taiwan_new_dollar' => 'Taiwan New Dollar',
    'currency_dominican_peso' => 'Dominican Peso',
    'currency_chilean_peso' => 'Peso Cileno',
    'currency_icelandic_krona' => 'Icelandic Króna',
    'currency_papua_new_guinean_kina' => 'Papua New Guinean Kina',
    'currency_jordanian_dinar' => 'Jordanian Dinar',
    'currency_myanmar_kyat' => 'Myanmar Kyat',
    'currency_peruvian_sol' => 'Peruvian Sol',
    'currency_botswana_pula' => 'Botswana Pula',
    'currency_hungarian_forint' => 'Hungarian Forint',
    'currency_ugandan_shilling' => 'Ugandan Shilling',
    'currency_barbadian_dollar' => 'Barbadian Dollar',
    'currency_brunei_dollar' => 'Brunei Dollar',
    'currency_georgian_lari' => 'Georgian Lari',
    'currency_qatari_riyal' => 'Qatari Riyal',
    'currency_honduran_lempira' => 'Honduran Lempira',
    'currency_surinamese_dollar' => 'Surinamese Dollar',
    'currency_bahraini_dinar' => 'Bahraini Dinar',
    'currency_venezuelan_bolivars' => 'Venezuelan Bolivars',
    'currency_south_korean_won' => 'South Korean Won',
    'currency_moroccan_dirham' => 'Moroccan Dirham',
    'currency_jamaican_dollar' => 'Jamaican Dollar',
    'currency_angolan_kwanza' => 'Angolan Kwanza',
    'currency_haitian_gourde' => 'Haitian Gourde',
    'currency_zambian_kwacha' => 'Zambian Kwacha',
    'currency_nepalese_rupee' => 'Nepalese Rupee',
    'currency_cfp_franc' => 'CFP Franc',
    'currency_mauritian_rupee' => 'Mauritian Rupee',
    'currency_cape_verdean_escudo' => 'Cape Verdean Escudo',
    'currency_kuwaiti_dinar' => 'Kuwaiti Dinar',
    'currency_algerian_dinar' => 'Algerian Dinar',
    'currency_macedonian_denar' => 'Macedonian Denar',
    'currency_fijian_dollar' => 'Fijian Dollar',
    'currency_bolivian_boliviano' => 'Bolivian Boliviano',
    'currency_albanian_lek' => 'Albanian Lek',
    'currency_serbian_dinar' => 'Serbian Dinar',
    'currency_lebanese_pound' => 'Lebanese Pound',
    'currency_armenian_dram' => 'Armenian Dram',
    'currency_azerbaijan_manat' => 'Azerbaijan Manat',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Bosnia and Herzegovina Convertible Mark',
    'currency_belarusian_ruble' => 'Belarusian Ruble',
    'currency_moldovan_leu' => 'Moldovan Leu',
    'currency_kazakhstani_tenge' => 'Kazakhstani Tenge',
    'currency_gibraltar_pound' => 'Gibraltar Pound',

    'review_app_help' => 'We hope you\'re enjoying using the app.<br/>If you\'d consider :link we\'d greatly appreciate it!',
    'writing_a_review' => 'writing a review',

    'use_english_version' => 'Assicurati di stare usanto la versione Inglese dei file. <br/> Usiamo le instestazioni delle colonne come corrispondenza per i campi.',
    'tax1' => 'Prima Tassa',
    'tax2' => 'Seconda Tassa',
    'fee_help' => 'Le tariffe delle piattaforme sono i costi applicati per l\'accesso alle reti finanziarie che gestiscono i pagamenti online.',
    'format_export' => 'Exporting format',
    'custom1' => 'First Custom',
    'custom2' => 'Second Custom',
    'contact_first_name' => 'Contact First Name',
    'contact_last_name' => 'Contact Last Name',
    'contact_custom1' => 'Contact First Custom',
    'contact_custom2' => 'Contact Second Custom',
    'currency' => 'Valuta',
    'ofx_help' => 'To troubleshoot check for comments on :ofxhome_link and test with :ofxget_link.',
    'comments' => 'commenti',

    'item_product' => 'Prodotto Articolo',
    'item_notes' => 'Note Articolo',
    'item_cost' => 'Costo Articolo',
    'item_quantity' => 'Quantità Articolo',
    'item_tax_rate' => 'Tasso d\'imposta Articolo',
    'item_tax_name' => 'Nome Tassa Articolo',
    'item_tax1' => 'Tassa 1 Articolo',
    'item_tax2' => 'Tassa 2 Articolo',

    'delete_company' => 'Elimina azienda',
    'delete_company_help' => 'Permanently delete the company along with all data and setting.',
    'delete_company_message' => 'Warning: This will permanently delete your company, there is no undo.',

    'applied_discount' => 'The coupon has been applied, the plan price has been reduced by :discount%.',
    'applied_free_year' => 'The coupon has been applied, your account has been upgraded to pro for one year.',

    'contact_us_help' => 'If you\'re reporting an error please include any relevant logs from storage/logs/laravel-error.log',
    'include_errors' => 'Includi errori',
    'include_errors_help' => 'Includi :link da storage/logs/laravel-error.log',
    'recent_errors' => 'errori recenti',
    'customer' => 'Cliente',
    'customers' => 'Clienti',
    'created_customer' => 'Cliente creato con successo',
    'created_customers' => 'Creati con successo :count clienti',

    'purge_details' => 'The data in your company (:account) has been successfully purged.',
    'deleted_company' => 'Azienda cancellata con successo',
    'deleted_account' => 'Account cancellato con successo',
    'deleted_company_details' => 'La tua azienda (:account) è stata cancellata con successo.',
    'deleted_account_details' => 'Your account (:account) has been successfully deleted.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'SEPA Direct Debit',
    'enable_alipay' => 'Accetta Alipay',
    'enable_sofort' => 'Accetta trasferimenti bancari EU',
    'stripe_alipay_help' => 'Queste piattaforme devono anche essere attivate in :link',
    'calendar' => 'Calendario',
    'pro_plan_calendar' => ':link to enable the calendar by joining the Pro Plan',

    'what_are_you_working_on' => 'Su cosa stai lavorando?',
    'time_tracker' => 'Time Tracker',
    'refresh' => 'Aggiorna',
    'filter_sort' => 'Filtra/Ordina',
    'no_description' => 'Nessuna descrizione',
    'time_tracker_login' => 'Time Tracker Login',
    'save_or_discard' => 'Save or discard your changes',
    'discard_changes' => 'Scarta modifiche',
    'tasks_not_enabled' => 'Le Attività non sono abilitate',
    'started_task' => 'Attività iniziata con successo',
    'create_client' => 'Crea nuovo cliente',

    'download_desktop_app' => 'Download the desktop app',
    'download_iphone_app' => 'Scarica l\'applicazione per iPhone',
    'download_android_app' => 'Download the Android app',
    'time_tracker_mobile_help' => 'Doppio tap sull\'attività per selezionarla',
    'stopped' => 'Fermato',
    'ascending' => 'Crescente',
    'descending' => 'Decrescente',
    'sort_field' => 'Ordina per',
    'sort_direction' => 'Direction',
    'discard' => 'Scarta',
    'time_am' => 'AM',
    'time_pm' => 'PM',
    'time_mins' => 'minuti',
    'time_hr' => 'ora',
    'time_hrs' => 'ore',
    'clear' => 'Clear',
    'warn_payment_gateway' => 'Nota: per accettare pagamenti online è necessaria una piattaforma di pagamento, :link per aggiungerne una.',
    'task_rate' => 'Tariffa per le  attività',
    'task_rate_help' => 'Imposta tariffa predefinita per le attività da fatturare',
    'past_due' => 'Scaduta',
    'document' => 'Documento',
    'invoice_or_expense' => 'Fattura/Spesa',
    'invoice_pdfs' => 'PDF della fattura',
    'enable_sepa' => 'Accetta SEPA',
    'enable_bitcoin' => 'Accetta Bitcoin',
    'iban' => 'IBAN',
    'sepa_authorization' => 'Fornendo il tuo IBAN e confermando questo pagamento, autorizzi :company e Stripe, il nostro fornitore di servizi di pagamento, a inviare istruzioni alla tua banca per addebitare il tuo conto e la tua banca ad addebitare il tuo conto in base a tali istruzioni. Hai diritto a un rimborso dalla tua banca secondo i termini e le condizioni del tuo accordo con la tua banca. Un rimborso deve essere richiesto entro 8 settimane a partire dalla data in cui il tuo conto è stato addebitato.',
    'recover_license' => 'Recupera licenza',
    'purchase' => 'Acquista',
    'recover' => 'Recupera',
    'apply' => 'Applica',
    'recover_white_label_header' => 'Recover White Label License',
    'apply_white_label_header' => 'Apply White Label License',
    'videos' => 'Video',
    'video' => 'Video',
    'return_to_invoice' => 'Ritorna alla fattura',
    'gateway_help_13' => 'To use ITN leave the PDT Key field blank.',
    'partial_due_date' => 'Partial Due Date',
    'task_fields' => 'Campi Attività',
    'product_fields_help' => 'Drag and drop fields to change their order',
    'custom_value1' => 'Valore Personalizzato',
    'custom_value2' => 'Valore Personalizzato',
    'enable_two_factor' => 'Autenticazione a due fattori',
    'enable_two_factor_help' => 'Usa il tuo telefono per confermare la tua identità quando accedi',
    'two_factor_setup' => 'Impostazione autenticazione a due fattori',
    'two_factor_setup_help' => 'Scan the bar code with a :link compatible app.',
    'one_time_password' => 'Password a uso singolo',
    'set_phone_for_two_factor' => 'Definite il vostro numero di telefono portatile come soluzione di backup.',
    'enabled_two_factor' => 'Successfully enabled Two-Factor Authentication',
    'add_product' => 'Aggiungi prodotto',
    'email_will_be_sent_on' => 'Note: the email will be sent on :date.',
    'invoice_product' => 'Fattura prodotto',
    'self_host_login' => 'Self-Host Login',
    'set_self_hoat_url' => 'Self-Host URL',
    'local_storage_required' => 'Error: local storage is not available.',
    'your_password_reset_link' => 'Il tuo link di reset password',
    'subdomain_taken' => 'The subdomain is already in use',
    'client_login' => 'Log-in cliente',
    'converted_amount' => 'Converted Amount',
    'default' => 'Default',
    'shipping_address' => 'Indirizzo di spedizione',
    'bllling_address' => 'Indirizzo di fatturazione',
    'billing_address1' => 'Via di fatturazione',
    'billing_address2' => 'App/scala di fatturazione',
    'billing_city' => 'Città di fatturazione',
    'billing_state' => 'Stato/Provincia di fatturazione',
    'billing_postal_code' => 'Codice postale di fatturazione',
    'billing_country' => 'Paese fatturazione',
    'shipping_address1' => 'Via di spedizione',
    'shipping_address2' => 'Piano/Appartamento di spedizione',
    'shipping_city' => 'Città di spedizione',
    'shipping_state' => 'Provincia di spedizione',
    'shipping_postal_code' => 'Codice Postale di spedizione',
    'shipping_country' => 'Paese di spedizione',
    'classify' => 'Classify',
    'show_shipping_address_help' => 'Richiedere al cliente di fornire il proprio indirizzo di spedizione',
    'ship_to_billing_address' => 'Inviare a indirizzo di fatturazione',
    'delivery_note' => 'Nota di consegna',
    'show_tasks_in_portal' => 'Mostra le Attività sul portale dei clienti',
    'cancel_schedule' => 'Cancel Schedule',
    'scheduled_report' => 'Scheduled Report',
    'scheduled_report_help' => 'Email the :report report as :format to :email',
    'created_scheduled_report' => 'Successfully scheduled report',
    'deleted_scheduled_report' => 'Successfully canceled scheduled report',
    'scheduled_report_attached' => 'Your scheduled :type report is attached.',
    'scheduled_report_error' => 'Failed to create schedule report',
    'invalid_one_time_password' => 'Password monouso non valida',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Accetta Apple Pay e Google Pay',
    'requires_subdomain' => 'Questo tipo di pagamento richiede che un :link.',
    'subdomain_is_set' => 'il sottodominio è impostato',
    'verification_file' => 'Verification File',
    'verification_file_missing' => 'Il file di verifica è necessario per accettare i pagamenti.',
    'apple_pay_domain' => 'Use <code>:domain</code> as the domain in :link.',
    'apple_pay_not_supported' => 'Siamo spiacenti, Apple/Google Pay non sono supportati dal tuo browser',
    'optional_payment_methods' => 'Metodi di pagamento opzionali',
    'add_subscription' => 'Aggiungi abbonamento',
    'target_url' => 'Target',
    'target_url_help' => 'When the selected event occurs the app will post the entity to the target URL.',
    'event' => 'Evento',
    'subscription_event_1' => 'Cliente creato',
    'subscription_event_2' => 'Fattura creata',
    'subscription_event_3' => 'Preventivo creato',
    'subscription_event_4' => 'Pagamento creato',
    'subscription_event_5' => 'Fornitore creato',
    'subscription_event_6' => 'Preventivo aggiornato',
    'subscription_event_7' => 'Preventivo cancellato',
    'subscription_event_8' => 'Fattura aggiornata',
    'subscription_event_9' => 'Fattura cancellata',
    'subscription_event_10' => 'Cliente aggiornato',
    'subscription_event_11' => 'Cliente cancellato',
    'subscription_event_12' => 'Pagamento cancellato',
    'subscription_event_13' => 'Fornitore aggiornato',
    'subscription_event_14' => 'Fornitore eliminato',
    'subscription_event_15' => 'Spesa creata',
    'subscription_event_16' => 'Spesa aggiornata',
    'subscription_event_17' => 'Spesa eliminata',
    'subscription_event_18' => 'Attività creata',
    'subscription_event_19' => 'Attività aggiornata',
    'subscription_event_20' => 'Attività cancellata',
    'subscription_event_21' => 'Preventivo approvato',
    'subscriptions' => 'Abbonamenti',
    'updated_subscription' => 'Abbonamento aggiornato con successo',
    'created_subscription' => 'Abbonamento creato con successo',
    'edit_subscription' => 'Modifica Abbonamento',
    'archive_subscription' => 'Archivia Abbonamento',
    'archived_subscription' => 'Abbonamento archiviato con successo',
    'project_error_multiple_clients' => 'I progetti non possono appartenere a clienti diversi',
    'invoice_project' => 'Fattura progetto',
    'module_recurring_invoice' => 'Fatture Ricorrenti',
    'module_credit' => 'Crediti',
    'module_quote' => 'Preventivi e Proposte',
    'module_task' => 'Attività e progetti',
    'module_expense' => 'Spese & fornitori',
    'module_ticket' => 'Tickets',
    'reminders' => 'Reminders',
    'send_client_reminders' => 'Send email reminders',
    'can_view_tasks' => 'le Attività sono visibili sul portale',
    'is_not_sent_reminders' => 'Reminders are not sent',
    'promotion_footer' => 'Your promotion will expire soon, :link to upgrade now.',
    'unable_to_delete_primary' => 'Note: to delete this company first delete all linked companies.',
    'please_register' => 'Per favore registra il tuo account',
    'processing_request' => 'Elaborando richiesta',
    'mcrypt_warning' => 'Warning: Mcrypt is deprecated, run :command to update your cipher.',
    'edit_times' => 'Edit Times',
    'inclusive_taxes_help' => 'Include <b>taxes in the cost</b>',
    'inclusive_taxes_notice' => 'Questa impostazione non può essere modificata una volta creata una fattura.',
    'inclusive_taxes_warning' => 'Attenzione: le fatture esistenti dovranno essere salvate di nuovo',
    'copy_shipping' => 'Copia Spedizione',
    'copy_billing' => 'Copia Fatturazione',
    'quote_has_expired' => 'Il preventivo è scaduto, si prega di contattare il responsabile.',
    'empty_table_footer' => 'Showing 0 to 0 of 0 entries',
    'do_not_trust' => 'Non ricordare questo dispositivo',
    'trust_for_30_days' => 'Ricorda per 30 giorni',
    'trust_forever' => 'Ricorda per sempre',
    'kanban' => 'Kanban',
    'backlog' => 'Backlog',
    'ready_to_do' => 'Ready to do',
    'in_progress' => 'In progress',
    'add_status' => 'Add status',
    'archive_status' => 'Archive Status',
    'new_status' => 'New Status',
    'convert_products' => 'Converti prodotti',
    'convert_products_help' => 'Converti automaticamenti i prezzi dei prodotti nella valuta del cliente',
    'improve_client_portal_link' => 'Set a subdomain to shorten the client portal link.',
    'budgeted_hours' => 'Ore preventivate',
    'progress' => 'Progresso',
    'view_project' => 'Vedi progetto',
    'summary' => 'Sommario',
    'endless_reminder' => 'Endless Reminder',
    'signature_on_invoice_help' => 'Add the following code to show your client\'s signature on the PDF.',
    'signature_on_pdf' => 'Mostra su PDF',
    'signature_on_pdf_help' => 'Mostra la firma del cliente sul PDF della fattura/preventivo.',
    'expired_white_label' => 'The white label license has expired',
    'return_to_login' => 'Ritorna al login',
    'convert_products_tip' => 'Note: add a :link named ":name" to see the exchange rate.',
    'amount_greater_than_balance' => 'L\'importo è superiore al saldo della fattura, verrà creato del credito con l\'importo rimanente.',
    'custom_fields_tip' => 'Use <code>Label|Option1,Option2</code> to show a select box.',
    'client_information' => 'Informazioni Cliente',
    'updated_client_details' => 'Dettagli cliente aggiornati con successo',
    'auto' => 'Auto',
    'tax_amount' => 'Tax Amount',
    'tax_paid' => '`Tassa pagata',
    'none' => 'None',
    'proposal_message_button' => 'To view your proposal for :amount, click the button below.',
    'proposal' => 'Proposte',
    'proposals' => 'Proposte',
    'list_proposals' => 'List Proposals',
    'new_proposal' => 'Nuova proposta',
    'edit_proposal' => 'Modifica proposta',
    'archive_proposal' => 'Archivia proposta',
    'delete_proposal' => 'Cancella proposta',
    'created_proposal' => 'Proposta creata con successo',
    'updated_proposal' => 'Proposta aggiornata con successo',
    'archived_proposal' => 'Proposta archiviata con successo',
    'deleted_proposal' => 'Proposta archiviata con successo',
    'archived_proposals' => ':count proposte archiviate con successo',
    'deleted_proposals' => ':count proposte archiviate con successo',
    'restored_proposal' => 'Proposta riprestinata con successo',
    'restore_proposal' => 'Riprestina proposta',
    'snippet' => 'Snippet',
    'snippets' => 'Snippets',
    'proposal_snippet' => 'Snippet',
    'proposal_snippets' => 'Snippets',
    'new_proposal_snippet' => 'New Snippet',
    'edit_proposal_snippet' => 'Edit Snippet',
    'archive_proposal_snippet' => 'Archive Snippet',
    'delete_proposal_snippet' => 'Delete Snippet',
    'created_proposal_snippet' => 'Successfully created snippet',
    'updated_proposal_snippet' => 'Successfully updated snippet',
    'archived_proposal_snippet' => 'Successfully archived snippet',
    'deleted_proposal_snippet' => 'Successfully archived snippet',
    'archived_proposal_snippets' => 'Successfully archived :count snippets',
    'deleted_proposal_snippets' => 'Successfully archived :count snippets',
    'restored_proposal_snippet' => 'Successfully restored snippet',
    'restore_proposal_snippet' => 'Restore Snippet',
    'template' => 'Modello',
    'templates' => 'Modelli',
    'proposal_template' => 'Modello',
    'proposal_templates' => 'Modelli',
    'new_proposal_template' => 'Nuovo Modello',
    'edit_proposal_template' => 'Modifica Modello',
    'archive_proposal_template' => 'Archivia Modello',
    'delete_proposal_template' => 'Elimina Modello',
    'created_proposal_template' => 'Modello creato con successo',
    'updated_proposal_template' => 'Modello aggiornato con successo',
    'archived_proposal_template' => 'Modello archiviato con successo',
    'deleted_proposal_template' => 'Modello archiviato con successo',
    'archived_proposal_templates' => ':count modelli archiviati con successo',
    'deleted_proposal_templates' => ':count modelli archiviati con successo',
    'restored_proposal_template' => 'Modello ripristinato con successo',
    'restore_proposal_template' => 'Ripristina Modello',
    'proposal_category' => 'Categoria',
    'proposal_categories' => 'Categorie',
    'new_proposal_category' => 'Nuova Categoria',
    'edit_proposal_category' => 'Modifica Categoria',
    'archive_proposal_category' => 'Archivia Categoria',
    'delete_proposal_category' => 'Elimina categoria',
    'created_proposal_category' => 'Categoria creata con successo',
    'updated_proposal_category' => 'Categoria aggiornata con successo',
    'archived_proposal_category' => 'Categoria archiviata con successo',
    'deleted_proposal_category' => 'Categoria archiviata con successo',
    'archived_proposal_categories' => 'Archiviato con successo :count categorie',
    'deleted_proposal_categories' => 'Archiviato con successo :count categorie',
    'restored_proposal_category' => 'Categoria ripristinata con successo',
    'restore_proposal_category' => 'Ripristina categoria',
    'delete_status' => 'Delete Status',
    'standard' => 'Standard',
    'icon' => 'Icona',
    'proposal_not_found' => 'La proposta richiesta non è disponibile',
    'create_proposal_category' => 'Crea categoria',
    'clone_proposal_template' => 'Clona Modello',
    'proposal_email' => 'Invia proposta',
    'proposal_subject' => 'Nuova proposta :number da :account',
    'proposal_message' => 'To view your proposal for :amount, click the link below.',
    'emailed_proposal' => 'Proposta inviata con successo',
    'load_template' => 'Carica Modello',
    'no_assets' => 'No images, drag to upload',
    'add_image' => 'Aggiungi Immagine',
    'select_image' => 'Seleziona Immagine',
    'upgrade_to_upload_images' => 'Upgrade to the enterprise plan to upload images',
    'delete_image' => 'Cancella Immagine',
    'delete_image_help' => 'Warning: deleting the image will remove it from all proposals.',
    'amount_variable_help' => 'Nota: il campo $amount della fattura userà il campo parziale/deposito se impostato, altrimenti verrà usato il saldo della fattura.',
    'taxes_are_included_help' => 'Note: Inclusive taxes have been enabled.',
    'taxes_are_not_included_help' => 'Note: Inclusive taxes are not enabled.',
    'change_requires_purge' => 'Changing this setting requires :link the account data.',
    'purging' => 'purging',
    'warning_local_refund' => 'Il rimborso verrà registrato nell\'applicazione ma NON sarà processato dalla piattaforma di pagamento.',
    'email_address_changed' => 'L\'indirizzo email è stato modificato',
    'email_address_changed_message' => 'The email address for your account has been changed from :old_email to :new_email.',
    'test' => 'Test',
    'beta' => 'Beta',
    'gmp_required' => 'Esportare su ZIP richiede l\'estensione GMP',
    'email_history' => 'Storico email',
    'loading' => 'Caricando',
    'no_messages_found' => 'Nessuno messaggio trovato',
    'processing' => 'Processing',
    'reactivate' => 'Riattiva',
    'reactivated_email' => 'The email address has been reactivated',
    'emails' => 'Emails',
    'opened' => 'Aperto',
    'bounced' => 'Bounced',
    'total_sent' => 'Totale inviato',
    'total_opened' => 'Totale aperto',
    'total_bounced' => 'Total Bounced',
    'total_spam' => 'Total Spam',
    'platforms' => 'Piattaforme',
    'email_clients' => 'Email Clients',
    'mobile' => 'Mobile',
    'desktop' => 'Desktop',
    'webmail' => 'Webmail',
    'group' => 'Gruppo',
    'subgroup' => 'Sottogruppo',
    'unset' => 'Unset',
    'received_new_payment' => 'Hai ricevuto un nuovo pagamento!',
    'slack_webhook_help' => 'Ricevi notifiche di pagamento utilizzando :link.',
    'slack_incoming_webhooks' => 'Slack incoming webhooks',
    'accept' => 'Accetta',
    'accepted_terms' => 'Accettato con successo gli ultimi termini di servizio',
    'invalid_url' => 'URL non valido',
    'workflow_settings' => 'Impostazioni Flusso di Lavoro',
    'auto_email_invoice' => 'Auto Email',
    'auto_email_invoice_help' => 'Invia automaticamente per email le fatture ricorrenti quando vengono create.',
    'auto_archive_invoice' => 'Auto Archiviazione',
    'auto_archive_invoice_help' => 'Archivia automaticamente le fatture quando vengono pagate.',
    'auto_archive_quote' => 'Auto Archiviazione',
    'auto_archive_quote_help' => 'Automatically archive quotes when they are converted.',
    'require_approve_quote' => 'Richiedi approvazione preventivo',
    'require_approve_quote_help' => 'Require clients to approve quotes.',
    'allow_approve_expired_quote' => 'Allow approve expired quote',
    'allow_approve_expired_quote_help' => 'Allow clients to approve expired quotes.',
    'invoice_workflow' => 'Flusso di Lavoro Fattura',
    'quote_workflow' => 'Flusso di Lavoro Preventivo',
    'client_must_be_active' => 'Error: the client must be active',
    'purge_client' => 'Purge Client',
    'purged_client' => 'Successfully purged client',
    'purge_client_warning' => 'Tutti i dati collegati (fatture, attività,lmente cancellati. spese, documenti, ecc) saranno ugualmente cancellati.',
    'clone_product' => 'Clona prodotto',
    'item_details' => 'Dettagli Articolo',
    'send_item_details_help' => 'Invia dettagli articoli alla piattaforma di pagamento.',
    'view_proposal' => 'Visualizza proposta',
    'view_in_portal' => 'Vedi nel portale',
    'cookie_message' => 'This website uses cookies to ensure you get the best experience on our website.',
    'got_it' => 'Capito!',
    'vendor_will_create' => 'fornitore verrà creato',
    'vendors_will_create' => 'fornitori verranno creati',
    'created_vendors' => 'Creato/i con successo :count venditore/i',
    'import_vendors' => 'Importa fornitori',
    'company' => 'Azienda',
    'client_field' => 'Campo Cliente',
    'contact_field' => 'Campo Contatti',
    'product_field' => 'Campo Prodotto',
    'task_field' => 'Campo attività',
    'project_field' => 'Campo Progetto',
    'expense_field' => 'Campo Spese',
    'vendor_field' => 'Campo Fornitore',
    'company_field' => 'Campo azienda',
    'invoice_field' => 'Campo fattura',
    'invoice_surcharge' => 'Sovrapprezzo Fattura',
    'custom_task_fields_help' => 'Aggiungere un campo alla creazione di attività',
    'custom_project_fields_help' => 'Aggiungi un campo alla creazione dei progetti.',
    'custom_expense_fields_help' => 'Aggiungi un campo alla creazione delle spese.',
    'custom_vendor_fields_help' => 'Aggiungi un campo alla creazione dei fornitori.',
    'messages' => 'Messaggi',
    'unpaid_invoice' => 'Fattura non pagata',
    'paid_invoice' => 'Fattura pagata',
    'unapproved_quote' => 'Preventivi non approvati',
    'unapproved_proposal' => 'Proposta non approvata',
    'autofills_city_state' => 'Riempi automaticamente la città/stato',
    'no_match_found' => 'Nessuna corrispondenza trovata',
    'password_strength' => 'Sicurezza Password',
    'strength_weak' => 'Debole',
    'strength_good' => 'Buona',
    'strength_strong' => 'Forte',
    'mark' => 'Segna',
    'updated_task_status' => 'Stato dell\'attività aggiornato con successo',
    'background_image' => 'Immagine di sfondo',
    'background_image_help' => 'Usa il :link per gestire le tue immagini, ti raccomandiamo di utilizzare file piccoli.',
    'proposal_editor' => 'proposal editor',
    'background' => 'Background',
    'guide' => 'Guida',
    'gateway_fee_item' => 'Articolo Commissione Piattaforma',
    'gateway_fee_description' => 'Sovraccarico Commissione Piattaforma',
    'gateway_fee_discount_description' => 'Sconto Commissione Piattaforma',
    'show_payments' => 'Mostra i pagamenti',
    'show_aging' => 'Show Aging',
    'reference' => 'Riferimento',
    'amount_paid' => 'Importo pagato',
    'send_notifications_for' => 'Invia notifiche per',
    'all_invoices' => 'Tutte le fatture',
    'my_invoices' => 'Le mie fatture',
    'payment_reference' => 'Riferimento di pagamento',
    'maximum' => 'Massimo',
    'sort' => 'Ordina',
    'refresh_complete' => 'Aggiornamento completi',
    'please_enter_your_email' => 'Inserisci la tua email',
    'please_enter_your_password' => 'Si prega di inserire la password',
    'please_enter_your_url' => 'Inserisci il tuo URL',
    'please_enter_a_product_key' => 'Inserire una chiave prodotto',
    'an_error_occurred' => 'An error occurred',
    'overview' => 'Panoramica',
    'copied_to_clipboard' => 'Copied :value to the clipboard',
    'error' => 'Errore',
    'could_not_launch' => 'Esecuzione non riuscita',
    'additional' => 'Aggiuntivo',
    'ok' => 'Ok',
    'email_is_invalid' => 'Email non valida',
    'items' => 'Articoli',
    'partial_deposit' => 'Parziale/Deposito',
    'add_item' => 'Aggiungi Articolo',
    'total_amount' => 'Ammontare Totale',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Stato della fattura',
    'click_plus_to_add_item' => 'Clicca su + per aggiungere un articolo',
    'count_selected' => ':count selected',
    'dismiss' => 'Chiudi',
    'please_select_a_date' => 'Selezionate una data per favore',
    'please_select_a_client' => 'Seleziona un cliente',
    'language' => 'Linguaggio',
    'updated_at' => 'Aggiornato',
    'please_enter_an_invoice_number' => 'Si prega di inserire un numero di fattura',
    'please_enter_a_quote_number' => 'Inserisci un numero preventivo',
    'clients_invoices' => 'fatture di :client',
    'viewed' => 'Visto',
    'approved' => 'Approvato',
    'invoice_status_1' => 'Bozza',
    'invoice_status_2' => 'Invia',
    'invoice_status_3' => 'Visto',
    'invoice_status_4' => 'Approvato',
    'invoice_status_5' => 'Parziale',
    'invoice_status_6' => 'Pagato',
    'marked_invoice_as_sent' => 'Fattura contrassegnata con successo come inviata',
    'please_enter_a_client_or_contact_name' => 'Si prega di inserire un cliente o nome del contatto',
    'restart_app_to_apply_change' => 'Riavviare la app per applicare il cambiamento',
    'refresh_data' => 'Aggiorna dati',
    'blank_contact' => 'Svuota Contatti',
    'no_records_found' => 'Nessun dato trovato',
    'industry' => 'Industria',
    'size' => 'Dimensione',
    'net' => 'Netto',
    'show_tasks' => 'Mostra attività',
    'email_reminders' => 'Email Reminders',
    'reminder1' => 'First Reminder',
    'reminder2' => 'Second Reminder',
    'reminder3' => 'Third Reminder',
    'send' => 'Invia',
    'auto_billing' => 'Fatturazione automatica',
    'button' => 'Pulsante',
    'more' => 'Altro',
    'edit_recurring_invoice' => 'Modifica Fattura Ricorrente',
    'edit_recurring_quote' => 'Modifica Preventivo Ricorrente',
    'quote_status' => 'Stato preventivo',
    'please_select_an_invoice' => 'Selezionate una fattura per favore',
    'filtered_by' => 'Filtrato per',
    'payment_status' => 'Stato del pagamento',
    'payment_status_1' => 'In attesa',
    'payment_status_2' => 'Annullato',
    'payment_status_3' => 'Fallito',
    'payment_status_4' => 'Completato',
    'payment_status_5' => 'Parzialmente rimborsato',
    'payment_status_6' => 'Rimborsato',
    'send_receipt_to_client' => 'Invia ricevuta al cliente',
    'refunded' => 'Rimborsato',
    'marked_quote_as_sent' => 'Successfully marked quote as sent',
    'custom_module_settings' => 'Custom Module Settings',
    'ticket' => 'Ticket',
    'tickets' => 'Tickets',
    'ticket_number' => 'Ticket #',
    'new_ticket' => 'Nuovo Ticket',
    'edit_ticket' => 'Modifica Ticket',
    'view_ticket' => 'Vedi Ticket',
    'archive_ticket' => 'Archivia Ticket',
    'restore_ticket' => 'Ripristina Ticket',
    'delete_ticket' => 'Elimina Ticket',
    'archived_ticket' => 'Successfully archived ticket',
    'archived_tickets' => 'Successfully archived tickets',
    'restored_ticket' => 'Successfully restored ticket',
    'deleted_ticket' => 'Successfully deleted ticket',
    'open' => 'Apri',
    'new' => 'Nuovo',
    'closed' => 'Chiuso',
    'reopened' => 'Riapri',
    'priority' => 'Priorità',
    'last_updated' => 'Ultimo aggiornamento',
    'comment' => 'Commenti',
    'tags' => 'Tag',
    'linked_objects' => 'Oggetti collegati',
    'low' => 'Basso',
    'medium' => 'Medio',
    'high' => 'Alto',
    'no_due_date' => 'Nessuna data di scadenza impostata',
    'assigned_to' => 'Assegnato a',
    'reply' => 'Rispondi',
    'awaiting_reply' => 'In attesa di risposta',
    'ticket_close' => 'Chiudi Ticket',
    'ticket_reopen' => 'Riapri Ticket',
    'ticket_open' => 'Apri Ticket',
    'ticket_split' => 'Dividi Ticket',
    'ticket_merge' => 'Unisci Ticket',
    'ticket_update' => 'Aggiorna Ticket',
    'ticket_settings' => 'Impostazioni Ticket',
    'updated_ticket' => 'Ticket Aggiornato',
    'mark_spam' => 'Segnala come Spam',
    'local_part' => 'Local Part',
    'local_part_unavailable' => 'Name taken',
    'local_part_available' => 'Nome disponibile',
    'local_part_invalid' => 'Nome invalido (solo alfanumerico, no spazi',
    'local_part_help' => 'Personalizza la parte locale della tua email di supporto in entrata, cioè TUO_NOME@support.invoiceninja.com',
    'from_name_help' => 'From name is the recognizable sender which is displayed instead of the email address, ie Support Center',
    'local_part_placeholder' => 'YOUR_NAME',
    'from_name_placeholder' => 'Centro di supporto',
    'attachments' => 'Allegati',
    'client_upload' => 'Caricamenti cliente',
    'enable_client_upload_help' => 'Allow clients to upload documents/attachments',
    'max_file_size_help' => 'Maximum file size (KB) is limited by your post_max_size and upload_max_filesize variables as set in your PHP.INI',
    'max_file_size' => 'Dimensione massima file',
    'mime_types' => 'Mime types',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Comma separated list of allowed mime types, leave blank for all',
    'ticket_number_start_help' => 'Il numero del ticket deve essere maggiore del numero di ticket corrente',
    'new_ticket_template_id' => 'Nuovo ticket',
    'new_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a new ticket is created',
    'update_ticket_template_id' => 'Ticket aggiornato',
    'update_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is updated',
    'close_ticket_template_id' => 'Ticket chiuso',
    'close_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is closed',
    'default_priority' => 'Priorità di default',
    'alert_new_comment_id' => 'Nuovo commento',
    'alert_comment_ticket_help' => 'Selecting a template will send a notification (to agent) when a comment is made.',
    'alert_comment_ticket_email_help' => 'Comma separated emails to bcc on new comment.',
    'new_ticket_notification_list' => 'Additional new ticket notifications',
    'update_ticket_notification_list' => 'Additional new comment notifications',
    'comma_separated_values' => 'admin@example.com, supervisor@example.com',
    'alert_ticket_assign_agent_id' => 'Ticket assignment',
    'alert_ticket_assign_agent_id_hel' => 'Selecting a template will send a notification (to agent) when a ticket is assigned.',
    'alert_ticket_assign_agent_id_notifications' => 'Additional ticket assigned notifications',
    'alert_ticket_assign_agent_id_help' => 'Comma separated emails to bcc on ticket assignment.',
    'alert_ticket_transfer_email_help' => 'Comma separated emails to bcc on ticket transfer.',
    'alert_ticket_overdue_agent_id' => 'Ticket overdue',
    'alert_ticket_overdue_email' => 'Additional overdue ticket notifications',
    'alert_ticket_overdue_email_help' => 'Comma separated emails to bcc on ticket overdue.',
    'alert_ticket_overdue_agent_id_help' => 'Selecting a template will send a notification (to agent) when a ticket becomes overdue.',
    'ticket_master' => 'Ticket Master',
    'ticket_master_help' => 'Has the ability to assign and transfer tickets. Assigned as the default agent for all tickets.',
    'default_agent' => 'Agente di default',
    'default_agent_help' => 'If selected will automatically be assigned to all inbound tickets',
    'show_agent_details' => 'Mostra i dettagli dell\'agente sulle risposte',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Rimuovi avatar',
    'ticket_not_found' => 'Ticket non trovato',
    'add_template' => 'Aggiungi Modello',
    'ticket_template' => 'Modello Ticket',
    'ticket_templates' => 'Modelli Ticket',
    'updated_ticket_template' => 'Modello Ticket Aggiornato',
    'created_ticket_template' => 'Modello Ticket Creato',
    'archive_ticket_template' => 'Archivia il modello',
    'restore_ticket_template' => 'Riprestina  il modello',
    'archived_ticket_template' => 'Modello archiviato con successo',
    'restored_ticket_template' => 'Modello ripristinato con successo',
    'close_reason' => 'Let us know why you are closing this ticket',
    'reopen_reason' => 'Let us know why you are reopening this ticket',
    'enter_ticket_message' => 'Please enter a message to update the ticket',
    'show_hide_all' => 'Mostra / Nascondi tutto',
    'subject_required' => 'Soggetto richiesto',
    'mobile_refresh_warning' => 'If you\'re using the mobile app you may need to do a full refresh.',
    'enable_proposals_for_background' => 'To upload a background image :link to enable the proposals module.',
    'ticket_assignment' => 'Ticket :ticket_number has been assigned to :agent',
    'ticket_contact_reply' => 'Ticket :ticket_number has been updated by client :contact',
    'ticket_new_template_subject' => 'Ticket :ticket_number has been created.',
    'ticket_updated_template_subject' => 'Ticket :ticket_number has been updated.',
    'ticket_closed_template_subject' => 'Ticket :ticket_number has been closed.',
    'ticket_overdue_template_subject' => 'Ticket :ticket_number is now overdue',
    'merge' => 'Unisci',
    'merged' => 'Unito',
    'agent' => 'Agente',
    'parent_ticket' => 'Parent Ticket',
    'linked_tickets' => 'Tickets collegati',
    'merge_prompt' => 'Enter ticket number to merge into',
    'merge_from_to' => 'Ticket #:old_ticket merged into Ticket #:new_ticket',
    'merge_closed_ticket_text' => 'Ticket #:old_ticket was closed and merged into Ticket#:new_ticket - :subject',
    'merge_updated_ticket_text' => 'Ticket #:old_ticket was closed and merged into this ticket',
    'merge_placeholder' => 'Merge ticket #:ticket into the following ticket',
    'select_ticket' => 'Seleziona ticket',
    'new_internal_ticket' => 'Nuovo ticket interno',
    'internal_ticket' => 'Ticket interno',
    'create_ticket' => 'Crea ticket',
    'allow_inbound_email_tickets_external' => 'New Tickets by email (Client)',
    'allow_inbound_email_tickets_external_help' => 'Allow clients to create new tickets by email',
    'include_in_filter' => 'Includi nel filtro',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Compara',
    'hosted_login' => 'Hosted Login',
    'selfhost_login' => 'Selfhost Login',
    'google_login' => 'Login Google',
    'thanks_for_patience' => 'Thank for your patience while we work to implement these features.\n\nWe hope to have them completed in the next few months.\n\nUntil then we\'ll continue to support the',
    'legacy_mobile_app' => 'legacy mobile app',
    'today' => 'Oggi',
    'current' => 'Corrente',
    'previous' => 'Precedente',
    'current_period' => 'Periodo corrente',
    'comparison_period' => 'Periodo di comparazione',
    'previous_period' => 'Periodo precedente',
    'previous_year' => 'Anno precedente',
    'compare_to' => 'Compara a',
    'last_week' => 'L\'ultima settimana',
    'clone_to_invoice' => 'Clona a fattura',
    'clone_to_quote' => 'Clona su preventivo',
    'convert' => 'Convertire',
    'last7_days' => 'Ultimi 7 giorni',
    'last30_days' => 'Ultimi 30 giorni',
    'custom_js' => 'JS personalizzato',
    'adjust_fee_percent_help' => 'Adjust percent to account for fee',
    'show_product_notes' => 'Mostra i dettagli del prodotto',
    'show_product_notes_help' => 'Includi la <b>descrizione ed il costo</b> nel menu a tendina del prodotto',
    'important' => 'Importante',
    'thank_you_for_using_our_app' => 'Grazie di avere scelto la nostra app!',
    'if_you_like_it' => 'If you like it please',
    'to_rate_it' => 'to rate it.',
    'average' => 'Media',
    'unapproved' => 'non approvato',
    'authenticate_to_change_setting' => 'Si prega di autenticarsi per cambiare questa impostazione',
    'locked' => 'Bloccato',
    'authenticate' => 'Autentica',
    'please_authenticate' => 'Si prega di autenticarsi',
    'biometric_authentication' => 'Biometric Authentication',
    'auto_start_tasks' => 'Partenza automaticha delle attività',
    'budgeted' => 'Preventivato',
    'please_enter_a_name' => 'Si prega di inserire un nome',
    'click_plus_to_add_time' => 'Premi + per aggiungere tempo',
    'design' => 'Stile',
    'password_is_too_short' => 'La password è troppo corta',
    'failed_to_find_record' => 'Impossibile trovare dati',
    'valid_until_days' => 'Valido fino a',
    'valid_until_days_help' => 'Automatically sets the <b>Valid Until</b> value on quotes to this many days in the future.  Leave blank to disable.',
    'usually_pays_in_days' => 'Giorni',
    'requires_an_enterprise_plan' => 'Requires an enterprise plan',
    'take_picture' => 'Fai foto',
    'upload_file' => 'Carica file',
    'new_document' => 'Nuovo documento',
    'edit_document' => 'Modifica documento',
    'uploaded_document' => 'Successfully uploaded document',
    'updated_document' => 'Successfully updated document',
    'archived_document' => 'Successfully archived document',
    'deleted_document' => 'Successfully deleted document',
    'restored_document' => 'Successfully restored document',
    'no_history' => 'Nessuno Storico',
    'expense_status_1' => 'Registrato',
    'expense_status_2' => 'In attesa',
    'expense_status_3' => 'Fatturata',
    'no_record_selected' => 'Nessun dato selezionato',
    'error_unsaved_changes' => 'Please save or cancel your changes',
    'thank_you_for_your_purchase' => 'Thank you for your purchase!',
    'redeem' => 'Redeem',
    'back' => 'Indietro',
    'past_purchases' => 'Acquisti passati',
    'annual_subscription' => 'Abbonamento Annuale',
    'pro_plan' => 'Pro Plan',
    'enterprise_plan' => 'Enterprise Plan',
    'count_users' => ':count utenti',
    'upgrade' => 'Aggiorna',
    'please_enter_a_first_name' => 'Si prega di inserire un nome',
    'please_enter_a_last_name' => 'Si prega di inserire un cognome',
    'please_agree_to_terms_and_privacy' => 'Si prega di accettare i termini di servizio e della privacy per creare un account.',
    'i_agree_to_the' => 'Accetto la',
    'terms_of_service_link' => 'Termini di servizio',
    'privacy_policy_link' => 'privacy policy',
    'view_website' => 'Visualizza sito web',
    'create_account' => 'Crea un account',
    'email_login' => 'Login email',
    'late_fees' => 'Late Fees',
    'payment_number' => 'Numero di pagamento',
    'before_due_date' => 'Prima della data di scadenza',
    'after_due_date' => 'After the due date',
    'after_invoice_date' => 'Dopo la data della fattura',
    'filtered_by_user' => 'Filtrato per utente',
    'created_user' => 'Utente creato con successo',
    'primary_font' => 'Font primario',
    'secondary_font' => 'Font secondario',
    'number_padding' => 'Number Padding',
    'general' => 'Generale',
    'surcharge_field' => 'Campo Sovrattassa',
    'company_value' => 'Valore azienda',
    'credit_field' => 'Campo Credito',
    'payment_field' => 'Campo Pagamento',
    'group_field' => 'Campo Gruppo',
    'number_counter' => 'Number Counter',
    'number_pattern' => 'Pattern numerico',
    'custom_javascript' => 'Javascript personalizzato',
    'portal_mode' => 'Modalità portale',
    'attach_pdf' => 'Allega PDF',
    'attach_documents' => 'Allega documenti',
    'attach_ubl' => 'Allega UBL',
    'email_style' => 'Stile Email',
    'processed' => 'Processato',
    'fee_amount' => 'Importo della tassa',
    'fee_percent' => 'Tassa Percentuale',
    'fee_cap' => 'Tassa massima',
    'limits_and_fees' => 'Limits/Fees',
    'credentials' => 'Credenziali',
    'require_billing_address_help' => 'Richiedere al cliente di fornire il suo indirizzo di fatturazione',
    'require_shipping_address_help' => 'Richiedere al cliente di fornire il proprio indirizzo di spedizione',
    'deleted_tax_rate' => 'Successfully deleted tax rate',
    'restored_tax_rate' => 'Successfully restored tax rate',
    'provider' => 'Provider',
    'company_gateway' => 'Piattaforma di Pagamento',
    'company_gateways' => 'Piattaforme di Pagamento',
    'new_company_gateway' => 'Nuova Piattaforma',
    'edit_company_gateway' => 'Modifica Piattaforma',
    'created_company_gateway' => 'Piattaforma creata con successo',
    'updated_company_gateway' => 'Piattaforma aggiornata con successo',
    'archived_company_gateway' => 'Piattaforma archiviata con successo',
    'deleted_company_gateway' => 'Piattaforma eliminata con successo',
    'restored_company_gateway' => 'Piattaforma ripristinata con successo',
    'continue_editing' => 'Continua la modifica',
    'default_value' => 'Valore di default',
    'currency_format' => 'Formato moneta',
    'first_day_of_the_week' => 'Primo giorno della settimana',
    'first_month_of_the_year' => 'Primo mese dell\'anno',
    'symbol' => 'Simbolo',
    'ocde' => 'Codice',
    'date_format' => 'Formato data',
    'datetime_format' => 'Formato data e ora',
    'send_reminders' => 'Send Reminders',
    'timezone' => 'Fuso Orario',
    'filtered_by_group' => 'Filtrato per gruppo',
    'filtered_by_invoice' => 'Filtrare per fattura',
    'filtered_by_client' => 'Filtrato per cliente',
    'filtered_by_vendor' => 'Filtrato per fornitore',
    'group_settings' => 'Impostazioni gruppo',
    'groups' => 'Gruppi',
    'new_group' => 'Nuovo gruppo',
    'edit_group' => 'Modifica gruppo',
    'created_group' => 'Gruppo creato con successo',
    'updated_group' => 'Gruppo aggiornato con successo',
    'archived_group' => 'Gruppo archiviato con successo',
    'deleted_group' => 'Gruppo cancellato con successo',
    'restored_group' => 'Gruppo ripristinato con successo',
    'upload_logo' => 'Carica logo',
    'uploaded_logo' => 'Logo caricato con successo',
    'saved_settings' => 'Impostazioni salvate con successo',
    'device_settings' => 'Impostazioni dispositivo',
    'credit_cards_and_banks' => 'Carte di credito & banche',
    'price' => 'Prezzo',
    'email_sign_up' => 'Registrati via Email',
    'google_sign_up' => 'Registrati con Google',
    'sign_up_with_google' => 'Accedi con Google',
    'long_press_multiselect' => 'Long-press Multiselect',
    'migrate_to_next_version' => 'Migrare alla prossima versione di Invoice Ninja',
    'migrate_intro_text' => 'Stiamo lavorando alla prossima versione di Invoice Ninja. Clicca il pulsante qui sotto per iniziare la migrazione.',
    'start_the_migration' => 'Inizia la migrazione',
    'migration' => 'Migrazione',
    'welcome_to_the_new_version' => 'Benvenuti nella nuova versione di Invoice Ninja',
    'next_step_data_download' => 'At the next step, we\'ll let you download your data for the migration.',
    'download_data' => 'Press button below to download the data.',
    'migration_import' => 'Awesome! Now you are ready to import your migration. Go to your new installation to import your data',
    'continue' => 'Continua',
    'company1' => 'Azienda Personalizzata 1',
    'company2' => 'Azienda Personalizzata 2',
    'company3' => 'Azienda Personalizzata 3',
    'company4' => 'Azienda Personalizzata 4',
    'product1' => 'Prodotto personalizzato 1',
    'product2' => 'Prodotto personalizzato 2',
    'product3' => 'Prodotto personalizzato 3',
    'product4' => 'Prodotto personalizzato 4',
    'client1' => 'Custom Client 1',
    'client2' => 'Custom Client 2',
    'client3' => 'Custom Client 3',
    'client4' => 'Custom Client 4',
    'contact1' => 'Custom Contact 1',
    'contact2' => 'Custom Contact 2',
    'contact3' => 'Custom Contact 3',
    'contact4' => 'Custom Contact 4',
    'task1' => 'Attività personalizzata 1',
    'task2' => 'Attività personalizzata 2',
    'task3' => 'Attività personalizzata 3',
    'task4' => 'Attività personalizzata 4',
    'project1' => 'Custom Project 1',
    'project2' => 'Custom Project 2',
    'project3' => 'Custom Project 3',
    'project4' => 'Custom Project 4',
    'expense1' => 'Custom Expense 1',
    'expense2' => 'Custom Expense 2',
    'expense3' => 'Custom Expense 3',
    'expense4' => 'Custom Expense 4',
    'vendor1' => 'Fornitore Personalizzato 1',
    'vendor2' => 'Fornitore Personalizzato 2',
    'vendor3' => 'Fornitore Personalizzato 3',
    'vendor4' => 'Fornitore Personalizzato 4',
    'invoice1' => 'Fattura Personalizzata 1',
    'invoice2' => 'Fattura Personalizzata 2',
    'invoice3' => 'Fattura Personalizzata 3',
    'invoice4' => 'Fattura Personalizzata 4',
    'payment1' => 'Pagamento personalizzato 1',
    'payment2' => 'Pagamento personalizzato 2',
    'payment3' => 'Pagamento personalizzato 3',
    'payment4' => 'Pagamento personalizzato 4',
    'surcharge1' => 'Sovrattassa personalizzata 1',
    'surcharge2' => 'Sovrattassa personalizzata 2',
    'surcharge3' => 'Sovrattassa personalizzata 3',
    'surcharge4' => 'Sovrattassa personalizzata 4',
    'group1' => 'Custom Group 1',
    'group2' => 'Custom Group 2',
    'group3' => 'Custom Group 3',
    'group4' => 'Custom Group 4',
    'number' => 'Numero',
    'count' => 'Count',
    'is_active' => 'È attivo',
    'contact_last_login' => 'Contact Last Login',
    'contact_full_name' => 'Contact Full Name',
    'contact_custom_value1' => 'Contact Custom Value 1',
    'contact_custom_value2' => 'Contact Custom Value 2',
    'contact_custom_value3' => 'Contact Custom Value 3',
    'contact_custom_value4' => 'Contact Custom Value 4',
    'assigned_to_id' => 'Assegnato all\'ID',
    'created_by_id' => 'Creato dall\'ID',
    'add_column' => 'Aggiungi Colonna',
    'edit_columns' => 'Modifica Colonne',
    'to_learn_about_gogle_fonts' => 'to learn about Google Fonts',
    'refund_date' => 'Data di rimborso',
    'multiselect' => 'Multi-selezione',
    'verify_password' => 'Verifica Password',
    'applied' => 'Applicato',
    'include_recent_errors' => 'Include recent errors from the logs',
    'your_message_has_been_received' => 'We have received your message and will try to respond promptly.',
    'show_product_details' => 'Mostra i dettagli del prodotto',
    'show_product_details_help' => 'Includi la descrizione ed il costo nel menu a tendina del prodotto',
    'pdf_min_requirements' => 'Il generatore di PDF richiede :version',
    'adjust_fee_percent' => 'Adjust Fee Percent',
    'configure_settings' => 'Configura Impostazioni',
    'about' => 'Info',
    'credit_email' => 'Credit Email',
    'domain_url' => 'URL dominio',
    'password_is_too_easy' => 'La password deve contenere una maiuscola ed un numero',
    'client_portal_tasks' => 'Attività del portale clienti',
    'client_portal_dashboard' => 'Pannello di Controllo Portale Clienti',
    'please_enter_a_value' => 'Per favore inserisci un valore',
    'deleted_logo' => 'Logo eliminato con successo',
    'generate_number' => 'Genera numero',
    'when_saved' => 'When Saved',
    'when_sent' => 'When Sent',
    'select_company' => 'Seleziona azienda',
    'float' => 'Float',
    'collapse' => 'Collapse',
    'show_or_hide' => 'Mostra/nascondi',
    'menu_sidebar' => 'Menu Sidebar',
    'history_sidebar' => 'Barra laterale storico',
    'tablet' => 'Tablet',
    'layout' => 'Layout',
    'module' => 'Module',
    'first_custom' => 'First Custom',
    'second_custom' => 'Second Custom',
    'third_custom' => 'Third Custom',
    'show_cost' => 'Mostra Costo',
    'show_cost_help' => 'Mostra un campo costo prodotto per tracciare il markup/profitto',
    'show_product_quantity' => 'Mostra quantità prodotto',
    'show_product_quantity_help' => 'Mostra un campo quantità prodotto, altrimenti imposta di default a 1',
    'show_invoice_quantity' => 'Mostra quantità fattura',
    'show_invoice_quantity_help' => 'Mostra un campo per la quantità degli articoli sulla riga, altrimenti imposta a uno',
    'default_quantity' => 'Default Quantity',
    'default_quantity_help' => 'Imposta automaticamente la quantità dell\'elemento nella riga ad uno',
    'one_tax_rate' => 'Una aliquota',
    'two_tax_rates' => 'Due aliquote',
    'three_tax_rates' => 'Tre aliquote',
    'default_tax_rate' => 'Aliquota di default',
    'invoice_tax' => 'Tassa fattura',
    'line_item_tax' => 'Riga imposta articolo',
    'inclusive_taxes' => 'Tasse inclusive',
    'invoice_tax_rates' => 'Aliquote della fattura',
    'item_tax_rates' => 'Tassi d\'imposta articolo',
    'configure_rates' => 'Configura aliquote',
    'tax_settings_rates' => 'Aliquote Fiscali',
    'accent_color' => 'Accent Color',
    'comma_sparated_list' => 'Lista separata da virgole',
    'single_line_text' => 'Testo a riga singola',
    'multi_line_text' => 'Testo multi-riga',
    'dropdown' => 'Menu a discesa',
    'field_type' => 'Tipo di campo',
    'recover_password_email_sent' => 'Una mail di recupero password è stata inviata',
    'removed_user' => 'Utente rimosso con successo',
    'freq_three_years' => 'Tre anni',
    'military_time_help' => 'Formato 24 ore',
    'click_here_capital' => 'Clicca qui',
    'marked_invoice_as_paid' => 'Fattura contrassegnata con successo come inviata',
    'marked_invoices_as_sent' => 'Fatture contrassegnate con successo come inviate',
    'marked_invoices_as_paid' => 'Fatture contrassegnate con successo come inviate',
    'activity_57' => 'Il sistema non è riuscito a inviare la fattura :invoice via e-mail',
    'custom_value3' => 'Custom Value 3',
    'custom_value4' => 'Custom Value 4',
    'email_style_custom' => 'Custom Email Style',
    'custom_message_dashboard' => 'Messaggio Pannello di Controllo Personalizzato',
    'custom_message_unpaid_invoice' => 'Messaggio personalizzato su fattura non pagata',
    'custom_message_paid_invoice' => 'Messaggio personalizzato fattura pagata',
    'custom_message_unapproved_quote' => 'Custom Unapproved Quote Message',
    'lock_sent_invoices' => 'Blocca le fatture inviate',
    'translations' => 'Traduzioni',
    'task_number_pattern' => 'Pattern numero attività',
    'task_number_counter' => 'Contatore numero attività',
    'expense_number_pattern' => 'Expense Number Pattern',
    'expense_number_counter' => 'Expense Number Counter',
    'vendor_number_pattern' => 'Vendor Number Pattern',
    'vendor_number_counter' => 'Vendor Number Counter',
    'ticket_number_pattern' => 'Ticket Number Pattern',
    'ticket_number_counter' => 'Ticket Number Counter',
    'payment_number_pattern' => 'Payment Number Pattern',
    'payment_number_counter' => 'Payment Number Counter',
    'invoice_number_pattern' => 'Pattern numerazione fatture',
    'quote_number_pattern' => 'Quote Number Pattern',
    'client_number_pattern' => 'Credit Number Pattern',
    'client_number_counter' => 'Credit Number Counter',
    'credit_number_pattern' => 'Credit Number Pattern',
    'credit_number_counter' => 'Credit Number Counter',
    'reset_counter_date' => 'Reset Counter Date',
    'counter_padding' => 'Counter Padding',
    'shared_invoice_quote_counter' => 'Contatore condiviso fatture/preventivi',
    'default_tax_name_1' => 'Default Tax Name 1',
    'default_tax_rate_1' => 'Default Tax Rate 1',
    'default_tax_name_2' => 'Default Tax Name 2',
    'default_tax_rate_2' => 'Default Tax Rate 2',
    'default_tax_name_3' => 'Default Tax Name 3',
    'default_tax_rate_3' => 'Default Tax Rate 3',
    'email_subject_invoice' => 'Oggetto della fattura e-mail',
    'email_subject_quote' => 'Email Quote Subject',
    'email_subject_payment' => 'Email Payment Subject',
    'switch_list_table' => 'Switch List Table',
    'client_city' => 'Città cliente',
    'client_state' => 'Stato cliente',
    'client_country' => 'Paese cliente',
    'client_is_active' => 'Il cliente è attivo',
    'client_balance' => 'Bilancio cliente',
    'client_address1' => 'Via del cliente',
    'client_address2' => 'Appartamento/Scala del cliente',
    'client_shipping_address1' => 'Via spedizione cliente',
    'client_shipping_address2' => 'Appartametno/Scala spedizione cliente',
    'tax_rate1' => 'Tax Rate 1',
    'tax_rate2' => 'Tax Rate 2',
    'tax_rate3' => 'Tax Rate 3',
    'archived_at' => 'Archived At',
    'has_expenses' => 'Has Expenses',
    'custom_taxes1' => 'Tasse Personalizzate 1',
    'custom_taxes2' => 'Tasse Personalizzate 2',
    'custom_taxes3' => 'Tasse Personalizzate 3',
    'custom_taxes4' => 'Tasse Personalizzate 4',
    'custom_surcharge1' => 'Sovrattassa personalizzata 1',
    'custom_surcharge2' => 'Sovrattassa personalizzata 2',
    'custom_surcharge3' => 'Sovrattassa personalizzata 3',
    'custom_surcharge4' => 'Sovrattassa personalizzata 4',
    'is_deleted' => 'È cancellato',
    'vendor_city' => 'Città Fornitore',
    'vendor_state' => 'Stato Fornitore',
    'vendor_country' => 'Paese fornitore',
    'credit_footer' => 'Credit Footer',
    'credit_terms' => 'Termini del Credito',
    'untitled_company' => 'Azienda senza nome',
    'added_company' => 'Azienda aggiunta con successo',
    'supported_events' => 'Supported Events',
    'custom3' => 'Third Custom',
    'custom4' => 'Fourth Custom',
    'optional' => 'Opzionale',
    'license' => 'Licenza',
    'invoice_balance' => 'Saldo della fattura',
    'saved_design' => 'Successfully saved design',
    'client_details' => 'Dettagli Cliente',
    'company_address' => 'Indirizzo azienda',
    'quote_details' => 'Dettagli Preventivo',
    'credit_details' => 'Dettagli Credito',
    'product_columns' => 'Colonne Prodotto',
    'task_columns' => 'Colonne attività',
    'add_field' => 'Aggiungi campo',
    'all_events' => 'Tutti gli eventi',
    'owned' => 'Posseduto',
    'payment_success' => 'Pagamento riuscito',
    'payment_failure' => 'Errore di pagamento',
    'quote_sent' => 'Preventivo inviato',
    'credit_sent' => 'Credito inviato',
    'invoice_viewed' => 'Fattura visualizzata',
    'quote_viewed' => 'Preventivo visualizzato',
    'credit_viewed' => 'Credito visualizzato',
    'quote_approved' => 'Preventivo approvato',
    'receive_all_notifications' => 'Ricevi tutte le notifiche',
    'purchase_license' => 'Acquista licenza',
    'enable_modules' => 'Attiva moduli',
    'converted_quote' => 'Preventivo convertito con successo',
    'credit_design' => 'Credit Design',
    'includes' => 'Includes',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Custom Designs',
    'designs' => 'Stili',
    'new_design' => 'New Design',
    'edit_design' => 'Edit Design',
    'created_design' => 'Successfully created design',
    'updated_design' => 'Successfully updated design',
    'archived_design' => 'Successfully archived design',
    'deleted_design' => 'Successfully deleted design',
    'removed_design' => 'Successfully removed design',
    'restored_design' => 'Successfully restored design',
    'recurring_tasks' => 'Attività ricorrenti',
    'removed_credit' => 'Successfully removed credit',
    'latest_version' => 'Latest Version',
    'update_now' => 'Aggiorna ora',
    'a_new_version_is_available' => 'A new version of the web app is available',
    'update_available' => 'Aggiornamento disponibile',
    'app_updated' => 'Aggiornamento completato con successo',
    'integrations' => 'Integrazioni',
    'tracking_id' => 'Id di tracciamento',
    'slack_webhook_url' => 'Slack Webhook URL',
    'partial_payment' => 'Pagamento parziale',
    'partial_payment_email' => 'Email di pagamento parziale',
    'clone_to_credit' => 'Clona su credito',
    'emailed_credit' => 'Successfully emailed credit',
    'marked_credit_as_sent' => 'Successfully marked credit as sent',
    'email_subject_payment_partial' => 'Oggetto e-mail pagamento parziale',
    'is_approved' => 'È approvato',
    'migration_went_wrong' => 'Ops, qualcosa è andato storto! Assicurati di aver impostato un\'istanza di Invoice Ninja v5 prima di iniziare la migrazione.',
    'cross_migration_message' => 'La migrazione incrociata degli account non è consentita. Per favore, leggi altro qui: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Email Credit',
    'client_email_not_set' => 'Il cliente non ha un indirizzo email impostato',
    'ledger' => 'Ledger',
    'view_pdf' => 'Vedi PDF',
    'all_records' => 'Tutti i dati',
    'owned_by_user' => 'Posseduto da utente',
    'credit_remaining' => 'Credit Remaining',
    'use_default' => 'Use default',
    'reminder_endless' => 'Endless Reminders',
    'number_of_days' => 'Number of days',
    'configure_payment_terms' => 'Configura termini di pagamento',
    'payment_term' => 'Termini di pagamento',
    'new_payment_term' => 'Nuovi termini di pagamento',
    'deleted_payment_term' => 'Termini di pagamento cancellati con successo',
    'removed_payment_term' => 'Termini di pagamento rimossi con successo',
    'restored_payment_term' => 'Termini di pagamento ripristinati con successo',
    'full_width_editor' => 'Full Width Editor',
    'full_height_filter' => 'Full Height Filter',
    'email_sign_in' => 'Sign in with email',
    'change' => 'Change',
    'change_to_mobile_layout' => 'Change to the mobile layout?',
    'change_to_desktop_layout' => 'Change to the desktop layout?',
    'send_from_gmail' => 'Send from Gmail',
    'reversed' => 'Reversed',
    'cancelled' => 'Cancelled',
    'quote_amount' => 'Quote Amount',
    'hosted' => 'Hosted',
    'selfhosted' => 'Self-Hosted',
    'hide_menu' => 'Nascondi menu',
    'show_menu' => 'Mostra menu',
    'partially_refunded' => 'Parzialmente rimborsato',
    'search_documents' => 'Cerca Documenti',
    'search_designs' => 'Search Designs',
    'search_invoices' => 'Cerca Fatture',
    'search_clients' => 'Cerca Clienti',
    'search_products' => 'Cerca Prodotti',
    'search_quotes' => 'Cerca Preventivi',
    'search_credits' => 'Cerca crediti',
    'search_vendors' => 'Cerca fornitori',
    'search_users' => 'Cerca utenti',
    'search_tax_rates' => 'Search Tax Rates',
    'search_tasks' => 'Cerca attività',
    'search_settings' => 'Cerca Impostazioni',
    'search_projects' => 'Cerca prodotti',
    'search_expenses' => 'Cerca spese',
    'search_payments' => 'Cerca pagamenti',
    'search_groups' => 'Cerca gruppi',
    'search_company' => 'Cerca Azienda',
    'cancelled_invoice' => 'Fattura annullata con successo',
    'cancelled_invoices' => 'Fatture annullate con successo',
    'reversed_invoice' => 'Fattura stornata con successo',
    'reversed_invoices' => 'Fatture stornate con successo',
    'reverse' => 'Reverse',
    'filtered_by_project' => 'Filtered by Project',
    'google_sign_in' => 'Sign in with Google',
    'activity_58' => ':user ha stornato la fattura :invoice',
    'activity_59' => ':user ha cancellato la fattura :invoice',
    'payment_reconciliation_failure' => 'Reconciliation Failure',
    'payment_reconciliation_success' => 'Reconciliation Success',
    'gateway_success' => 'Gateway Success',
    'gateway_failure' => 'Gateway Failure',
    'gateway_error' => 'Gateway Error',
    'email_send' => 'Email Send',
    'email_retry_queue' => 'Email Retry Queue',
    'failure' => 'Failure',
    'quota_exceeded' => 'Quota Exceeded',
    'upstream_failure' => 'Upstream Failure',
    'system_logs' => 'Registri di sistema',
    'copy_link' => 'Copia Collegamento',
    'welcome_to_invoice_ninja' => 'Benvenuti a Invoice Ninja',
    'optin' => 'Opt-In',
    'optout' => 'Opt-Out',
    'auto_convert' => 'Auto Convert',
    'reminder1_sent' => 'Reminder 1 Sent',
    'reminder2_sent' => 'Reminder 2 Sent',
    'reminder3_sent' => 'Reminder 3 Sent',
    'reminder_last_sent' => 'Reminder Last Sent',
    'pdf_page_info' => 'Pagina :current di :total',
    'emailed_credits' => 'Successfully emailed credits',
    'view_in_stripe' => 'View in Stripe',
    'rows_per_page' => 'Righe per pagina',
    'apply_payment' => 'Applica pagamento',
    'unapplied' => 'Unapplied',
    'custom_labels' => 'Etichette Personalizzate',
    'record_type' => 'Record Type',
    'record_name' => 'Record Name',
    'file_type' => 'File Type',
    'height' => 'Altezza',
    'width' => 'Larghezza',
    'health_check' => 'Health Check',
    'last_login_at' => 'Last Login At',
    'company_key' => 'Chiave azienda',
    'storefront' => 'Storefront',
    'storefront_help' => 'Permetti alle app di terze parti di creare fatture',
    'count_records_selected' => ':count records selected',
    'count_record_selected' => ':count record selected',
    'client_created' => 'Cliente creato',
    'online_payment_email' => 'Email di pagamento online',
    'manual_payment_email' => 'Email di pagamento manuale',
    'completed' => 'Completato',
    'gross' => 'Lordo',
    'net_amount' => 'Cifra al netto',
    'net_balance' => 'Bilancio Netto',
    'client_settings' => 'Impostazioni Cliente',
    'selected_invoices' => 'Fatture Selezionate',
    'selected_payments' => 'Pagamenti selezionati',
    'selected_quotes' => 'Preventivi Selezionati',
    'selected_tasks' => 'Attività Selezionate',
    'selected_expenses' => 'Spese Selezionate',
    'past_due_invoices' => 'Fatture scadute',
    'create_payment' => 'Crea pagamento',
    'update_quote' => 'Aggiorna Preventivo',
    'update_invoice' => 'Aggiorna Fattura',
    'update_client' => 'Aggiorna Cliente',
    'update_vendor' => 'Aggiorna Fornitore',
    'create_expense' => 'Crea Spesa',
    'update_expense' => 'Aggiorna Spesa',
    'update_task' => 'Aggiorna Attività',
    'approve_quote' => 'Aggiorna Preventivo',
    'when_paid' => 'Quando Pagato',
    'expires_on' => 'Scade il',
    'show_sidebar' => 'Mostra Barra Laterale',
    'hide_sidebar' => 'Nascondi Barra Laterale',
    'event_type' => 'Tipo Evento',
    'copy' => 'Copia',
    'must_be_online' => 'Please restart the app once connected to the internet',
    'crons_not_enabled' => 'The crons need to be enabled',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Search :count Webhooks',
    'search_webhook' => 'Search 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'New Webhook',
    'edit_webhook' => 'Edit Webhook',
    'created_webhook' => 'Successfully created webhook',
    'updated_webhook' => 'Successfully updated webhook',
    'archived_webhook' => 'Successfully archived webhook',
    'deleted_webhook' => 'Successfully deleted webhook',
    'removed_webhook' => 'Successfully removed webhook',
    'restored_webhook' => 'Successfully restored webhook',
    'search_tokens' => 'Search :count Tokens',
    'search_token' => 'Search 1 Token',
    'new_token' => 'New Token',
    'removed_token' => 'Successfully removed token',
    'restored_token' => 'Successfully restored token',
    'client_registration' => 'Registazione cliente',
    'client_registration_help' => 'Permetti al cliente di registrarsi da solo nel portale',
    'customize_and_preview' => 'Personalizza & Anterpima',
    'search_document' => 'Cerca 1 documento',
    'search_design' => 'Cerca 1 stile',
    'search_invoice' => 'Cerca 1 fattura',
    'search_client' => 'Cerca 1 cliente',
    'search_product' => 'Cerca 1 prodotto',
    'search_quote' => 'Cerca 1 preventivo',
    'search_credit' => 'Cerca 1 credito',
    'search_vendor' => 'Cerca 1 Fornitore',
    'search_user' => 'Cerca 1 utente',
    'search_tax_rate' => 'Search 1 Tax Rate',
    'search_task' => 'Cerca 1 attività',
    'search_project' => 'Search 1 Project',
    'search_expense' => 'Search 1 Expense',
    'search_payment' => 'Cerca 1 pagamento',
    'search_group' => 'Search 1 Group',
    'created_on' => 'Creato il',
    'payment_status_-1' => 'Non applicato',
    'lock_invoices' => 'Blocca fatture',
    'show_table' => 'Mostra Tabella',
    'show_list' => 'Mostra Lista',
    'view_changes' => 'Vedi modifiche',
    'force_update' => 'Forza aggiornamento',
    'force_update_help' => 'Stai eseguendo l\'ultima versione, ma potrebbero essere disponibili dei fix in attesa.',
    'mark_paid_help' => 'Track the expense has been paid',
    'mark_invoiceable_help' => 'Permetti la fatturazione delle spese',
    'add_documents_to_invoice_help' => 'Make the documents visible',
    'convert_currency_help' => 'Imposta un tasso di cambio',
    'expense_settings' => 'Impostazioni Spese',
    'clone_to_recurring' => 'Clone to Recurring',
    'crypto' => 'Crypto',
    'user_field' => 'User Field',
    'variables' => 'Variabili',
    'show_password' => 'Mostra Password',
    'hide_password' => 'Nascondi Password',
    'copy_error' => 'Copia Errore',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Fattura automatica abilitata',
    'total_taxes' => 'Totale Tasse',
    'line_taxes' => 'Riga tasse',
    'total_fields' => 'Campi Totale',
    'stopped_recurring_invoice' => 'Fermata con successo la fattura ricorrente',
    'started_recurring_invoice' => 'Fattura ricorrente avviata con successo',
    'resumed_recurring_invoice' => 'Fattura ricorrente ripresa con successo',
    'gateway_refund' => 'Gateway Refund',
    'gateway_refund_help' => 'Process the refund with the payment gateway',
    'due_date_days' => 'Due Date',
    'paused' => 'Pausato',
    'day_count' => 'Giorno :count',
    'first_day_of_the_month' => 'First Day of the Month',
    'last_day_of_the_month' => 'Last Day of the Month',
    'use_payment_terms' => 'Usa termini di pagamento',
    'endless' => 'Endless',
    'next_send_date' => 'Prossima data di invio',
    'remaining_cycles' => 'Cicli restanti',
    'created_recurring_invoice' => 'Fattura ricorrente creata con successo',
    'updated_recurring_invoice' => 'Fattura ricorrente aggiornata con successo',
    'removed_recurring_invoice' => 'Fattura ricorrente rimossa con successo',
    'search_recurring_invoice' => 'Cerca 1 fattura ricorrente',
    'search_recurring_invoices' => 'Cerca :count Fatture ricorrenti',
    'send_date' => 'Data di invio',
    'auto_bill_on' => 'Fattura automatica attiva',
    'minimum_under_payment_amount' => 'Minimum Under Payment Amount',
    'allow_over_payment' => 'Consenti pagamento in eccesso',
    'allow_over_payment_help' => 'Supporta il pagamento di un extra per accettare le mance',
    'allow_under_payment' => 'Consenti pagamento ridotto',
    'allow_under_payment_help' => 'Support paying at minimum the partial/deposit amount',
    'test_mode' => 'Test Mode',
    'calculated_rate' => 'Calculated Rate',
    'default_task_rate' => 'Tasso predefinito di attività ',
    'clear_cache' => 'Clear Cache',
    'sort_order' => 'Sort Order',
    'task_status' => 'Stato',
    'task_statuses' => 'Stati attività',
    'new_task_status' => 'Nuovo stato attività',
    'edit_task_status' => 'Modifica stato attività',
    'created_task_status' => 'Successfully created task status',
    'archived_task_status' => 'Successfully archived task status',
    'deleted_task_status' => 'Successfully deleted task status',
    'removed_task_status' => 'Successfully removed task status',
    'restored_task_status' => 'Successfully restored task status',
    'search_task_status' => 'Search 1 Task Status',
    'search_task_statuses' => 'Search :count Task Statuses',
    'show_tasks_table' => 'Show Tasks Table',
    'show_tasks_table_help' => 'Mostra sempre la sezione delle attività quando si creano le fatture',
    'invoice_task_timelog' => 'Timelog delle attività di fatturazione',
    'invoice_task_timelog_help' => 'Aggiungere i dettagli sull\'orario alle voci della fattura',
    'auto_start_tasks_help' => 'Start tasks before saving',
    'configure_statuses' => 'Configure Statuses',
    'task_settings' => 'Impostazioni attività',
    'configure_categories' => 'Configura Categorie',
    'edit_expense_category' => 'Modifica Categoria di Spesa',
    'removed_expense_category' => 'Categoria di spesa rimossa con successo',
    'search_expense_category' => 'Cerca 1 categoria di spesa',
    'search_expense_categories' => 'Cerca :count categorie di spesa',
    'use_available_credits' => 'Use Available Credits',
    'show_option' => 'Mostra opzione',
    'negative_payment_error' => 'The credit amount cannot exceed the payment amount',
    'should_be_invoiced_help' => 'Permettere la fatturazione della spesa',
    'configure_gateways' => 'Configure Gateways',
    'payment_partial' => 'Partial Payment',
    'is_running' => 'Is Running',
    'invoice_currency_id' => 'ID Valuta Fattura',
    'tax_name1' => 'Nome tassa 1',
    'tax_name2' => 'Nome tassa 2',
    'transaction_id' => 'ID transazione',
    'invoice_late' => 'Fattura in ritardo',
    'quote_expired' => 'Preventivo scaduto',
    'recurring_invoice_total' => 'Totale fattura',
    'actions' => 'Azioni',
    'expense_number' => 'Numero spesa',
    'task_number' => 'Numero attività',
    'project_number' => 'Numero progetto',
    'view_settings' => 'View Settings',
    'company_disabled_warning' => 'Attenzione: questa azienda non è ancora stata attivata',
    'late_invoice' => 'Fattura in ritardo',
    'expired_quote' => 'Preventivo scaduto',
    'remind_invoice' => 'Ricorda fattura',
    'client_phone' => 'Telefono cliente',
    'required_fields' => 'Campi richiesti',
    'enabled_modules' => 'Moduli abilitati',
    'activity_60' => ':contact ha visualizzato il preventivo :quote',
    'activity_61' => ':user ha aggiornato il cliente :client',
    'activity_62' => ':user ha aggiornato il fornitore :vendor',
    'activity_63' => ':user ha inviato il primo promemoria per la fattura :invoice a :contact',
    'activity_64' => ':user ha inviato un secondo promemoria per la fattura :invoice a :contact',
    'activity_65' => ':user ha inviato il terzo promemoria per la fattura :invoice a :contact',
    'activity_66' => ':user ha inviato un promemoria ricorrente per la fattura :invoice a :contact',
    'expense_category_id' => 'ID della categoria di spesa',
    'view_licenses' => 'Visualizza le licenze',
    'fullscreen_editor' => 'Editor a schermo intero',
    'sidebar_editor' => 'Editor barra laterale',
    'please_type_to_confirm' => 'Digita ":value" per confermare',
    'purge' => 'Purge',
    'clone_to' => 'Clone To',
    'clone_to_other' => 'Clona su altro',
    'labels' => 'Etichette',
    'add_custom' => 'Add Custom',
    'payment_tax' => 'Payment Tax',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Le fatture inviate sono bloccate',
    'paid_invoices_are_locked' => 'Le fatture pagate sono bloccate',
    'source_code' => 'Codice Sorgente',
    'app_platforms' => 'App Platforms',
    'archived_task_statuses' => 'Successfully archived :value task statuses',
    'deleted_task_statuses' => 'Successfully deleted :value task statuses',
    'restored_task_statuses' => 'Successfully restored :value task statuses',
    'deleted_expense_categories' => 'Eliminate con successo :value categorie di spesa',
    'restored_expense_categories' => 'Ripristinate con successo :value categorie di spesa',
    'archived_recurring_invoices' => 'Archiviato con successo :value fatture ricorrenti ',
    'deleted_recurring_invoices' => 'Cancellato con successo :value fatture ricorrenti',
    'restored_recurring_invoices' => 'Ripristinato con successo :value fatture ricorrenti',
    'archived_webhooks' => 'Successfully archived :value webhooks',
    'deleted_webhooks' => 'Successfully deleted :value webhooks',
    'removed_webhooks' => 'Successfully removed :value webhooks',
    'restored_webhooks' => 'Successfully restored :value webhooks',
    'api_docs' => 'API Docs',
    'archived_tokens' => 'Successfully archived :value tokens',
    'deleted_tokens' => 'Successfully deleted :value tokens',
    'restored_tokens' => 'Successfully restored :value tokens',
    'archived_payment_terms' => 'Successfully archived :value payment terms',
    'deleted_payment_terms' => 'Successfully deleted :value payment terms',
    'restored_payment_terms' => 'Successfully restored :value payment terms',
    'archived_designs' => 'Successfully archived :value designs',
    'deleted_designs' => 'Successfully deleted :value designs',
    'restored_designs' => 'Successfully restored :value designs',
    'restored_credits' => 'Successfully restored :value credits',
    'archived_users' => 'Successfully archived :value users',
    'deleted_users' => 'Successfully deleted :value users',
    'removed_users' => 'Successfully removed :value users',
    'restored_users' => 'Successfully restored :value users',
    'archived_tax_rates' => 'Successfully archived :value tax rates',
    'deleted_tax_rates' => 'Successfully deleted :value tax rates',
    'restored_tax_rates' => 'Successfully restored :value tax rates',
    'archived_company_gateways' => 'Successfully archived :value gateways',
    'deleted_company_gateways' => 'Successfully deleted :value gateways',
    'restored_company_gateways' => 'Successfully restored :value gateways',
    'archived_groups' => 'Successfully archived :value groups',
    'deleted_groups' => 'Successfully deleted :value groups',
    'restored_groups' => 'Successfully restored :value groups',
    'archived_documents' => 'Successfully archived :value documents',
    'deleted_documents' => 'Successfully deleted :value documents',
    'restored_documents' => 'Successfully restored :value documents',
    'restored_vendors' => 'Ripristinati con successo :value fornitori',
    'restored_expenses' => 'Successfully restored :value expenses',
    'restored_tasks' => 'Successfully restored :value tasks',
    'restored_projects' => 'Successfully restored :value projects',
    'restored_products' => 'Ripristinati con successo :value prodotti',
    'restored_clients' => 'Successfully restored :value clients',
    'restored_invoices' => 'Ripristinato con successo :value fatture',
    'restored_payments' => 'Successfully restored :value payments',
    'restored_quotes' => 'Successfully restored :value quotes',
    'update_app' => 'Aggiorna App',
    'started_import' => 'Successfully started import',
    'duplicate_column_mapping' => 'Duplicate column mapping',
    'uses_inclusive_taxes' => 'Usa tasse inclusive',
    'is_amount_discount' => 'Is Amount Discount',
    'map_to' => 'Map To',
    'first_row_as_column_names' => 'Use first row as column names',
    'no_file_selected' => 'No File Selected',
    'import_type' => 'Import Type',
    'draft_mode' => 'Draft Mode',
    'draft_mode_help' => 'Preview updates faster but is less accurate',
    'show_product_discount' => 'Mostra sconto prodotto',
    'show_product_discount_help' => 'Mostra un campo sconto articolo sulla riga',
    'tax_name3' => 'Tax Name 3',
    'debug_mode_is_enabled' => 'Debug mode is enabled',
    'debug_mode_is_enabled_help' => 'Warning: it is intended for use on local machines, it can leak credentials. Click to learn more.',
    'running_tasks' => 'Attività in corso',
    'recent_tasks' => 'Attività Recenti',
    'recent_expenses' => 'Spese Recenti',
    'upcoming_expenses' => 'Spese in arrivo',
    'search_payment_term' => 'Ricerca 1 Termine di pagamento',
    'search_payment_terms' => 'Cerca :count termini di pagamento',
    'save_and_preview' => 'Salva e mostra anteprima',
    'save_and_email' => 'Salva e invia e-mail',
    'converted_balance' => 'Converted Balance',
    'is_sent' => 'È inviato',
    'document_upload' => 'Caricamento Documenti',
    'document_upload_help' => 'Permettere ai clienti di caricare documenti',
    'expense_total' => 'Totale Spese',
    'enter_taxes' => 'Inserire tasse',
    'by_rate' => 'Per tasso',
    'by_amount' => 'Per ammontare',
    'enter_amount' => 'Inserire importo',
    'before_taxes' => 'Prima delle tasse',
    'after_taxes' => 'Dopo le tasse',
    'color' => 'Colore',
    'show' => 'Mostra',
    'empty_columns' => 'Colonne vuote',
    'project_name' => 'Nome progetto',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'This Quarter',
    'to_update_run' => 'To update run',
    'registration_url' => 'URL di registrazione',
    'show_product_cost' => 'Mostra costo prodotto',
    'complete' => 'Completa',
     'next' => 'Successivo',
     'next_step' => 'Avanti',
     'notification_credit_sent_subject' => 'Il credito :invoice è stato inviato a :client',
     'notification_credit_viewed_subject' => 'Il credito :invoice è stato visto da :client',
     'notification_credit_sent' => 'Al cliente :client è stata inviata per email la fattura :invoice per :amount.',
     'notification_credit_viewed' => 'Il cliente :client ha visualizzato il credito :credit per :amount.',
     'reset_password_text' => 'Inserire la mail per resettare la password.',
     'password_reset' => 'Reset password',
     'account_login_text' => 'Welcome back! Glad to see you.',
     'request_cancellation' => 'Richiedi Cancellazione',
     'delete_payment_method' => 'Elimina il metodo di pagamento',
     'about_to_delete_payment_method' => 'You are about to delete the payment method.',
     'action_cant_be_reversed' => 'Action can\'t be reversed',
     'profile_updated_successfully' => 'The profile has been updated successfully.',
     'currency_ethiopian_birr' => 'Ethiopian Birr',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Stato fattura',
     'email_already_register' => 'This email is already linked to an account',
     'locations' => 'Locations',
     'freq_indefinitely' => 'Indefinitely',
     'cycles_remaining' => 'Cicli restanti',
     'i_understand_delete' => 'Capisco, cancella',
     'download_files' => 'Scarica files',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'Nuova Iscrizione',
     'new_signup_text' => 'A new account has been created by :user - :email - from IP address: :ip',
     'notification_payment_paid_subject' => 'Pagamento effettuato da :client',
     'notification_partial_payment_paid_subject' => 'Pagamento parziale effettuato da :client',
     'notification_payment_paid' => 'Un pagamento di :amount è stato fatto dal cliente :client per la fattura :invoice',
     'notification_partial_payment_paid' => 'Un pagamento parziale di :amount è stato fatto dal cliente :client verso :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Fattura # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Display Log',
     'send_fail_logs_to_our_server' => 'Report errors in realtime',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Aggiorna le tue informazioni personali',
     'name_website_logo' => 'Nome, sito web e logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Indirizzo personale',
     'enter_your_personal_address' => 'Inserisci il tuo indirizzo personale',
     'enter_your_shipping_address' => 'Inserire l\'indirizzo di spedizione',
     'list_of_invoices' => 'Elenco di fatture',
     'with_selected' => 'With selected',
     'invoice_still_unpaid' => 'Questa fattura non è ancora stata pagata. Fare clic sul pulsante per completare il pagamento',
     'list_of_recurring_invoices' => 'Elenco delle fatture ricorrenti',
     'details_of_recurring_invoice' => 'Di seguito sono riportati alcuni dettagli sulla fattura ricorrente',
     'cancellation' => 'Cancellazione',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Attenzione! Stai richiedendo la cancellazione di questo servizio.\n Il tuo servizio può essere cancellato senza ulteriori notifiche a te.',
     'cancellation_pending' => 'Cancellazione in corso, ci metteremo in contatto!',
     'list_of_payments' => 'Elenco dei pagamenti',
     'payment_details' => 'Dettagli del pagamento',
     'list_of_payment_invoices' => 'Elenco delle fatture interessate dal pagamento',
     'list_of_payment_methods' => 'Elenco dei metodi di pagamento',
     'payment_method_details' => 'Dettagli del metodo di pagamento',
     'permanently_remove_payment_method' => 'Rimuovi definitivamente questo metodo di pagamento.',
     'warning_action_cannot_be_reversed' => 'Attenzione! Questa azione non può essere annullata!',
     'confirmation' => 'Conferma',
     'list_of_quotes' => 'Preventivi',
     'waiting_for_approval' => 'In attesa di approvazione',
     'quote_still_not_approved' => 'Questo preventivo non è ancora approvato',
     'list_of_credits' => 'Crediti',
     'required_extensions' => 'Estensioni richieste',
     'php_version' => 'Versione PHP',
     'writable_env_file' => 'File .env scrivibile',
     'env_not_writable' => 'Il file .env non è scrivibile dall\'utente corrente.',
     'minumum_php_version' => 'Versione minima di PHP',
     'satisfy_requirements' => 'Assicurati che tutti i requisiti siano soddisfatti.',
     'oops_issues' => 'Ops, qualcosa non quadra!',
     'open_in_new_tab' => 'Aprire in una nuova scheda',
     'complete_your_payment' => 'Completa il pagamento',
     'authorize_for_future_use' => 'Autorizza il metodo di pagamento per un utilizzo futuro',
     'page' => 'Pagina',
     'per_page' => 'Per pagina',
     'of' => 'Di',
     'view_credit' => 'Vedi Credito',
     'to_view_entity_password' => 'Inserisci la password per vedere :entity.',
     'showing_x_of' => 'Mostrando da :first a :last su :total risultati',
     'no_results' => 'Nessun risultato trovato.',
     'payment_failed_subject' => 'Pagamento non riuscito per il cliente :client',
     'payment_failed_body' => 'Un pagamento effettuato dal cliente :client non è riuscito, con il messaggio :message',
     'register' => 'Registrati',
     'register_label' => 'Crea il tuo account in pochi secondi',
     'password_confirmation' => 'Conferma la tua password',
     'verification' => 'Verifica',
     'complete_your_bank_account_verification' => 'Prima di usare un conto bancario deve essere verificato.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Il numero di carta di credito fornito non è valido.',
     'month_invalid' => 'Il mese inserito non è valido.',
     'year_invalid' => 'L\'anno inserito non è valido.',
     'https_required' => 'È richiesto HTTPS, il modulo fallirà',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'Dopo l\'aggiornamento della password, il tuo account verrà confermato.',
     'bank_account_not_linked' => 'Per pagare con un conto bancario, devi prima aggiungerlo come metodo di pagamento.',
     'application_settings_label' => 'Memorizziamo le informazioni di base sul tuo Invoice Ninja!',
     'recommended_in_production' => 'Altamente raccomandato in produzione',
     'enable_only_for_development' => 'Attiva solo per lo sviluppo',
     'test_pdf' => 'Testa PDF',
     'checkout_authorize_label' => 'Checkout.com può essere salvato come metodo di pagamento per uso futuro, una volta completata la prima transazione. Non dimenticare di impostare "Memorizza i dettagli della carta di credito" durante il processo di pagamento.',
     'sofort_authorize_label' => 'Il conto bancario (SOFORT) può essere salvato come metodo di pagamento per usi futuri, una volta completata la prima transazione. Non dimenticare di impostare "Memorizza i dettagli del pagamento" durante il processo di pagamento.',
     'node_status' => 'Stato di Node',
     'npm_status' => 'Stato di NPM',
     'node_status_not_found' => 'Non sono riuscito a trovare Node da nessuna parte. È installato?',
     'npm_status_not_found' => 'Non ho trovato NPM da nessuna parte. È installato?',
     'locked_invoice' => 'Questa fattura è bloccata e non può essere modificata',
     'downloads' => 'Downloads',
     'resource' => 'Resource',
     'document_details' => 'Dettagli sul documento',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Allowed file types:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Scarica selezione',
     'to_pay_invoices' => 'Per pagare le fatture, si deve',
     'add_payment_method_first' => 'aggiungi metodo di pagamento',
     'no_items_selected' => 'Nessun articolo selezionato',
     'payment_due' => 'Pagamento dovuto',
     'account_balance' => 'Saldo del conto',
     'thanks' => 'Grazie',
     'minimum_required_payment' => 'Minimum required payment is :amount',
     'under_payments_disabled' => 'L\'azienda non supporta i sotto-pagamenti',
     'over_payments_disabled' => 'L\'azienda non supporta i sovra-pagamenti',
     'saved_at' => 'Saved at :time',
     'credit_payment' => 'Credito applicato alla fattura :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Criptovaluta',
     'payment_type_Credit' => 'Credito',
     'store_for_future_use' => 'Store for future use',
     'pay_with_credit' => 'Paga con credito',
     'payment_method_saving_failed' => 'Il metodo di pagamento non può essere salvato per un utilizzo futuro.',
     'pay_with' => 'Paga con',
     'n/a' => 'N/A',
     'by_clicking_next_you_accept_terms' => 'Cliccando "avanti" confermerai l\'accettazione dei termini.',
     'not_specified' => 'Not specified',
     'before_proceeding_with_payment_warning' => 'Prima di procedere con il pagamento è necessario compilare i seguenti campi',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Paga',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Il promemoria 1 per la fattura :invoice è stato inviato a :client',
     'notification_invoice_reminder2_sent_subject' => 'Il promemoria 2 per la fattura :invoice è stato inviato a :client',
     'notification_invoice_reminder3_sent_subject' => 'Il promemoria 3 per la fattura :invoice è stato inviato a :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Il promemoria ricorrente per la fattura :invoice è stato inviato a :client',
     'assigned_user' => 'Utente assegnato',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Pagamento minimo',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'Nessuna fattura pagabile selezionata. Assicurati di non stare pagando una bozza di fattura o una fattura con saldo zero.',
     'required_payment_information' => 'Dettagli di pagamento richiesti',
     'required_payment_information_more' => 'Per completare un pagamento abbiamo bisogno di maggiori dettagli su di te.',
     'required_client_info_save_label' => 'Salveremo questo, così non dovrai inserirlo la prossima volta.',
     'notification_credit_bounced' => 'Non siamo stati in grado di consegnare il credito :invoice a :contact. \n :error',
     'notification_credit_bounced_subject' => 'Impossibile consegnare il credito :invoice',
     'save_payment_method_details' => 'Salva i dettagli del metodo di pagamento',
     'new_card' => 'New card',
     'new_bank_account' => 'Nuovo conto bancario',
     'company_limit_reached' => 'Limit of 10 companies per account.',
     'credits_applied_validation' => 'Il totale dei crediti applicati non può essere SUPERIORE al totale delle fatture',
     'credit_number_taken' => 'Credit number already taken',
     'credit_not_found' => 'Credito non trovato',
     'invoices_dont_match_client' => 'Le fatture selezionate non appartengono ad un unico cliente',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Fatture duplicate inviate.',
     'credit_with_no_invoice' => 'È necessario disporre di una fattura impostata quando si utilizza del credito in un pagamento',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Numero di fattura già usato',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Impossibile recuperare il pagamento specificato',
     'invoice_not_related_to_payment' => 'ID fattura :invoice non è relativa a questo pagamento',
     'credit_not_related_to_payment' => 'ID credito :credit non è relativo a questo pagamento',
     'max_refundable_invoice' => 'Tentativo di rimborso superiore al consentito per la fattura id :invoice, l\'importo massimo rimborsabile è :amount',
     'refund_without_invoices' => 'Si sta tentando di rimborsare un pagamento con fatture allegate, specificare le fatture valide da rimborsare.',
     'refund_without_credits' => 'Si sta tentando di rimborsare un pagamento con crediti allegati, specificare i crediti validi da rimborsare.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Numero di fattura ricorrente :number già usato',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Importo applicato rimanente insufficiente per coprire il pagamento.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'Una o più di queste fatture sono state pagate',
     'invoice_cannot_be_refunded' => 'L\'id della fattura :number non può essere rimborsato',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'Questo utente non può essere collegato a questa azienda. Forse ha già registrato un utente su un altro account?',
     'migration_completed' => 'Migration completed',
     'migration_completed_description' => 'Your migration has completed, please review your data after logging in.',
     'api_404' => '404 | Niente da vedere qui!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'No credits found.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'No Documents Found',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'La fattura non può essere segnata come pagata',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Oggetto di design personalizzato non valido',
     'quote_not_found' => 'Quote/s not found',
     'quote_unapprovable' => 'Impossibile approvare il preventivo in quanto scaduto.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'L\'aggiornamento automatico non è disponibile su questo sistema.',
     'user_detached' => 'Utente separato dall\'azienda',
     'create_webhook_failure' => 'Failed to create Webhook',
     'payment_message_extended' => 'Grazie per il pagamento di :amount per :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Token di pagamento non trovato, riprova. Se il problema persiste, prova con un altro metodo di pagamento',
     'vendor_address1' => 'Via Fornitore',
     'vendor_address2' => 'Scala/Appartamento Fornitore',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Show Actions',
     'start_multiselect' => 'Start Multiselect',
     'email_sent_to_confirm_email' => 'An email has been sent to confirm the email address',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Reply-To Name',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Color Theme',
     'start_migration' => 'Start Migration',
     'recurring_cancellation_request' => 'Richiesta di cancellazione della fattura ricorrente da :contact',
     'recurring_cancellation_request_body' => ':contact dal cliente :client ha chiesto di cancellare la fattura ricorrente :invoice',
     'hello' => 'Hello',
     'group_documents' => 'Group documents',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Select companies to migrate',
     'force_migration' => 'Force migration',
     'require_password_with_social_login' => 'Richiedi una password per il login Social',
     'stay_logged_in' => 'Rimani autenticato',
     'session_about_to_expire' => 'Warning: Your session is about to expire',
     'count_hours' => ':count Hours',
     'count_day' => '1 Day',
     'count_days' => ':count Days',
     'web_session_timeout' => 'Web Session Timeout',
     'security_settings' => 'Impostazioni di Sicurezza',
     'resend_email' => 'Resend Email',
     'confirm_your_email_address' => 'Please confirm your email address',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Accounting',
     'required_files_missing' => 'Please provide all CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'Puoi trovare API_SECRET nel file .env o in Invoice Ninja v5. Se questa proprietà manca, lascia il campo vuoto.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Attiva azienda',
     'activate_company_help' => 'Abilitare le e-mail, le fatture ricorrenti e le notifiche',
     'an_error_occurred_try_again' => 'An error occurred, please try again',
     'please_first_set_a_password' => 'Si prega di impostare prima una password',
     'changing_phone_disables_two_factor' => 'Attenzione: Cambiare il numero di telefono disabiliterà l\'autenticazione a due fattori',
     'help_translate' => 'Contribuisci alla traduzione',
     'please_select_a_country' => 'Selezionare un paese',
     'disabled_two_factor' => 'Successfully disabled 2FA',
     'connected_google' => 'Successfully connected account',
     'disconnected_google' => 'Successfully disconnected account',
     'delivered' => 'Delivered',
     'spam' => 'Spam',
     'view_docs' => 'View Docs',
     'enter_phone_to_enable_two_factor' => 'Si prega di fornire un numero di telefono cellulare per abilitare l\'autenticazione a due fattori',
     'send_sms' => 'Send SMS',
     'sms_code' => 'Codice SMS',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Disable Two Factor',
     'invoice_task_datelog' => 'Datelog delle attività di fatturazione',
     'invoice_task_datelog_help' => 'Aggiungi i dettagli della data alle voci della fattura',
     'promo_code' => 'Codice Promo',
     'recurring_invoice_issued_to' => 'Fattura ricorrente emessa a',
     'amount_greater_than_balance_v5' => 'L\'importo è superiore al saldo della fattura. Non si può pagare in eccesso una fattura.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Abbonamento',
     'new_subscription' => 'Nuovo Abbonamento',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Cerca 1 Abbonamento',
     'search_subscriptions' => 'Cerca :count Abbonamenti',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Scadenza Password',
     'shared_invoice_credit_counter' => 'Contatore di fatture/crediti condiviso',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'L\'importo è superiore al saldo della fattura. Non si può pagare in eccesso una fattura.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
